package OpenGL::Modern::NameLists::Modern;

# ATTENTION: This file is automatically generated by utils/generate-XS.pl!
#            Manual changes will be lost.

sub gl_functions {
    qw(
      glGetString
      glShaderSource_p
      glpCheckErrors
      glpSetAutoCheckErrors
      glAccum
      glActiveProgramEXT
      glActiveShaderProgram
      glActiveStencilFaceEXT
      glActiveTexture
      glActiveTextureARB
      glActiveVaryingNV_c
      glAddSwapHintRectWIN
      glAlphaFragmentOp1ATI
      glAlphaFragmentOp2ATI
      glAlphaFragmentOp3ATI
      glAlphaFunc
      glAlphaFuncx
      glApplyTextureEXT
      glAreProgramsResidentNV_c
      glAreTexturesResident_c
      glAreTexturesResidentEXT_c
      glArrayElement
      glArrayElementEXT
      glArrayObjectATI
      glAsyncMarkerSGIX
      glAttachObjectARB
      glAttachShader
      glBegin
      glBeginConditionalRender
      glBeginConditionalRenderNV
      glBeginConditionalRenderNVX
      glBeginFragmentShaderATI
      glBeginOcclusionQueryNV
      glBeginPerfMonitorAMD
      glBeginPerfQueryINTEL
      glBeginQuery
      glBeginQueryANGLE
      glBeginQueryARB
      glBeginQueryIndexed
      glBeginSceneEXT
      glBeginTransformFeedback
      glBeginTransformFeedbackEXT
      glBeginTransformFeedbackNV
      glBeginVertexShaderEXT
      glBeginVideoCaptureNV
      glBindAttribLocation_c
      glBindAttribLocationARB_c
      glBindBuffer
      glBindBufferARB
      glBindBufferBase
      glBindBufferBaseEXT
      glBindBufferBaseNV
      glBindBufferOffsetEXT
      glBindBufferOffsetNV
      glBindBufferRange
      glBindBufferRangeEXT
      glBindBufferRangeNV
      glBindBuffersBase_c
      glBindBuffersRange_c
      glBindFragDataLocation_c
      glBindFragDataLocationEXT_c
      glBindFragDataLocationIndexed_c
      glBindFragmentShaderATI
      glBindFramebuffer
      glBindFramebufferEXT
      glBindImageTexture
      glBindImageTextureEXT
      glBindImageTextures_c
      glBindLightParameterEXT
      glBindMaterialParameterEXT
      glBindMultiTextureEXT
      glBindParameterEXT
      glBindProgramARB
      glBindProgramNV
      glBindProgramPipeline
      glBindRenderbuffer
      glBindRenderbufferEXT
      glBindSampler
      glBindSamplers_c
      glBindTexGenParameterEXT
      glBindTexture
      glBindTextureEXT
      glBindTextures_c
      glBindTextureUnit
      glBindTextureUnitParameterEXT
      glBindTransformFeedback
      glBindTransformFeedbackNV
      glBindVertexArray
      glBindVertexArrayAPPLE
      glBindVertexBuffer
      glBindVertexBuffers_c
      glBindVertexShaderEXT
      glBindVideoCaptureStreamBufferNV
      glBindVideoCaptureStreamTextureNV
      glBinormalPointerEXT_c
      glBitmap_c
      glBlendBarrierKHR
      glBlendBarrierNV
      glBlendColor
      glBlendColorEXT
      glBlendEquation
      glBlendEquationEXT
      glBlendEquationi
      glBlendEquationiARB
      glBlendEquationIndexedAMD
      glBlendEquationSeparate
      glBlendEquationSeparateEXT
      glBlendEquationSeparatei
      glBlendEquationSeparateiARB
      glBlendEquationSeparateIndexedAMD
      glBlendFunc
      glBlendFunci
      glBlendFunciARB
      glBlendFuncIndexedAMD
      glBlendFuncSeparate
      glBlendFuncSeparateEXT
      glBlendFuncSeparatei
      glBlendFuncSeparateiARB
      glBlendFuncSeparateIndexedAMD
      glBlendParameteriNV
      glBlitFramebuffer
      glBlitFramebufferANGLE
      glBlitFramebufferEXT
      glBlitNamedFramebuffer
      glBufferAddressRangeNV
      glBufferData_c
      glBufferDataARB_c
      glBufferPageCommitmentARB
      glBufferParameteriAPPLE
      glBufferRegionEnabled
      glBufferStorage_c
      glBufferSubData_c
      glBufferSubDataARB_c
      glCallCommandListNV
      glCallList
      glCallLists_c
      glCheckFramebufferStatus
      glCheckFramebufferStatusEXT
      glCheckNamedFramebufferStatus
      glCheckNamedFramebufferStatusEXT
      glClampColor
      glClampColorARB
      glClear
      glClearAccum
      glClearBufferData_c
      glClearBufferfi
      glClearBufferfv_c
      glClearBufferiv_c
      glClearBufferSubData_c
      glClearBufferuiv_c
      glClearColor
      glClearColorIiEXT
      glClearColorIuiEXT
      glClearColorx
      glClearDepth
      glClearDepthdNV
      glClearDepthf
      glClearDepthfOES
      glClearDepthx
      glClearIndex
      glClearNamedBufferData_c
      glClearNamedBufferDataEXT_c
      glClearNamedBufferSubData_c
      glClearNamedBufferSubDataEXT_c
      glClearNamedFramebufferfi
      glClearNamedFramebufferfv_c
      glClearNamedFramebufferiv_c
      glClearNamedFramebufferuiv_c
      glClearStencil
      glClearTexImage_c
      glClearTexSubImage_c
      glClientActiveTexture
      glClientActiveTextureARB
      glClientActiveVertexStreamATI
      glClientAttribDefaultEXT
      glClientWaitSync
      glClipControl
      glClipPlane_c
      glClipPlanef_c
      glClipPlanefOES_c
      glClipPlanex_c
      glColor3b
      glColor3bv_c
      glColor3d
      glColor3dv_c
      glColor3f
      glColor3fv_c
      glColor3fVertex3fSUN
      glColor3fVertex3fvSUN_c
      glColor3hNV
      glColor3hvNV_c
      glColor3i
      glColor3iv_c
      glColor3s
      glColor3sv_c
      glColor3ub
      glColor3ubv_c
      glColor3ui
      glColor3uiv_c
      glColor3us
      glColor3usv_c
      glColor4b
      glColor4bv_c
      glColor4d
      glColor4dv_c
      glColor4f
      glColor4fNormal3fVertex3fSUN
      glColor4fNormal3fVertex3fvSUN_c
      glColor4fv_c
      glColor4hNV
      glColor4hvNV_c
      glColor4i
      glColor4iv_c
      glColor4s
      glColor4sv_c
      glColor4ub
      glColor4ubv_c
      glColor4ubVertex2fSUN
      glColor4ubVertex2fvSUN_c
      glColor4ubVertex3fSUN
      glColor4ubVertex3fvSUN_c
      glColor4ui
      glColor4uiv_c
      glColor4us
      glColor4usv_c
      glColor4x
      glColorFormatNV
      glColorFragmentOp1ATI
      glColorFragmentOp2ATI
      glColorFragmentOp3ATI
      glColorMask
      glColorMaski
      glColorMaskIndexedEXT
      glColorMaterial
      glColorP3ui
      glColorP3uiv_c
      glColorP4ui
      glColorP4uiv_c
      glColorPointer_c
      glColorPointerEXT_c
      glColorPointerListIBM_c
      glColorPointervINTEL_c
      glColorSubTable_c
      glColorSubTableEXT_c
      glColorTable_c
      glColorTableEXT_c
      glColorTableParameterfv_c
      glColorTableParameterfvSGI_c
      glColorTableParameteriv_c
      glColorTableParameterivSGI_c
      glColorTableSGI_c
      glCombinerInputNV
      glCombinerOutputNV
      glCombinerParameterfNV
      glCombinerParameterfvNV_c
      glCombinerParameteriNV
      glCombinerParameterivNV_c
      glCombinerStageParameterfvNV_c
      glCommandListSegmentsNV
      glCompileCommandListNV
      glCompileShader
      glCompileShaderARB
      glCompileShaderIncludeARB_c
      glCompressedMultiTexImage1DEXT_c
      glCompressedMultiTexImage2DEXT_c
      glCompressedMultiTexImage3DEXT_c
      glCompressedMultiTexSubImage1DEXT_c
      glCompressedMultiTexSubImage2DEXT_c
      glCompressedMultiTexSubImage3DEXT_c
      glCompressedTexImage1D_c
      glCompressedTexImage1DARB_c
      glCompressedTexImage2D_c
      glCompressedTexImage2DARB_c
      glCompressedTexImage3D_c
      glCompressedTexImage3DARB_c
      glCompressedTexSubImage1D_c
      glCompressedTexSubImage1DARB_c
      glCompressedTexSubImage2D_c
      glCompressedTexSubImage2DARB_c
      glCompressedTexSubImage3D_c
      glCompressedTexSubImage3DARB_c
      glCompressedTextureImage1DEXT_c
      glCompressedTextureImage2DEXT_c
      glCompressedTextureImage3DEXT_c
      glCompressedTextureSubImage1D_c
      glCompressedTextureSubImage1DEXT_c
      glCompressedTextureSubImage2D_c
      glCompressedTextureSubImage2DEXT_c
      glCompressedTextureSubImage3D_c
      glCompressedTextureSubImage3DEXT_c
      glConservativeRasterParameterfNV
      glConservativeRasterParameteriNV
      glConvolutionFilter1D_c
      glConvolutionFilter1DEXT_c
      glConvolutionFilter2D_c
      glConvolutionFilter2DEXT_c
      glConvolutionParameterf
      glConvolutionParameterfEXT
      glConvolutionParameterfv_c
      glConvolutionParameterfvEXT_c
      glConvolutionParameteri
      glConvolutionParameteriEXT
      glConvolutionParameteriv_c
      glConvolutionParameterivEXT_c
      glCopyBufferSubData
      glCopyColorSubTable
      glCopyColorSubTableEXT
      glCopyColorTable
      glCopyColorTableSGI
      glCopyConvolutionFilter1D
      glCopyConvolutionFilter1DEXT
      glCopyConvolutionFilter2D
      glCopyConvolutionFilter2DEXT
      glCopyImageSubData
      glCopyImageSubDataNV
      glCopyMultiTexImage1DEXT
      glCopyMultiTexImage2DEXT
      glCopyMultiTexSubImage1DEXT
      glCopyMultiTexSubImage2DEXT
      glCopyMultiTexSubImage3DEXT
      glCopyNamedBufferSubData
      glCopyPathNV
      glCopyPixels
      glCopyTexImage1D
      glCopyTexImage1DEXT
      glCopyTexImage2D
      glCopyTexImage2DEXT
      glCopyTexSubImage1D
      glCopyTexSubImage1DEXT
      glCopyTexSubImage2D
      glCopyTexSubImage2DEXT
      glCopyTexSubImage3D
      glCopyTexSubImage3DEXT
      glCopyTextureImage1DEXT
      glCopyTextureImage2DEXT
      glCopyTextureSubImage1D
      glCopyTextureSubImage1DEXT
      glCopyTextureSubImage2D
      glCopyTextureSubImage2DEXT
      glCopyTextureSubImage3D
      glCopyTextureSubImage3DEXT
      glCoverageModulationNV
      glCoverageModulationTableNV_c
      glCoverFillPathInstancedNV_c
      glCoverFillPathNV
      glCoverStrokePathInstancedNV_c
      glCoverStrokePathNV
      glCreateBuffers_c
      glCreateCommandListsNV_c
      glCreateFramebuffers_c
      glCreatePerfQueryINTEL_c
      glCreateProgram
      glCreateProgramObjectARB
      glCreateProgramPipelines_c
      glCreateQueries_c
      glCreateRenderbuffers_c
      glCreateSamplers_c
      glCreateShader
      glCreateShaderObjectARB
      glCreateShaderProgramEXT_c
      glCreateShaderProgramv_c
      glCreateStatesNV_c
      glCreateSyncFromCLeventARB
      glCreateTextures_c
      glCreateTransformFeedbacks_c
      glCreateVertexArrays_c
      glCullFace
      glCullParameterdvEXT_c
      glCullParameterfvEXT_c
      glCurrentPaletteMatrixARB
      glDebugMessageCallback_c
      glDebugMessageCallbackAMD_c
      glDebugMessageCallbackARB_c
      glDebugMessageControl_c
      glDebugMessageControlARB_c
      glDebugMessageEnableAMD_c
      glDebugMessageInsert_c
      glDebugMessageInsertAMD_c
      glDebugMessageInsertARB_c
      glDeleteAsyncMarkersSGIX
      glDeleteBufferRegion
      glDeleteBuffers_c
      glDeleteBuffersARB_c
      glDeleteCommandListsNV_c
      glDeleteFencesAPPLE_c
      glDeleteFencesNV_c
      glDeleteFragmentShaderATI
      glDeleteFramebuffers_c
      glDeleteFramebuffersEXT_c
      glDeleteLists
      glDeleteNamedStringARB_c
      glDeleteNamesAMD_c
      glDeleteObjectARB
      glDeleteOcclusionQueriesNV_c
      glDeletePathsNV
      glDeletePerfMonitorsAMD_c
      glDeletePerfQueryINTEL
      glDeleteProgram
      glDeleteProgramPipelines_c
      glDeleteProgramsARB_c
      glDeleteProgramsNV_c
      glDeleteQueries_c
      glDeleteQueriesANGLE_c
      glDeleteQueriesARB_c
      glDeleteRenderbuffers_c
      glDeleteRenderbuffersEXT_c
      glDeleteSamplers_c
      glDeleteShader
      glDeleteStatesNV_c
      glDeleteSync
      glDeleteTextures_c
      glDeleteTexturesEXT_c
      glDeleteTransformFeedbacks_c
      glDeleteTransformFeedbacksNV_c
      glDeleteVertexArrays_c
      glDeleteVertexArraysAPPLE_c
      glDeleteVertexShaderEXT
      glDepthBoundsdNV
      glDepthBoundsEXT
      glDepthFunc
      glDepthMask
      glDepthRange
      glDepthRangeArrayv_c
      glDepthRangedNV
      glDepthRangef
      glDepthRangefOES
      glDepthRangeIndexed
      glDepthRangex
      glDetachObjectARB
      glDetachShader
      glDetailTexFuncSGIS_c
      glDisable
      glDisableClientState
      glDisableClientStateiEXT
      glDisableClientStateIndexedEXT
      glDisablei
      glDisableIndexedEXT
      glDisableVariantClientStateEXT
      glDisableVertexArrayAttrib
      glDisableVertexArrayAttribEXT
      glDisableVertexArrayEXT
      glDisableVertexAttribAPPLE
      glDisableVertexAttribArray
      glDisableVertexAttribArrayARB
      glDispatchCompute
      glDispatchComputeGroupSizeARB
      glDispatchComputeIndirect
      glDrawArrays
      glDrawArraysEXT
      glDrawArraysIndirect_c
      glDrawArraysInstanced
      glDrawArraysInstancedANGLE
      glDrawArraysInstancedARB
      glDrawArraysInstancedBaseInstance
      glDrawArraysInstancedEXT
      glDrawBuffer
      glDrawBufferRegion
      glDrawBuffers_c
      glDrawBuffersARB_c
      glDrawBuffersATI_c
      glDrawCommandsAddressNV_c
      glDrawCommandsNV_c
      glDrawCommandsStatesAddressNV_c
      glDrawCommandsStatesNV_c
      glDrawElementArrayAPPLE
      glDrawElementArrayATI
      glDrawElements_c
      glDrawElementsBaseVertex_c
      glDrawElementsIndirect_c
      glDrawElementsInstanced_c
      glDrawElementsInstancedANGLE_c
      glDrawElementsInstancedARB_c
      glDrawElementsInstancedBaseInstance_c
      glDrawElementsInstancedBaseVertex_c
      glDrawElementsInstancedBaseVertexBaseInstance_c
      glDrawElementsInstancedEXT_c
      glDrawPixels_c
      glDrawRangeElementArrayAPPLE
      glDrawRangeElementArrayATI
      glDrawRangeElements_c
      glDrawRangeElementsBaseVertex_c
      glDrawRangeElementsEXT_c
      glDrawTextureNV
      glDrawTransformFeedback
      glDrawTransformFeedbackInstanced
      glDrawTransformFeedbackNV
      glDrawTransformFeedbackStream
      glDrawTransformFeedbackStreamInstanced
      glDrawVkImageNV
      glEdgeFlag
      glEdgeFlagFormatNV
      glEdgeFlagPointer_c
      glEdgeFlagPointerEXT_c
      glEdgeFlagPointerListIBM_c
      glEdgeFlagv_c
      glElementPointerAPPLE_c
      glElementPointerATI_c
      glEnable
      glEnableClientState
      glEnableClientStateiEXT
      glEnableClientStateIndexedEXT
      glEnablei
      glEnableIndexedEXT
      glEnableVariantClientStateEXT
      glEnableVertexArrayAttrib
      glEnableVertexArrayAttribEXT
      glEnableVertexArrayEXT
      glEnableVertexAttribAPPLE
      glEnableVertexAttribArray
      glEnableVertexAttribArrayARB
      glEnd
      glEndConditionalRender
      glEndConditionalRenderNV
      glEndConditionalRenderNVX
      glEndFragmentShaderATI
      glEndList
      glEndOcclusionQueryNV
      glEndPerfMonitorAMD
      glEndPerfQueryINTEL
      glEndQuery
      glEndQueryANGLE
      glEndQueryARB
      glEndQueryIndexed
      glEndSceneEXT
      glEndTransformFeedback
      glEndTransformFeedbackEXT
      glEndTransformFeedbackNV
      glEndVertexShaderEXT
      glEndVideoCaptureNV
      glEvalCoord1d
      glEvalCoord1dv_c
      glEvalCoord1f
      glEvalCoord1fv_c
      glEvalCoord2d
      glEvalCoord2dv_c
      glEvalCoord2f
      glEvalCoord2fv_c
      glEvalMapsNV
      glEvalMesh1
      glEvalMesh2
      glEvalPoint1
      glEvalPoint2
      GLEW_3DFX_multisample
      GLEW_3DFX_tbuffer
      GLEW_3DFX_texture_compression_FXT1
      GLEW_AMD_blend_minmax_factor
      GLEW_AMD_conservative_depth
      GLEW_AMD_debug_output
      GLEW_AMD_depth_clamp_separate
      GLEW_AMD_draw_buffers_blend
      GLEW_AMD_gcn_shader
      GLEW_AMD_gpu_shader_int64
      GLEW_AMD_interleaved_elements
      GLEW_AMD_multi_draw_indirect
      GLEW_AMD_name_gen_delete
      GLEW_AMD_occlusion_query_event
      GLEW_AMD_performance_monitor
      GLEW_AMD_pinned_memory
      GLEW_AMD_query_buffer_object
      GLEW_AMD_sample_positions
      GLEW_AMD_seamless_cubemap_per_texture
      GLEW_AMD_shader_atomic_counter_ops
      GLEW_AMD_shader_explicit_vertex_parameter
      GLEW_AMD_shader_stencil_export
      GLEW_AMD_shader_stencil_value_export
      GLEW_AMD_shader_trinary_minmax
      GLEW_AMD_sparse_texture
      GLEW_AMD_stencil_operation_extended
      GLEW_AMD_texture_texture4
      GLEW_AMD_transform_feedback3_lines_triangles
      GLEW_AMD_transform_feedback4
      GLEW_AMD_vertex_shader_layer
      GLEW_AMD_vertex_shader_tessellator
      GLEW_AMD_vertex_shader_viewport_index
      GLEW_ANGLE_depth_texture
      GLEW_ANGLE_framebuffer_blit
      GLEW_ANGLE_framebuffer_multisample
      GLEW_ANGLE_instanced_arrays
      GLEW_ANGLE_pack_reverse_row_order
      GLEW_ANGLE_program_binary
      GLEW_ANGLE_texture_compression_dxt1
      GLEW_ANGLE_texture_compression_dxt3
      GLEW_ANGLE_texture_compression_dxt5
      GLEW_ANGLE_texture_usage
      GLEW_ANGLE_timer_query
      GLEW_ANGLE_translated_shader_source
      GLEW_APPLE_aux_depth_stencil
      GLEW_APPLE_client_storage
      GLEW_APPLE_element_array
      GLEW_APPLE_fence
      GLEW_APPLE_float_pixels
      GLEW_APPLE_flush_buffer_range
      GLEW_APPLE_object_purgeable
      GLEW_APPLE_pixel_buffer
      GLEW_APPLE_rgb_422
      GLEW_APPLE_row_bytes
      GLEW_APPLE_specular_vector
      GLEW_APPLE_texture_range
      GLEW_APPLE_transform_hint
      GLEW_APPLE_vertex_array_object
      GLEW_APPLE_vertex_array_range
      GLEW_APPLE_vertex_program_evaluators
      GLEW_APPLE_ycbcr_422
      GLEW_ARB_ES2_compatibility
      GLEW_ARB_ES3_1_compatibility
      GLEW_ARB_ES3_2_compatibility
      GLEW_ARB_ES3_compatibility
      GLEW_ARB_arrays_of_arrays
      GLEW_ARB_base_instance
      GLEW_ARB_bindless_texture
      GLEW_ARB_blend_func_extended
      GLEW_ARB_buffer_storage
      GLEW_ARB_cl_event
      GLEW_ARB_clear_buffer_object
      GLEW_ARB_clear_texture
      GLEW_ARB_clip_control
      GLEW_ARB_color_buffer_float
      GLEW_ARB_compatibility
      GLEW_ARB_compressed_texture_pixel_storage
      GLEW_ARB_compute_shader
      GLEW_ARB_compute_variable_group_size
      GLEW_ARB_conditional_render_inverted
      GLEW_ARB_conservative_depth
      GLEW_ARB_copy_buffer
      GLEW_ARB_copy_image
      GLEW_ARB_cull_distance
      GLEW_ARB_debug_output
      GLEW_ARB_depth_buffer_float
      GLEW_ARB_depth_clamp
      GLEW_ARB_depth_texture
      GLEW_ARB_derivative_control
      GLEW_ARB_direct_state_access
      GLEW_ARB_draw_buffers
      GLEW_ARB_draw_buffers_blend
      GLEW_ARB_draw_elements_base_vertex
      GLEW_ARB_draw_indirect
      GLEW_ARB_draw_instanced
      GLEW_ARB_enhanced_layouts
      GLEW_ARB_explicit_attrib_location
      GLEW_ARB_explicit_uniform_location
      GLEW_ARB_fragment_coord_conventions
      GLEW_ARB_fragment_layer_viewport
      GLEW_ARB_fragment_program
      GLEW_ARB_fragment_program_shadow
      GLEW_ARB_fragment_shader
      GLEW_ARB_fragment_shader_interlock
      GLEW_ARB_framebuffer_no_attachments
      GLEW_ARB_framebuffer_object
      GLEW_ARB_framebuffer_sRGB
      GLEW_ARB_geometry_shader4
      GLEW_ARB_get_program_binary
      GLEW_ARB_get_texture_sub_image
      GLEW_ARB_gl_spirv
      GLEW_ARB_gpu_shader5
      GLEW_ARB_gpu_shader_fp64
      GLEW_ARB_gpu_shader_int64
      GLEW_ARB_half_float_pixel
      GLEW_ARB_half_float_vertex
      GLEW_ARB_imaging
      GLEW_ARB_indirect_parameters
      GLEW_ARB_instanced_arrays
      GLEW_ARB_internalformat_query
      GLEW_ARB_internalformat_query2
      GLEW_ARB_invalidate_subdata
      GLEW_ARB_map_buffer_alignment
      GLEW_ARB_map_buffer_range
      GLEW_ARB_matrix_palette
      GLEW_ARB_multi_bind
      GLEW_ARB_multi_draw_indirect
      GLEW_ARB_multisample
      GLEW_ARB_multitexture
      GLEW_ARB_occlusion_query
      GLEW_ARB_occlusion_query2
      GLEW_ARB_parallel_shader_compile
      GLEW_ARB_pipeline_statistics_query
      GLEW_ARB_pixel_buffer_object
      GLEW_ARB_point_parameters
      GLEW_ARB_point_sprite
      GLEW_ARB_post_depth_coverage
      GLEW_ARB_program_interface_query
      GLEW_ARB_provoking_vertex
      GLEW_ARB_query_buffer_object
      GLEW_ARB_robust_buffer_access_behavior
      GLEW_ARB_robustness
      GLEW_ARB_robustness_application_isolation
      GLEW_ARB_robustness_share_group_isolation
      GLEW_ARB_sample_locations
      GLEW_ARB_sample_shading
      GLEW_ARB_sampler_objects
      GLEW_ARB_seamless_cube_map
      GLEW_ARB_seamless_cubemap_per_texture
      GLEW_ARB_separate_shader_objects
      GLEW_ARB_shader_atomic_counter_ops
      GLEW_ARB_shader_atomic_counters
      GLEW_ARB_shader_ballot
      GLEW_ARB_shader_bit_encoding
      GLEW_ARB_shader_clock
      GLEW_ARB_shader_draw_parameters
      GLEW_ARB_shader_group_vote
      GLEW_ARB_shader_image_load_store
      GLEW_ARB_shader_image_size
      GLEW_ARB_shader_objects
      GLEW_ARB_shader_precision
      GLEW_ARB_shader_stencil_export
      GLEW_ARB_shader_storage_buffer_object
      GLEW_ARB_shader_subroutine
      GLEW_ARB_shader_texture_image_samples
      GLEW_ARB_shader_texture_lod
      GLEW_ARB_shader_viewport_layer_array
      GLEW_ARB_shading_language_100
      GLEW_ARB_shading_language_420pack
      GLEW_ARB_shading_language_include
      GLEW_ARB_shading_language_packing
      GLEW_ARB_shadow
      GLEW_ARB_shadow_ambient
      GLEW_ARB_sparse_buffer
      GLEW_ARB_sparse_texture
      GLEW_ARB_sparse_texture2
      GLEW_ARB_sparse_texture_clamp
      GLEW_ARB_stencil_texturing
      GLEW_ARB_sync
      GLEW_ARB_tessellation_shader
      GLEW_ARB_texture_barrier
      GLEW_ARB_texture_border_clamp
      GLEW_ARB_texture_buffer_object
      GLEW_ARB_texture_buffer_object_rgb32
      GLEW_ARB_texture_buffer_range
      GLEW_ARB_texture_compression
      GLEW_ARB_texture_compression_bptc
      GLEW_ARB_texture_compression_rgtc
      GLEW_ARB_texture_cube_map
      GLEW_ARB_texture_cube_map_array
      GLEW_ARB_texture_env_add
      GLEW_ARB_texture_env_combine
      GLEW_ARB_texture_env_crossbar
      GLEW_ARB_texture_env_dot3
      GLEW_ARB_texture_filter_minmax
      GLEW_ARB_texture_float
      GLEW_ARB_texture_gather
      GLEW_ARB_texture_mirror_clamp_to_edge
      GLEW_ARB_texture_mirrored_repeat
      GLEW_ARB_texture_multisample
      GLEW_ARB_texture_non_power_of_two
      GLEW_ARB_texture_query_levels
      GLEW_ARB_texture_query_lod
      GLEW_ARB_texture_rectangle
      GLEW_ARB_texture_rg
      GLEW_ARB_texture_rgb10_a2ui
      GLEW_ARB_texture_stencil8
      GLEW_ARB_texture_storage
      GLEW_ARB_texture_storage_multisample
      GLEW_ARB_texture_swizzle
      GLEW_ARB_texture_view
      GLEW_ARB_timer_query
      GLEW_ARB_transform_feedback2
      GLEW_ARB_transform_feedback3
      GLEW_ARB_transform_feedback_instanced
      GLEW_ARB_transform_feedback_overflow_query
      GLEW_ARB_transpose_matrix
      GLEW_ARB_uniform_buffer_object
      GLEW_ARB_vertex_array_bgra
      GLEW_ARB_vertex_array_object
      GLEW_ARB_vertex_attrib_64bit
      GLEW_ARB_vertex_attrib_binding
      GLEW_ARB_vertex_blend
      GLEW_ARB_vertex_buffer_object
      GLEW_ARB_vertex_program
      GLEW_ARB_vertex_shader
      GLEW_ARB_vertex_type_10f_11f_11f_rev
      GLEW_ARB_vertex_type_2_10_10_10_rev
      GLEW_ARB_viewport_array
      GLEW_ARB_window_pos
      GLEW_ATIX_point_sprites
      GLEW_ATIX_texture_env_combine3
      GLEW_ATIX_texture_env_route
      GLEW_ATIX_vertex_shader_output_point_size
      GLEW_ATI_draw_buffers
      GLEW_ATI_element_array
      GLEW_ATI_envmap_bumpmap
      GLEW_ATI_fragment_shader
      GLEW_ATI_map_object_buffer
      GLEW_ATI_meminfo
      GLEW_ATI_pn_triangles
      GLEW_ATI_separate_stencil
      GLEW_ATI_shader_texture_lod
      GLEW_ATI_text_fragment_shader
      GLEW_ATI_texture_compression_3dc
      GLEW_ATI_texture_env_combine3
      GLEW_ATI_texture_float
      GLEW_ATI_texture_mirror_once
      GLEW_ATI_vertex_array_object
      GLEW_ATI_vertex_attrib_array_object
      GLEW_ATI_vertex_streams
      GLEW_EGL_NV_robustness_video_memory_purge
      GLEW_EXT_422_pixels
      GLEW_EXT_Cg_shader
      GLEW_EXT_abgr
      GLEW_EXT_bgra
      GLEW_EXT_bindable_uniform
      GLEW_EXT_blend_color
      GLEW_EXT_blend_equation_separate
      GLEW_EXT_blend_func_separate
      GLEW_EXT_blend_logic_op
      GLEW_EXT_blend_minmax
      GLEW_EXT_blend_subtract
      GLEW_EXT_clip_volume_hint
      GLEW_EXT_cmyka
      GLEW_EXT_color_subtable
      GLEW_EXT_compiled_vertex_array
      GLEW_EXT_convolution
      GLEW_EXT_coordinate_frame
      GLEW_EXT_copy_texture
      GLEW_EXT_cull_vertex
      GLEW_EXT_debug_label
      GLEW_EXT_debug_marker
      GLEW_EXT_depth_bounds_test
      GLEW_EXT_direct_state_access
      GLEW_EXT_draw_buffers2
      GLEW_EXT_draw_instanced
      GLEW_EXT_draw_range_elements
      GLEW_EXT_fog_coord
      GLEW_EXT_fragment_lighting
      GLEW_EXT_framebuffer_blit
      GLEW_EXT_framebuffer_multisample
      GLEW_EXT_framebuffer_multisample_blit_scaled
      GLEW_EXT_framebuffer_object
      GLEW_EXT_framebuffer_sRGB
      GLEW_EXT_geometry_shader4
      GLEW_EXT_gpu_program_parameters
      GLEW_EXT_gpu_shader4
      GLEW_EXT_histogram
      GLEW_EXT_index_array_formats
      GLEW_EXT_index_func
      GLEW_EXT_index_material
      GLEW_EXT_index_texture
      GLEW_EXT_light_texture
      GLEW_EXT_misc_attribute
      GLEW_EXT_multi_draw_arrays
      GLEW_EXT_multisample
      GLEW_EXT_packed_depth_stencil
      GLEW_EXT_packed_float
      GLEW_EXT_packed_pixels
      GLEW_EXT_paletted_texture
      GLEW_EXT_pixel_buffer_object
      GLEW_EXT_pixel_transform
      GLEW_EXT_pixel_transform_color_table
      GLEW_EXT_point_parameters
      GLEW_EXT_polygon_offset
      GLEW_EXT_polygon_offset_clamp
      GLEW_EXT_post_depth_coverage
      GLEW_EXT_provoking_vertex
      GLEW_EXT_raster_multisample
      GLEW_EXT_rescale_normal
      GLEW_EXT_scene_marker
      GLEW_EXT_secondary_color
      GLEW_EXT_separate_shader_objects
      GLEW_EXT_separate_specular_color
      GLEW_EXT_shader_image_load_formatted
      GLEW_EXT_shader_image_load_store
      GLEW_EXT_shader_integer_mix
      GLEW_EXT_shadow_funcs
      GLEW_EXT_shared_texture_palette
      GLEW_EXT_sparse_texture2
      GLEW_EXT_stencil_clear_tag
      GLEW_EXT_stencil_two_side
      GLEW_EXT_stencil_wrap
      GLEW_EXT_subtexture
      GLEW_EXT_texture
      GLEW_EXT_texture3D
      GLEW_EXT_texture_array
      GLEW_EXT_texture_buffer_object
      GLEW_EXT_texture_compression_dxt1
      GLEW_EXT_texture_compression_latc
      GLEW_EXT_texture_compression_rgtc
      GLEW_EXT_texture_compression_s3tc
      GLEW_EXT_texture_cube_map
      GLEW_EXT_texture_edge_clamp
      GLEW_EXT_texture_env
      GLEW_EXT_texture_env_add
      GLEW_EXT_texture_env_combine
      GLEW_EXT_texture_env_dot3
      GLEW_EXT_texture_filter_anisotropic
      GLEW_EXT_texture_filter_minmax
      GLEW_EXT_texture_integer
      GLEW_EXT_texture_lod_bias
      GLEW_EXT_texture_mirror_clamp
      GLEW_EXT_texture_object
      GLEW_EXT_texture_perturb_normal
      GLEW_EXT_texture_rectangle
      GLEW_EXT_texture_sRGB
      GLEW_EXT_texture_sRGB_decode
      GLEW_EXT_texture_shared_exponent
      GLEW_EXT_texture_snorm
      GLEW_EXT_texture_swizzle
      GLEW_EXT_timer_query
      GLEW_EXT_transform_feedback
      GLEW_EXT_vertex_array
      GLEW_EXT_vertex_array_bgra
      GLEW_EXT_vertex_attrib_64bit
      GLEW_EXT_vertex_shader
      GLEW_EXT_vertex_weighting
      GLEW_EXT_window_rectangles
      GLEW_EXT_x11_sync_object
      GLEW_GREMEDY_frame_terminator
      GLEW_GREMEDY_string_marker
      GLEW_HP_convolution_border_modes
      GLEW_HP_image_transform
      GLEW_HP_occlusion_test
      GLEW_HP_texture_lighting
      GLEW_IBM_cull_vertex
      GLEW_IBM_multimode_draw_arrays
      GLEW_IBM_rasterpos_clip
      GLEW_IBM_static_data
      GLEW_IBM_texture_mirrored_repeat
      GLEW_IBM_vertex_array_lists
      GLEW_INGR_color_clamp
      GLEW_INGR_interlace_read
      GLEW_INTEL_conservative_rasterization
      GLEW_INTEL_fragment_shader_ordering
      GLEW_INTEL_framebuffer_CMAA
      GLEW_INTEL_map_texture
      GLEW_INTEL_parallel_arrays
      GLEW_INTEL_performance_query
      GLEW_INTEL_texture_scissor
      GLEW_KHR_blend_equation_advanced
      GLEW_KHR_blend_equation_advanced_coherent
      GLEW_KHR_context_flush_control
      GLEW_KHR_debug
      GLEW_KHR_no_error
      GLEW_KHR_robust_buffer_access_behavior
      GLEW_KHR_robustness
      GLEW_KHR_texture_compression_astc_hdr
      GLEW_KHR_texture_compression_astc_ldr
      GLEW_KHR_texture_compression_astc_sliced_3d
      GLEW_KTX_buffer_region
      GLEW_MESAX_texture_stack
      GLEW_MESA_pack_invert
      GLEW_MESA_resize_buffers
      GLEW_MESA_shader_integer_functions
      GLEW_MESA_window_pos
      GLEW_MESA_ycbcr_texture
      GLEW_NVX_blend_equation_advanced_multi_draw_buffers
      GLEW_NVX_conditional_render
      GLEW_NVX_gpu_memory_info
      GLEW_NVX_linked_gpu_multicast
      GLEW_NV_bindless_multi_draw_indirect
      GLEW_NV_bindless_multi_draw_indirect_count
      GLEW_NV_bindless_texture
      GLEW_NV_blend_equation_advanced
      GLEW_NV_blend_equation_advanced_coherent
      GLEW_NV_blend_square
      GLEW_NV_clip_space_w_scaling
      GLEW_NV_command_list
      GLEW_NV_compute_program5
      GLEW_NV_conditional_render
      GLEW_NV_conservative_raster
      GLEW_NV_conservative_raster_dilate
      GLEW_NV_conservative_raster_pre_snap_triangles
      GLEW_NV_copy_depth_to_color
      GLEW_NV_copy_image
      GLEW_NV_deep_texture3D
      GLEW_NV_depth_buffer_float
      GLEW_NV_depth_clamp
      GLEW_NV_depth_range_unclamped
      GLEW_NV_draw_texture
      GLEW_NV_draw_vulkan_image
      GLEW_NV_evaluators
      GLEW_NV_explicit_multisample
      GLEW_NV_fence
      GLEW_NV_fill_rectangle
      GLEW_NV_float_buffer
      GLEW_NV_fog_distance
      GLEW_NV_fragment_coverage_to_color
      GLEW_NV_fragment_program
      GLEW_NV_fragment_program2
      GLEW_NV_fragment_program4
      GLEW_NV_fragment_program_option
      GLEW_NV_fragment_shader_interlock
      GLEW_NV_framebuffer_mixed_samples
      GLEW_NV_framebuffer_multisample_coverage
      GLEW_NV_geometry_program4
      GLEW_NV_geometry_shader4
      GLEW_NV_geometry_shader_passthrough
      GLEW_NV_gpu_multicast
      GLEW_NV_gpu_program4
      GLEW_NV_gpu_program5
      GLEW_NV_gpu_program5_mem_extended
      GLEW_NV_gpu_program_fp64
      GLEW_NV_gpu_shader5
      GLEW_NV_half_float
      GLEW_NV_internalformat_sample_query
      GLEW_NV_light_max_exponent
      GLEW_NV_multisample_coverage
      GLEW_NV_multisample_filter_hint
      GLEW_NV_occlusion_query
      GLEW_NV_packed_depth_stencil
      GLEW_NV_parameter_buffer_object
      GLEW_NV_parameter_buffer_object2
      GLEW_NV_path_rendering
      GLEW_NV_path_rendering_shared_edge
      GLEW_NV_pixel_data_range
      GLEW_NV_point_sprite
      GLEW_NV_present_video
      GLEW_NV_primitive_restart
      GLEW_NV_register_combiners
      GLEW_NV_register_combiners2
      GLEW_NV_robustness_video_memory_purge
      GLEW_NV_sample_locations
      GLEW_NV_sample_mask_override_coverage
      GLEW_NV_shader_atomic_counters
      GLEW_NV_shader_atomic_float
      GLEW_NV_shader_atomic_float64
      GLEW_NV_shader_atomic_fp16_vector
      GLEW_NV_shader_atomic_int64
      GLEW_NV_shader_buffer_load
      GLEW_NV_shader_storage_buffer_object
      GLEW_NV_shader_thread_group
      GLEW_NV_shader_thread_shuffle
      GLEW_NV_stereo_view_rendering
      GLEW_NV_tessellation_program5
      GLEW_NV_texgen_emboss
      GLEW_NV_texgen_reflection
      GLEW_NV_texture_barrier
      GLEW_NV_texture_compression_vtc
      GLEW_NV_texture_env_combine4
      GLEW_NV_texture_expand_normal
      GLEW_NV_texture_multisample
      GLEW_NV_texture_rectangle
      GLEW_NV_texture_shader
      GLEW_NV_texture_shader2
      GLEW_NV_texture_shader3
      GLEW_NV_transform_feedback
      GLEW_NV_transform_feedback2
      GLEW_NV_uniform_buffer_unified_memory
      GLEW_NV_vdpau_interop
      GLEW_NV_vertex_array_range
      GLEW_NV_vertex_array_range2
      GLEW_NV_vertex_attrib_integer_64bit
      GLEW_NV_vertex_buffer_unified_memory
      GLEW_NV_vertex_program
      GLEW_NV_vertex_program1_1
      GLEW_NV_vertex_program2
      GLEW_NV_vertex_program2_option
      GLEW_NV_vertex_program3
      GLEW_NV_vertex_program4
      GLEW_NV_video_capture
      GLEW_NV_viewport_array2
      GLEW_NV_viewport_swizzle
      GLEW_OES_byte_coordinates
      GLEW_OES_compressed_paletted_texture
      GLEW_OES_read_format
      GLEW_OES_single_precision
      GLEW_OML_interlace
      GLEW_OML_resample
      GLEW_OML_subsample
      GLEW_OVR_multiview
      GLEW_OVR_multiview2
      GLEW_PGI_misc_hints
      GLEW_PGI_vertex_hints
      GLEW_REGAL_ES1_0_compatibility
      GLEW_REGAL_ES1_1_compatibility
      GLEW_REGAL_enable
      GLEW_REGAL_error_string
      GLEW_REGAL_extension_query
      GLEW_REGAL_log
      GLEW_REGAL_proc_address
      GLEW_REND_screen_coordinates
      GLEW_S3_s3tc
      GLEW_SGIS_color_range
      GLEW_SGIS_detail_texture
      GLEW_SGIS_fog_function
      GLEW_SGIS_generate_mipmap
      GLEW_SGIS_multisample
      GLEW_SGIS_pixel_texture
      GLEW_SGIS_point_line_texgen
      GLEW_SGIS_sharpen_texture
      GLEW_SGIS_texture4D
      GLEW_SGIS_texture_border_clamp
      GLEW_SGIS_texture_edge_clamp
      GLEW_SGIS_texture_filter4
      GLEW_SGIS_texture_lod
      GLEW_SGIS_texture_select
      GLEW_SGIX_async
      GLEW_SGIX_async_histogram
      GLEW_SGIX_async_pixel
      GLEW_SGIX_blend_alpha_minmax
      GLEW_SGIX_clipmap
      GLEW_SGIX_convolution_accuracy
      GLEW_SGIX_depth_texture
      GLEW_SGIX_flush_raster
      GLEW_SGIX_fog_offset
      GLEW_SGIX_fog_texture
      GLEW_SGIX_fragment_specular_lighting
      GLEW_SGIX_framezoom
      GLEW_SGIX_interlace
      GLEW_SGIX_ir_instrument1
      GLEW_SGIX_list_priority
      GLEW_SGIX_pixel_texture
      GLEW_SGIX_pixel_texture_bits
      GLEW_SGIX_reference_plane
      GLEW_SGIX_resample
      GLEW_SGIX_shadow
      GLEW_SGIX_shadow_ambient
      GLEW_SGIX_sprite
      GLEW_SGIX_tag_sample_buffer
      GLEW_SGIX_texture_add_env
      GLEW_SGIX_texture_coordinate_clamp
      GLEW_SGIX_texture_lod_bias
      GLEW_SGIX_texture_multi_buffer
      GLEW_SGIX_texture_range
      GLEW_SGIX_texture_scale_bias
      GLEW_SGIX_vertex_preclip
      GLEW_SGIX_vertex_preclip_hint
      GLEW_SGIX_ycrcb
      GLEW_SGI_color_matrix
      GLEW_SGI_color_table
      GLEW_SGI_texture_color_table
      GLEW_SUNX_constant_data
      GLEW_SUN_convolution_border_modes
      GLEW_SUN_global_alpha
      GLEW_SUN_mesh_array
      GLEW_SUN_read_video_pixels
      GLEW_SUN_slice_accum
      GLEW_SUN_triangle_list
      GLEW_SUN_vertex
      GLEW_VERSION_1_1
      GLEW_VERSION_1_2
      GLEW_VERSION_1_2_1
      GLEW_VERSION_1_3
      GLEW_VERSION_1_4
      GLEW_VERSION_1_5
      GLEW_VERSION_2_0
      GLEW_VERSION_2_1
      GLEW_VERSION_3_0
      GLEW_VERSION_3_1
      GLEW_VERSION_3_2
      GLEW_VERSION_3_3
      GLEW_VERSION_4_0
      GLEW_VERSION_4_1
      GLEW_VERSION_4_2
      GLEW_VERSION_4_3
      GLEW_VERSION_4_4
      GLEW_VERSION_4_5
      GLEW_WIN_phong_shading
      GLEW_WIN_specular_fog
      GLEW_WIN_swap_hint
      glExecuteProgramNV_c
      glExtractComponentEXT
      glFeedbackBuffer_c
      glFenceSync
      glFinalCombinerInputNV
      glFinish
      glFinishAsyncSGIX_c
      glFinishFenceAPPLE
      glFinishFenceNV
      glFinishObjectAPPLE
      glFinishTextureSUNX
      glFlush
      glFlushMappedBufferRange
      glFlushMappedBufferRangeAPPLE
      glFlushMappedNamedBufferRange
      glFlushMappedNamedBufferRangeEXT
      glFlushPixelDataRangeNV
      glFlushRasterSGIX
      glFlushVertexArrayRangeAPPLE_c
      glFlushVertexArrayRangeNV
      glFogCoordd
      glFogCoorddEXT
      glFogCoorddv_c
      glFogCoorddvEXT_c
      glFogCoordf
      glFogCoordfEXT
      glFogCoordFormatNV
      glFogCoordfv_c
      glFogCoordfvEXT_c
      glFogCoordhNV
      glFogCoordhvNV_c
      glFogCoordPointer_c
      glFogCoordPointerEXT_c
      glFogCoordPointerListIBM_c
      glFogf
      glFogFuncSGIS_c
      glFogfv_c
      glFogi
      glFogiv_c
      glFogx
      glFogxv_c
      glFragmentColorMaterialEXT
      glFragmentColorMaterialSGIX
      glFragmentCoverageColorNV
      glFragmentLightfEXT
      glFragmentLightfSGIX
      glFragmentLightfvEXT_c
      glFragmentLightfvSGIX_c
      glFragmentLightiEXT
      glFragmentLightiSGIX
      glFragmentLightivEXT_c
      glFragmentLightivSGIX_c
      glFragmentLightModelfEXT
      glFragmentLightModelfSGIX
      glFragmentLightModelfvEXT_c
      glFragmentLightModelfvSGIX_c
      glFragmentLightModeliEXT
      glFragmentLightModeliSGIX
      glFragmentLightModelivEXT_c
      glFragmentLightModelivSGIX_c
      glFragmentMaterialfEXT
      glFragmentMaterialfSGIX
      glFragmentMaterialfvEXT_c
      glFragmentMaterialfvSGIX_c
      glFragmentMaterialiEXT
      glFragmentMaterialiSGIX
      glFragmentMaterialivEXT_c
      glFragmentMaterialivSGIX_c
      glFramebufferDrawBufferEXT
      glFramebufferDrawBuffersEXT_c
      glFramebufferParameteri
      glFramebufferReadBufferEXT
      glFramebufferRenderbuffer
      glFramebufferRenderbufferEXT
      glFramebufferSampleLocationsfvARB_c
      glFramebufferSampleLocationsfvNV_c
      glFramebufferTexture
      glFramebufferTexture1D
      glFramebufferTexture1DEXT
      glFramebufferTexture2D
      glFramebufferTexture2DEXT
      glFramebufferTexture3D
      glFramebufferTexture3DEXT
      glFramebufferTextureARB
      glFramebufferTextureEXT
      glFramebufferTextureFaceARB
      glFramebufferTextureFaceEXT
      glFramebufferTextureLayer
      glFramebufferTextureLayerARB
      glFramebufferTextureLayerEXT
      glFramebufferTextureMultiviewOVR
      glFrameTerminatorGREMEDY
      glFrameZoomSGIX
      glFreeObjectBufferATI
      glFrontFace
      glFrustum
      glFrustumf
      glFrustumfOES
      glFrustumx
      glGenAsyncMarkersSGIX
      glGenBuffers_c
      glGenBuffersARB_c
      glGenerateMipmap
      glGenerateMipmapEXT
      glGenerateMultiTexMipmapEXT
      glGenerateTextureMipmap
      glGenerateTextureMipmapEXT
      glGenFencesAPPLE_c
      glGenFencesNV_c
      glGenFragmentShadersATI
      glGenFramebuffers_c
      glGenFramebuffersEXT_c
      glGenLists
      glGenNamesAMD_c
      glGenOcclusionQueriesNV_c
      glGenPathsNV
      glGenPerfMonitorsAMD_c
      glGenProgramPipelines_c
      glGenProgramsARB_c
      glGenProgramsNV_c
      glGenQueries_c
      glGenQueriesANGLE_c
      glGenQueriesARB_c
      glGenRenderbuffers_c
      glGenRenderbuffersEXT_c
      glGenSamplers_c
      glGenSymbolsEXT
      glGenTextures_c
      glGenTexturesEXT_c
      glGenTransformFeedbacks_c
      glGenTransformFeedbacksNV_c
      glGenVertexArrays_c
      glGenVertexArraysAPPLE_c
      glGenVertexShadersEXT
      glGetActiveAtomicCounterBufferiv_c
      glGetActiveAttrib_c
      glGetActiveAttribARB_c
      glGetActiveSubroutineName_c
      glGetActiveSubroutineUniformiv_c
      glGetActiveSubroutineUniformName_c
      glGetActiveUniform_c
      glGetActiveUniformARB_c
      glGetActiveUniformBlockiv_c
      glGetActiveUniformBlockName_c
      glGetActiveUniformName_c
      glGetActiveUniformsiv_c
      glGetActiveVaryingNV_c
      glGetArrayObjectfvATI_c
      glGetArrayObjectivATI_c
      glGetAttachedObjectsARB_c
      glGetAttachedShaders_c
      glGetAttribLocation_c
      glGetAttribLocationARB_c
      glGetBooleanIndexedvEXT_c
      glGetBooleani_v_c
      glGetBooleanv_c
      glGetBufferParameteri64v_c
      glGetBufferParameteriv_c
      glGetBufferParameterivARB_c
      glGetBufferParameterui64vNV_c
      glGetBufferPointerv_c
      glGetBufferPointervARB_c
      glGetBufferSubData_c
      glGetBufferSubDataARB_c
      glGetClipPlane_c
      glGetClipPlanef_c
      glGetClipPlanefOES_c
      glGetClipPlanex_c
      glGetColorTable_c
      glGetColorTableEXT_c
      glGetColorTableParameterfv_c
      glGetColorTableParameterfvEXT_c
      glGetColorTableParameterfvSGI_c
      glGetColorTableParameteriv_c
      glGetColorTableParameterivEXT_c
      glGetColorTableParameterivSGI_c
      glGetColorTableSGI_c
      glGetCombinerInputParameterfvNV_c
      glGetCombinerInputParameterivNV_c
      glGetCombinerOutputParameterfvNV_c
      glGetCombinerOutputParameterivNV_c
      glGetCombinerStageParameterfvNV_c
      glGetCommandHeaderNV
      glGetCompressedMultiTexImageEXT_c
      glGetCompressedTexImage_c
      glGetCompressedTexImageARB_c
      glGetCompressedTextureImage_c
      glGetCompressedTextureImageEXT_c
      glGetCompressedTextureSubImage_c
      glGetConvolutionFilter_c
      glGetConvolutionFilterEXT_c
      glGetConvolutionParameterfv_c
      glGetConvolutionParameterfvEXT_c
      glGetConvolutionParameteriv_c
      glGetConvolutionParameterivEXT_c
      glGetCoverageModulationTableNV_c
      glGetDebugMessageLog_c
      glGetDebugMessageLogAMD_c
      glGetDebugMessageLogARB_c
      glGetDetailTexFuncSGIS_c
      glGetDoubleIndexedvEXT_c
      glGetDoublei_v_c
      glGetDoublei_vEXT_c
      glGetDoublev_c
      glGetError
      glGetExtensionREGAL_c
      glGetFenceivNV_c
      glGetFinalCombinerInputParameterfvNV_c
      glGetFinalCombinerInputParameterivNV_c
      glGetFirstPerfQueryIdINTEL_c
      glGetFixedv_c
      glGetFloatIndexedvEXT_c
      glGetFloati_v_c
      glGetFloati_vEXT_c
      glGetFloatv_c
      glGetFogFuncSGIS_c
      glGetFragDataIndex_c
      glGetFragDataLocation_c
      glGetFragDataLocationEXT_c
      glGetFragmentLightfvEXT_c
      glGetFragmentLightfvSGIX_c
      glGetFragmentLightivEXT_c
      glGetFragmentLightivSGIX_c
      glGetFragmentMaterialfvEXT_c
      glGetFragmentMaterialfvSGIX_c
      glGetFragmentMaterialivEXT_c
      glGetFragmentMaterialivSGIX_c
      glGetFramebufferAttachmentParameteriv_c
      glGetFramebufferAttachmentParameterivEXT_c
      glGetFramebufferParameteriv_c
      glGetFramebufferParameterivEXT_c
      glGetGraphicsResetStatus
      glGetGraphicsResetStatusARB
      glGetHandleARB
      glGetHistogram_c
      glGetHistogramEXT_c
      glGetHistogramParameterfv_c
      glGetHistogramParameterfvEXT_c
      glGetHistogramParameteriv_c
      glGetHistogramParameterivEXT_c
      glGetImageHandleARB
      glGetImageHandleNV
      glGetImageTransformParameterfvHP_c
      glGetImageTransformParameterivHP_c
      glGetInfoLogARB_c
      glGetInteger64i_v_c
      glGetInteger64v_c
      glGetIntegerIndexedvEXT_c
      glGetIntegeri_v_c
      glGetIntegerui64i_vNV_c
      glGetIntegerui64vNV_c
      glGetIntegerv_c
      glGetInternalformati64v_c
      glGetInternalformativ_c
      glGetInternalformatSampleivNV_c
      glGetInvariantBooleanvEXT_c
      glGetInvariantFloatvEXT_c
      glGetInvariantIntegervEXT_c
      glGetLightfv_c
      glGetLightiv_c
      glGetLightxv_c
      glGetLocalConstantBooleanvEXT_c
      glGetLocalConstantFloatvEXT_c
      glGetLocalConstantIntegervEXT_c
      glGetMapAttribParameterfvNV_c
      glGetMapAttribParameterivNV_c
      glGetMapControlPointsNV_c
      glGetMapdv_c
      glGetMapfv_c
      glGetMapiv_c
      glGetMapParameterfvNV_c
      glGetMapParameterivNV_c
      glGetMaterialfv_c
      glGetMaterialiv_c
      glGetMaterialxv_c
      glGetMinmax_c
      glGetMinmaxEXT_c
      glGetMinmaxParameterfv_c
      glGetMinmaxParameterfvEXT_c
      glGetMinmaxParameteriv_c
      glGetMinmaxParameterivEXT_c
      glGetMultisamplefv_c
      glGetMultisamplefvNV_c
      glGetMultiTexEnvfvEXT_c
      glGetMultiTexEnvivEXT_c
      glGetMultiTexGendvEXT_c
      glGetMultiTexGenfvEXT_c
      glGetMultiTexGenivEXT_c
      glGetMultiTexImageEXT_c
      glGetMultiTexLevelParameterfvEXT_c
      glGetMultiTexLevelParameterivEXT_c
      glGetMultiTexParameterfvEXT_c
      glGetMultiTexParameterIivEXT_c
      glGetMultiTexParameterIuivEXT_c
      glGetMultiTexParameterivEXT_c
      glGetNamedBufferParameteri64v_c
      glGetNamedBufferParameteriv_c
      glGetNamedBufferParameterivEXT_c
      glGetNamedBufferParameterui64vNV_c
      glGetNamedBufferPointerv_c
      glGetNamedBufferPointervEXT_c
      glGetNamedBufferSubData_c
      glGetNamedBufferSubDataEXT_c
      glGetNamedFramebufferAttachmentParameteriv_c
      glGetNamedFramebufferAttachmentParameterivEXT_c
      glGetNamedFramebufferParameteriv_c
      glGetNamedFramebufferParameterivEXT_c
      glGetNamedProgramivEXT_c
      glGetNamedProgramLocalParameterdvEXT_c
      glGetNamedProgramLocalParameterfvEXT_c
      glGetNamedProgramLocalParameterIivEXT_c
      glGetNamedProgramLocalParameterIuivEXT_c
      glGetNamedProgramStringEXT_c
      glGetNamedRenderbufferParameteriv_c
      glGetNamedRenderbufferParameterivEXT_c
      glGetNamedStringARB_c
      glGetNamedStringivARB_c
      glGetnColorTableARB_c
      glGetnCompressedTexImage_c
      glGetnCompressedTexImageARB_c
      glGetnConvolutionFilterARB_c
      glGetNextPerfQueryIdINTEL_c
      glGetnHistogramARB_c
      glGetnMapdvARB_c
      glGetnMapfvARB_c
      glGetnMapivARB_c
      glGetnMinmaxARB_c
      glGetnPixelMapfvARB_c
      glGetnPixelMapuivARB_c
      glGetnPixelMapusvARB_c
      glGetnPolygonStippleARB_c
      glGetnSeparableFilterARB_c
      glGetnTexImage_c
      glGetnTexImageARB_c
      glGetnUniformdv_c
      glGetnUniformdvARB_c
      glGetnUniformfv_c
      glGetnUniformfvARB_c
      glGetnUniformi64vARB_c
      glGetnUniformiv_c
      glGetnUniformivARB_c
      glGetnUniformui64vARB_c
      glGetnUniformuiv_c
      glGetnUniformuivARB_c
      glGetObjectBufferfvATI_c
      glGetObjectBufferivATI_c
      glGetObjectLabel_c
      glGetObjectLabelEXT_c
      glGetObjectParameterfvARB_c
      glGetObjectParameterivAPPLE_c
      glGetObjectParameterivARB_c
      glGetObjectPtrLabel_c
      glGetOcclusionQueryivNV_c
      glGetOcclusionQueryuivNV_c
      glGetPathColorGenfvNV_c
      glGetPathColorGenivNV_c
      glGetPathCommandsNV_c
      glGetPathCoordsNV_c
      glGetPathDashArrayNV_c
      glGetPathLengthNV
      glGetPathMetricRangeNV_c
      glGetPathMetricsNV_c
      glGetPathParameterfvNV_c
      glGetPathParameterivNV_c
      glGetPathSpacingNV_c
      glGetPathTexGenfvNV_c
      glGetPathTexGenivNV_c
      glGetPerfCounterInfoINTEL_c
      glGetPerfMonitorCounterDataAMD_c
      glGetPerfMonitorCounterInfoAMD_c
      glGetPerfMonitorCountersAMD_c
      glGetPerfMonitorCounterStringAMD_c
      glGetPerfMonitorGroupsAMD_c
      glGetPerfMonitorGroupStringAMD_c
      glGetPerfQueryDataINTEL_c
      glGetPerfQueryIdByNameINTEL_c
      glGetPerfQueryInfoINTEL_c
      glGetPixelMapfv_c
      glGetPixelMapuiv_c
      glGetPixelMapusv_c
      glGetPixelTransformParameterfvEXT_c
      glGetPixelTransformParameterivEXT_c
      glGetPointerIndexedvEXT_c
      glGetPointeri_vEXT_c
      glGetPointerv_c
      glGetPolygonStipple_c
      glGetProcAddressREGAL_c
      glGetProgramBinary_c
      glGetProgramEnvParameterdvARB_c
      glGetProgramEnvParameterfvARB_c
      glGetProgramInfoLog_c
      glGetProgramInterfaceiv_c
      glGetProgramiv_c
      glGetProgramivARB_c
      glGetProgramivNV_c
      glGetProgramLocalParameterdvARB_c
      glGetProgramLocalParameterfvARB_c
      glGetProgramNamedParameterdvNV_c
      glGetProgramNamedParameterfvNV_c
      glGetProgramParameterdvNV_c
      glGetProgramParameterfvNV_c
      glGetProgramPipelineInfoLog_c
      glGetProgramPipelineiv_c
      glGetProgramResourcefvNV_c
      glGetProgramResourceIndex_c
      glGetProgramResourceiv_c
      glGetProgramResourceLocation_c
      glGetProgramResourceLocationIndex_c
      glGetProgramResourceName_c
      glGetProgramStageiv_c
      glGetProgramStringARB_c
      glGetProgramStringNV_c
      glGetQueryBufferObjecti64v
      glGetQueryBufferObjectiv
      glGetQueryBufferObjectui64v
      glGetQueryBufferObjectuiv
      glGetQueryIndexediv_c
      glGetQueryiv_c
      glGetQueryivANGLE_c
      glGetQueryivARB_c
      glGetQueryObjecti64v_c
      glGetQueryObjecti64vANGLE_c
      glGetQueryObjecti64vEXT_c
      glGetQueryObjectiv_c
      glGetQueryObjectivANGLE_c
      glGetQueryObjectivARB_c
      glGetQueryObjectui64v_c
      glGetQueryObjectui64vANGLE_c
      glGetQueryObjectui64vEXT_c
      glGetQueryObjectuiv_c
      glGetQueryObjectuivANGLE_c
      glGetQueryObjectuivARB_c
      glGetRenderbufferParameteriv_c
      glGetRenderbufferParameterivEXT_c
      glGetSamplerParameterfv_c
      glGetSamplerParameterIiv_c
      glGetSamplerParameterIuiv_c
      glGetSamplerParameteriv_c
      glGetSeparableFilter_c
      glGetSeparableFilterEXT_c
      glGetShaderInfoLog_c
      glGetShaderiv_c
      glGetShaderPrecisionFormat_c
      glGetShaderSource_c
      glGetShaderSourceARB_c
      glGetSharpenTexFuncSGIS_c
      glGetStageIndexNV
      glGetSubroutineIndex_c
      glGetSubroutineUniformLocation_c
      glGetSynciv_c
      glGetTexBumpParameterfvATI_c
      glGetTexBumpParameterivATI_c
      glGetTexEnvfv_c
      glGetTexEnviv_c
      glGetTexEnvxv_c
      glGetTexFilterFuncSGIS_c
      glGetTexGendv_c
      glGetTexGenfv_c
      glGetTexGeniv_c
      glGetTexImage_c
      glGetTexLevelParameterfv_c
      glGetTexLevelParameteriv_c
      glGetTexParameterfv_c
      glGetTexParameterIiv_c
      glGetTexParameterIivEXT_c
      glGetTexParameterIuiv_c
      glGetTexParameterIuivEXT_c
      glGetTexParameteriv_c
      glGetTexParameterPointervAPPLE_c
      glGetTexParameterxv_c
      glGetTextureHandleARB
      glGetTextureHandleNV
      glGetTextureImage_c
      glGetTextureImageEXT_c
      glGetTextureLevelParameterfv_c
      glGetTextureLevelParameterfvEXT_c
      glGetTextureLevelParameteriv_c
      glGetTextureLevelParameterivEXT_c
      glGetTextureParameterfv_c
      glGetTextureParameterfvEXT_c
      glGetTextureParameterIiv_c
      glGetTextureParameterIivEXT_c
      glGetTextureParameterIuiv_c
      glGetTextureParameterIuivEXT_c
      glGetTextureParameteriv_c
      glGetTextureParameterivEXT_c
      glGetTextureSamplerHandleARB
      glGetTextureSamplerHandleNV
      glGetTextureSubImage_c
      glGetTrackMatrixivNV_c
      glGetTransformFeedbacki64_v_c
      glGetTransformFeedbackiv_c
      glGetTransformFeedbacki_v_c
      glGetTransformFeedbackVarying_c
      glGetTransformFeedbackVaryingEXT_c
      glGetTransformFeedbackVaryingNV_c
      glGetTranslatedShaderSourceANGLE_c
      glGetUniformBlockIndex_c
      glGetUniformBufferSizeEXT
      glGetUniformdv_c
      glGetUniformfv_c
      glGetUniformfvARB_c
      glGetUniformi64vARB_c
      glGetUniformi64vNV_c
      glGetUniformIndices_c
      glGetUniformiv_c
      glGetUniformivARB_c
      glGetUniformLocation_c
      glGetUniformLocationARB_c
      glGetUniformOffsetEXT
      glGetUniformSubroutineuiv_c
      glGetUniformui64vARB_c
      glGetUniformui64vNV_c
      glGetUniformuiv_c
      glGetUniformuivEXT_c
      glGetVariantArrayObjectfvATI_c
      glGetVariantArrayObjectivATI_c
      glGetVariantBooleanvEXT_c
      glGetVariantFloatvEXT_c
      glGetVariantIntegervEXT_c
      glGetVariantPointervEXT_c
      glGetVaryingLocationNV_c
      glGetVertexArrayIndexed64iv_c
      glGetVertexArrayIndexediv_c
      glGetVertexArrayIntegeri_vEXT_c
      glGetVertexArrayIntegervEXT_c
      glGetVertexArrayiv_c
      glGetVertexArrayPointeri_vEXT_c
      glGetVertexArrayPointervEXT_c
      glGetVertexAttribArrayObjectfvATI_c
      glGetVertexAttribArrayObjectivATI_c
      glGetVertexAttribdv_c
      glGetVertexAttribdvARB_c
      glGetVertexAttribdvNV_c
      glGetVertexAttribfv_c
      glGetVertexAttribfvARB_c
      glGetVertexAttribfvNV_c
      glGetVertexAttribIiv_c
      glGetVertexAttribIivEXT_c
      glGetVertexAttribIuiv_c
      glGetVertexAttribIuivEXT_c
      glGetVertexAttribiv_c
      glGetVertexAttribivARB_c
      glGetVertexAttribivNV_c
      glGetVertexAttribLdv_c
      glGetVertexAttribLdvEXT_c
      glGetVertexAttribLi64vNV_c
      glGetVertexAttribLui64vARB_c
      glGetVertexAttribLui64vNV_c
      glGetVertexAttribPointerv_c
      glGetVertexAttribPointervARB_c
      glGetVertexAttribPointervNV_c
      glGetVideoCaptureivNV_c
      glGetVideoCaptureStreamdvNV_c
      glGetVideoCaptureStreamfvNV_c
      glGetVideoCaptureStreamivNV_c
      glGetVideoi64vNV_c
      glGetVideoivNV_c
      glGetVideoui64vNV_c
      glGetVideouivNV_c
      glGetVkProcAddrNV_c
      glGlobalAlphaFactorbSUN
      glGlobalAlphaFactordSUN
      glGlobalAlphaFactorfSUN
      glGlobalAlphaFactoriSUN
      glGlobalAlphaFactorsSUN
      glGlobalAlphaFactorubSUN
      glGlobalAlphaFactoruiSUN
      glGlobalAlphaFactorusSUN
      glHint
      glHistogram
      glHistogramEXT
      glImageTransformParameterfHP
      glImageTransformParameterfvHP_c
      glImageTransformParameteriHP
      glImageTransformParameterivHP_c
      glImportSyncEXT
      glIndexd
      glIndexdv_c
      glIndexf
      glIndexFormatNV
      glIndexFuncEXT
      glIndexfv_c
      glIndexi
      glIndexiv_c
      glIndexMask
      glIndexMaterialEXT
      glIndexPointer_c
      glIndexPointerEXT_c
      glIndexPointerListIBM_c
      glIndexs
      glIndexsv_c
      glIndexub
      glIndexubv_c
      glInitNames
      glInsertComponentEXT
      glInsertEventMarkerEXT_c
      glInterleavedArrays_c
      glInterpolatePathsNV
      glInvalidateBufferData
      glInvalidateBufferSubData
      glInvalidateFramebuffer_c
      glInvalidateNamedFramebufferData_c
      glInvalidateNamedFramebufferSubData_c
      glInvalidateSubFramebuffer_c
      glInvalidateTexImage
      glInvalidateTexSubImage
      glIsAsyncMarkerSGIX
      glIsBuffer
      glIsBufferARB
      glIsBufferResidentNV
      glIsCommandListNV
      glIsEnabled
      glIsEnabledi
      glIsEnabledIndexedEXT
      glIsFenceAPPLE
      glIsFenceNV
      glIsFramebuffer
      glIsFramebufferEXT
      glIsImageHandleResidentARB
      glIsImageHandleResidentNV
      glIsList
      glIsNameAMD
      glIsNamedBufferResidentNV
      glIsNamedStringARB_c
      glIsObjectBufferATI
      glIsOcclusionQueryNV
      glIsPathNV
      glIsPointInFillPathNV
      glIsPointInStrokePathNV
      glIsProgram
      glIsProgramARB
      glIsProgramNV
      glIsProgramPipeline
      glIsQuery
      glIsQueryANGLE
      glIsQueryARB
      glIsRenderbuffer
      glIsRenderbufferEXT
      glIsSampler
      glIsShader
      glIsStateNV
      glIsSupportedREGAL_c
      glIsSync
      glIsTexture
      glIsTextureEXT
      glIsTextureHandleResidentARB
      glIsTextureHandleResidentNV
      glIsTransformFeedback
      glIsTransformFeedbackNV
      glIsVariantEnabledEXT
      glIsVertexArray
      glIsVertexArrayAPPLE
      glIsVertexAttribEnabledAPPLE
      glLabelObjectEXT_c
      glLGPUCopyImageSubDataNVX
      glLGPUInterlockNVX
      glLGPUNamedBufferSubDataNVX_c
      glLightEnviEXT
      glLightf
      glLightfv_c
      glLighti
      glLightiv_c
      glLightModelf
      glLightModelfv_c
      glLightModeli
      glLightModeliv_c
      glLightModelx
      glLightModelxv_c
      glLightx
      glLightxv_c
      glLineStipple
      glLineWidth
      glLineWidthx
      glLinkProgram
      glLinkProgramARB
      glListBase
      glListDrawCommandsStatesClientNV_c
      glLoadIdentity
      glLoadMatrixd_c
      glLoadMatrixf_c
      glLoadMatrixx_c
      glLoadName
      glLoadProgramNV_c
      glLoadTransposeMatrixd_c
      glLoadTransposeMatrixdARB_c
      glLoadTransposeMatrixf_c
      glLoadTransposeMatrixfARB_c
      glLockArraysEXT
      glLogicOp
      glLogMessageCallbackREGAL
      glMakeBufferNonResidentNV
      glMakeBufferResidentNV
      glMakeImageHandleNonResidentARB
      glMakeImageHandleNonResidentNV
      glMakeImageHandleResidentARB
      glMakeImageHandleResidentNV
      glMakeNamedBufferNonResidentNV
      glMakeNamedBufferResidentNV
      glMakeTextureHandleNonResidentARB
      glMakeTextureHandleNonResidentNV
      glMakeTextureHandleResidentARB
      glMakeTextureHandleResidentNV
      glMap1d_c
      glMap1f_c
      glMap2d_c
      glMap2f_c
      glMapBuffer_c
      glMapBufferARB_c
      glMapBufferRange_c
      glMapControlPointsNV_c
      glMapGrid1d
      glMapGrid1f
      glMapGrid2d
      glMapGrid2f
      glMapNamedBuffer_c
      glMapNamedBufferEXT_c
      glMapNamedBufferRange_c
      glMapNamedBufferRangeEXT_c
      glMapObjectBufferATI_c
      glMapParameterfvNV_c
      glMapParameterivNV_c
      glMapTexture2DINTEL_c
      glMapVertexAttrib1dAPPLE_c
      glMapVertexAttrib1fAPPLE_c
      glMapVertexAttrib2dAPPLE_c
      glMapVertexAttrib2fAPPLE_c
      glMaterialf
      glMaterialfv_c
      glMateriali
      glMaterialiv_c
      glMaterialx
      glMaterialxv_c
      glMatrixFrustumEXT
      glMatrixIndexPointerARB_c
      glMatrixIndexubvARB_c
      glMatrixIndexuivARB_c
      glMatrixIndexusvARB_c
      glMatrixLoad3x2fNV_c
      glMatrixLoad3x3fNV_c
      glMatrixLoaddEXT_c
      glMatrixLoadfEXT_c
      glMatrixLoadIdentityEXT
      glMatrixLoadTranspose3x3fNV_c
      glMatrixLoadTransposedEXT_c
      glMatrixLoadTransposefEXT_c
      glMatrixMode
      glMatrixMult3x2fNV_c
      glMatrixMult3x3fNV_c
      glMatrixMultdEXT_c
      glMatrixMultfEXT_c
      glMatrixMultTranspose3x3fNV_c
      glMatrixMultTransposedEXT_c
      glMatrixMultTransposefEXT_c
      glMatrixOrthoEXT
      glMatrixPopEXT
      glMatrixPushEXT
      glMatrixRotatedEXT
      glMatrixRotatefEXT
      glMatrixScaledEXT
      glMatrixScalefEXT
      glMatrixTranslatedEXT
      glMatrixTranslatefEXT
      glMaxShaderCompilerThreadsARB
      glMemoryBarrier
      glMemoryBarrierByRegion
      glMemoryBarrierEXT
      glMinmax
      glMinmaxEXT
      glMinSampleShading
      glMinSampleShadingARB
      glMulticastBarrierNV
      glMulticastBlitFramebufferNV
      glMulticastBufferSubDataNV_c
      glMulticastCopyBufferSubDataNV
      glMulticastCopyImageSubDataNV
      glMulticastFramebufferSampleLocationsfvNV_c
      glMulticastGetQueryObjecti64vNV_c
      glMulticastGetQueryObjectivNV_c
      glMulticastGetQueryObjectui64vNV_c
      glMulticastGetQueryObjectuivNV_c
      glMulticastWaitSyncNV
      glMultiDrawArrays_c
      glMultiDrawArraysEXT_c
      glMultiDrawArraysIndirect_c
      glMultiDrawArraysIndirectAMD_c
      glMultiDrawArraysIndirectBindlessCountNV_c
      glMultiDrawArraysIndirectBindlessNV_c
      glMultiDrawArraysIndirectCountARB_c
      glMultiDrawElementArrayAPPLE_c
      glMultiDrawElements_c
      glMultiDrawElementsBaseVertex_c
      glMultiDrawElementsEXT_c
      glMultiDrawElementsIndirect_c
      glMultiDrawElementsIndirectAMD_c
      glMultiDrawElementsIndirectBindlessCountNV_c
      glMultiDrawElementsIndirectBindlessNV_c
      glMultiDrawElementsIndirectCountARB_c
      glMultiDrawRangeElementArrayAPPLE_c
      glMultiModeDrawArraysIBM_c
      glMultiModeDrawElementsIBM_c
      glMultiTexBufferEXT
      glMultiTexCoord1d
      glMultiTexCoord1dARB
      glMultiTexCoord1dv_c
      glMultiTexCoord1dvARB_c
      glMultiTexCoord1f
      glMultiTexCoord1fARB
      glMultiTexCoord1fv_c
      glMultiTexCoord1fvARB_c
      glMultiTexCoord1hNV
      glMultiTexCoord1hvNV_c
      glMultiTexCoord1i
      glMultiTexCoord1iARB
      glMultiTexCoord1iv_c
      glMultiTexCoord1ivARB_c
      glMultiTexCoord1s
      glMultiTexCoord1sARB
      glMultiTexCoord1sv_c
      glMultiTexCoord1svARB_c
      glMultiTexCoord2d
      glMultiTexCoord2dARB
      glMultiTexCoord2dv_c
      glMultiTexCoord2dvARB_c
      glMultiTexCoord2f
      glMultiTexCoord2fARB
      glMultiTexCoord2fv_c
      glMultiTexCoord2fvARB_c
      glMultiTexCoord2hNV
      glMultiTexCoord2hvNV_c
      glMultiTexCoord2i
      glMultiTexCoord2iARB
      glMultiTexCoord2iv_c
      glMultiTexCoord2ivARB_c
      glMultiTexCoord2s
      glMultiTexCoord2sARB
      glMultiTexCoord2sv_c
      glMultiTexCoord2svARB_c
      glMultiTexCoord3d
      glMultiTexCoord3dARB
      glMultiTexCoord3dv_c
      glMultiTexCoord3dvARB_c
      glMultiTexCoord3f
      glMultiTexCoord3fARB
      glMultiTexCoord3fv_c
      glMultiTexCoord3fvARB_c
      glMultiTexCoord3hNV
      glMultiTexCoord3hvNV_c
      glMultiTexCoord3i
      glMultiTexCoord3iARB
      glMultiTexCoord3iv_c
      glMultiTexCoord3ivARB_c
      glMultiTexCoord3s
      glMultiTexCoord3sARB
      glMultiTexCoord3sv_c
      glMultiTexCoord3svARB_c
      glMultiTexCoord4d
      glMultiTexCoord4dARB
      glMultiTexCoord4dv_c
      glMultiTexCoord4dvARB_c
      glMultiTexCoord4f
      glMultiTexCoord4fARB
      glMultiTexCoord4fv_c
      glMultiTexCoord4fvARB_c
      glMultiTexCoord4hNV
      glMultiTexCoord4hvNV_c
      glMultiTexCoord4i
      glMultiTexCoord4iARB
      glMultiTexCoord4iv_c
      glMultiTexCoord4ivARB_c
      glMultiTexCoord4s
      glMultiTexCoord4sARB
      glMultiTexCoord4sv_c
      glMultiTexCoord4svARB_c
      glMultiTexCoord4x
      glMultiTexCoordP1ui
      glMultiTexCoordP1uiv_c
      glMultiTexCoordP2ui
      glMultiTexCoordP2uiv_c
      glMultiTexCoordP3ui
      glMultiTexCoordP3uiv_c
      glMultiTexCoordP4ui
      glMultiTexCoordP4uiv_c
      glMultiTexCoordPointerEXT_c
      glMultiTexEnvfEXT
      glMultiTexEnvfvEXT_c
      glMultiTexEnviEXT
      glMultiTexEnvivEXT_c
      glMultiTexGendEXT
      glMultiTexGendvEXT_c
      glMultiTexGenfEXT
      glMultiTexGenfvEXT_c
      glMultiTexGeniEXT
      glMultiTexGenivEXT_c
      glMultiTexImage1DEXT_c
      glMultiTexImage2DEXT_c
      glMultiTexImage3DEXT_c
      glMultiTexParameterfEXT
      glMultiTexParameterfvEXT_c
      glMultiTexParameteriEXT
      glMultiTexParameterIivEXT_c
      glMultiTexParameterIuivEXT_c
      glMultiTexParameterivEXT_c
      glMultiTexRenderbufferEXT
      glMultiTexSubImage1DEXT_c
      glMultiTexSubImage2DEXT_c
      glMultiTexSubImage3DEXT_c
      glMultMatrixd_c
      glMultMatrixf_c
      glMultMatrixx_c
      glMultTransposeMatrixd_c
      glMultTransposeMatrixdARB_c
      glMultTransposeMatrixf_c
      glMultTransposeMatrixfARB_c
      glNamedBufferData_c
      glNamedBufferDataEXT_c
      glNamedBufferStorage_c
      glNamedBufferStorageEXT_c
      glNamedBufferSubData_c
      glNamedBufferSubDataEXT_c
      glNamedCopyBufferSubDataEXT
      glNamedFramebufferDrawBuffer
      glNamedFramebufferDrawBuffers_c
      glNamedFramebufferParameteri
      glNamedFramebufferParameteriEXT
      glNamedFramebufferReadBuffer
      glNamedFramebufferRenderbuffer
      glNamedFramebufferRenderbufferEXT
      glNamedFramebufferSampleLocationsfvARB_c
      glNamedFramebufferSampleLocationsfvNV_c
      glNamedFramebufferTexture
      glNamedFramebufferTexture1DEXT
      glNamedFramebufferTexture2DEXT
      glNamedFramebufferTexture3DEXT
      glNamedFramebufferTextureEXT
      glNamedFramebufferTextureFaceEXT
      glNamedFramebufferTextureLayer
      glNamedFramebufferTextureLayerEXT
      glNamedProgramLocalParameter4dEXT
      glNamedProgramLocalParameter4dvEXT_c
      glNamedProgramLocalParameter4fEXT
      glNamedProgramLocalParameter4fvEXT_c
      glNamedProgramLocalParameterI4iEXT
      glNamedProgramLocalParameterI4ivEXT_c
      glNamedProgramLocalParameterI4uiEXT
      glNamedProgramLocalParameterI4uivEXT_c
      glNamedProgramLocalParameters4fvEXT_c
      glNamedProgramLocalParametersI4ivEXT_c
      glNamedProgramLocalParametersI4uivEXT_c
      glNamedProgramStringEXT_c
      glNamedRenderbufferStorage
      glNamedRenderbufferStorageEXT
      glNamedRenderbufferStorageMultisample
      glNamedRenderbufferStorageMultisampleCoverageEXT
      glNamedRenderbufferStorageMultisampleEXT
      glNamedStringARB_c
      glNewBufferRegion
      glNewList
      glNewObjectBufferATI_c
      glNormal3b
      glNormal3bv_c
      glNormal3d
      glNormal3dv_c
      glNormal3f
      glNormal3fv_c
      glNormal3fVertex3fSUN
      glNormal3fVertex3fvSUN_c
      glNormal3hNV
      glNormal3hvNV_c
      glNormal3i
      glNormal3iv_c
      glNormal3s
      glNormal3sv_c
      glNormal3x
      glNormalFormatNV
      glNormalP3ui
      glNormalP3uiv_c
      glNormalPointer_c
      glNormalPointerEXT_c
      glNormalPointerListIBM_c
      glNormalPointervINTEL_c
      glNormalStream3bATI
      glNormalStream3bvATI_c
      glNormalStream3dATI
      glNormalStream3dvATI_c
      glNormalStream3fATI
      glNormalStream3fvATI_c
      glNormalStream3iATI
      glNormalStream3ivATI_c
      glNormalStream3sATI
      glNormalStream3svATI_c
      glObjectLabel_c
      glObjectPtrLabel_c
      glObjectPurgeableAPPLE
      glObjectUnpurgeableAPPLE
      glOrtho
      glOrthof
      glOrthofOES
      glOrthox
      glPassTexCoordATI
      glPassThrough
      glPatchParameterfv_c
      glPatchParameteri
      glPathColorGenNV_c
      glPathCommandsNV_c
      glPathCoordsNV_c
      glPathCoverDepthFuncNV
      glPathDashArrayNV_c
      glPathFogGenNV
      glPathGlyphIndexArrayNV_c
      glPathGlyphIndexRangeNV_c
      glPathGlyphRangeNV_c
      glPathGlyphsNV_c
      glPathMemoryGlyphIndexArrayNV_c
      glPathParameterfNV
      glPathParameterfvNV_c
      glPathParameteriNV
      glPathParameterivNV_c
      glPathStencilDepthOffsetNV
      glPathStencilFuncNV
      glPathStringNV_c
      glPathSubCommandsNV_c
      glPathSubCoordsNV_c
      glPathTexGenNV_c
      glPauseTransformFeedback
      glPauseTransformFeedbackNV
      glPixelDataRangeNV_c
      glPixelMapfv_c
      glPixelMapuiv_c
      glPixelMapusv_c
      glPixelStoref
      glPixelStorei
      glPixelTexGenSGIX
      glPixelTransferf
      glPixelTransferi
      glPixelTransformParameterfEXT
      glPixelTransformParameterfvEXT_c
      glPixelTransformParameteriEXT
      glPixelTransformParameterivEXT_c
      glPixelZoom
      glPNTrianglesfATI
      glPNTrianglesiATI
      glPointAlongPathNV_c
      glPointParameterf
      glPointParameterfARB
      glPointParameterfEXT
      glPointParameterfv_c
      glPointParameterfvARB_c
      glPointParameterfvEXT_c
      glPointParameteri
      glPointParameteriNV
      glPointParameteriv_c
      glPointParameterivNV_c
      glPointParameterx
      glPointParameterxv_c
      glPointSize
      glPointSizePointerOES_c
      glPointSizex
      glPollAsyncSGIX_c
      glPolygonMode
      glPolygonOffset
      glPolygonOffsetClampEXT
      glPolygonOffsetEXT
      glPolygonOffsetx
      glPolygonStipple_c
      glPopAttrib
      glPopClientAttrib
      glPopDebugGroup
      glPopGroupMarkerEXT
      glPopMatrix
      glPopName
      glPresentFrameDualFillNV
      glPresentFrameKeyedNV
      glPrimitiveBoundingBoxARB
      glPrimitiveRestartIndex
      glPrimitiveRestartIndexNV
      glPrimitiveRestartNV
      glPrioritizeTextures_c
      glPrioritizeTexturesEXT_c
      glProgramBinary_c
      glProgramBufferParametersfvNV_c
      glProgramBufferParametersIivNV_c
      glProgramBufferParametersIuivNV_c
      glProgramEnvParameter4dARB
      glProgramEnvParameter4dvARB_c
      glProgramEnvParameter4fARB
      glProgramEnvParameter4fvARB_c
      glProgramEnvParameterI4iNV
      glProgramEnvParameterI4ivNV_c
      glProgramEnvParameterI4uiNV
      glProgramEnvParameterI4uivNV_c
      glProgramEnvParameters4fvEXT_c
      glProgramEnvParametersI4ivNV_c
      glProgramEnvParametersI4uivNV_c
      glProgramLocalParameter4dARB
      glProgramLocalParameter4dvARB_c
      glProgramLocalParameter4fARB
      glProgramLocalParameter4fvARB_c
      glProgramLocalParameterI4iNV
      glProgramLocalParameterI4ivNV_c
      glProgramLocalParameterI4uiNV
      glProgramLocalParameterI4uivNV_c
      glProgramLocalParameters4fvEXT_c
      glProgramLocalParametersI4ivNV_c
      glProgramLocalParametersI4uivNV_c
      glProgramNamedParameter4dNV_c
      glProgramNamedParameter4dvNV_c
      glProgramNamedParameter4fNV_c
      glProgramNamedParameter4fvNV_c
      glProgramParameter4dNV
      glProgramParameter4dvNV_c
      glProgramParameter4fNV
      glProgramParameter4fvNV_c
      glProgramParameteri
      glProgramParameteriARB
      glProgramParameteriEXT
      glProgramParameters4dvNV_c
      glProgramParameters4fvNV_c
      glProgramPathFragmentInputGenNV_c
      glProgramStringARB_c
      glProgramUniform1d
      glProgramUniform1dv_c
      glProgramUniform1f
      glProgramUniform1fEXT
      glProgramUniform1fv_c
      glProgramUniform1fvEXT_c
      glProgramUniform1i
      glProgramUniform1i64ARB
      glProgramUniform1i64NV
      glProgramUniform1i64vARB_c
      glProgramUniform1i64vNV_c
      glProgramUniform1iEXT
      glProgramUniform1iv_c
      glProgramUniform1ivEXT_c
      glProgramUniform1ui
      glProgramUniform1ui64ARB
      glProgramUniform1ui64NV
      glProgramUniform1ui64vARB_c
      glProgramUniform1ui64vNV_c
      glProgramUniform1uiEXT
      glProgramUniform1uiv_c
      glProgramUniform1uivEXT_c
      glProgramUniform2d
      glProgramUniform2dv_c
      glProgramUniform2f
      glProgramUniform2fEXT
      glProgramUniform2fv_c
      glProgramUniform2fvEXT_c
      glProgramUniform2i
      glProgramUniform2i64ARB
      glProgramUniform2i64NV
      glProgramUniform2i64vARB_c
      glProgramUniform2i64vNV_c
      glProgramUniform2iEXT
      glProgramUniform2iv_c
      glProgramUniform2ivEXT_c
      glProgramUniform2ui
      glProgramUniform2ui64ARB
      glProgramUniform2ui64NV
      glProgramUniform2ui64vARB_c
      glProgramUniform2ui64vNV_c
      glProgramUniform2uiEXT
      glProgramUniform2uiv_c
      glProgramUniform2uivEXT_c
      glProgramUniform3d
      glProgramUniform3dv_c
      glProgramUniform3f
      glProgramUniform3fEXT
      glProgramUniform3fv_c
      glProgramUniform3fvEXT_c
      glProgramUniform3i
      glProgramUniform3i64ARB
      glProgramUniform3i64NV
      glProgramUniform3i64vARB_c
      glProgramUniform3i64vNV_c
      glProgramUniform3iEXT
      glProgramUniform3iv_c
      glProgramUniform3ivEXT_c
      glProgramUniform3ui
      glProgramUniform3ui64ARB
      glProgramUniform3ui64NV
      glProgramUniform3ui64vARB_c
      glProgramUniform3ui64vNV_c
      glProgramUniform3uiEXT
      glProgramUniform3uiv_c
      glProgramUniform3uivEXT_c
      glProgramUniform4d
      glProgramUniform4dv_c
      glProgramUniform4f
      glProgramUniform4fEXT
      glProgramUniform4fv_c
      glProgramUniform4fvEXT_c
      glProgramUniform4i
      glProgramUniform4i64ARB
      glProgramUniform4i64NV
      glProgramUniform4i64vARB_c
      glProgramUniform4i64vNV_c
      glProgramUniform4iEXT
      glProgramUniform4iv_c
      glProgramUniform4ivEXT_c
      glProgramUniform4ui
      glProgramUniform4ui64ARB
      glProgramUniform4ui64NV
      glProgramUniform4ui64vARB_c
      glProgramUniform4ui64vNV_c
      glProgramUniform4uiEXT
      glProgramUniform4uiv_c
      glProgramUniform4uivEXT_c
      glProgramUniformHandleui64ARB
      glProgramUniformHandleui64NV
      glProgramUniformHandleui64vARB_c
      glProgramUniformHandleui64vNV_c
      glProgramUniformMatrix2dv_c
      glProgramUniformMatrix2fv_c
      glProgramUniformMatrix2fvEXT_c
      glProgramUniformMatrix2x3dv_c
      glProgramUniformMatrix2x3fv_c
      glProgramUniformMatrix2x3fvEXT_c
      glProgramUniformMatrix2x4dv_c
      glProgramUniformMatrix2x4fv_c
      glProgramUniformMatrix2x4fvEXT_c
      glProgramUniformMatrix3dv_c
      glProgramUniformMatrix3fv_c
      glProgramUniformMatrix3fvEXT_c
      glProgramUniformMatrix3x2dv_c
      glProgramUniformMatrix3x2fv_c
      glProgramUniformMatrix3x2fvEXT_c
      glProgramUniformMatrix3x4dv_c
      glProgramUniformMatrix3x4fv_c
      glProgramUniformMatrix3x4fvEXT_c
      glProgramUniformMatrix4dv_c
      glProgramUniformMatrix4fv_c
      glProgramUniformMatrix4fvEXT_c
      glProgramUniformMatrix4x2dv_c
      glProgramUniformMatrix4x2fv_c
      glProgramUniformMatrix4x2fvEXT_c
      glProgramUniformMatrix4x3dv_c
      glProgramUniformMatrix4x3fv_c
      glProgramUniformMatrix4x3fvEXT_c
      glProgramUniformui64NV
      glProgramUniformui64vNV_c
      glProgramVertexLimitNV
      glProvokingVertex
      glProvokingVertexEXT
      glPushAttrib
      glPushClientAttrib
      glPushClientAttribDefaultEXT
      glPushDebugGroup_c
      glPushGroupMarkerEXT_c
      glPushMatrix
      glPushName
      glQueryCounter
      glQueryCounterANGLE
      glQueryObjectParameteruiAMD
      glRasterPos2d
      glRasterPos2dv_c
      glRasterPos2f
      glRasterPos2fv_c
      glRasterPos2i
      glRasterPos2iv_c
      glRasterPos2s
      glRasterPos2sv_c
      glRasterPos3d
      glRasterPos3dv_c
      glRasterPos3f
      glRasterPos3fv_c
      glRasterPos3i
      glRasterPos3iv_c
      glRasterPos3s
      glRasterPos3sv_c
      glRasterPos4d
      glRasterPos4dv_c
      glRasterPos4f
      glRasterPos4fv_c
      glRasterPos4i
      glRasterPos4iv_c
      glRasterPos4s
      glRasterPos4sv_c
      glRasterSamplesEXT
      glReadBuffer
      glReadBufferRegion
      glReadnPixels_c
      glReadnPixelsARB_c
      glReadPixels_c
      glReadVideoPixelsSUN_c
      glRectd
      glRectdv_c
      glRectf
      glRectfv_c
      glRecti
      glRectiv_c
      glRects
      glRectsv_c
      glReferencePlaneSGIX_c
      glReleaseShaderCompiler
      glRenderbufferStorage
      glRenderbufferStorageEXT
      glRenderbufferStorageMultisample
      glRenderbufferStorageMultisampleANGLE
      glRenderbufferStorageMultisampleCoverageNV
      glRenderbufferStorageMultisampleEXT
      glRenderGpuMaskNV
      glRenderMode
      glReplacementCodePointerSUN_c
      glReplacementCodeubSUN
      glReplacementCodeubvSUN_c
      glReplacementCodeuiColor3fVertex3fSUN
      glReplacementCodeuiColor3fVertex3fvSUN_c
      glReplacementCodeuiColor4fNormal3fVertex3fSUN
      glReplacementCodeuiColor4fNormal3fVertex3fvSUN_c
      glReplacementCodeuiColor4ubVertex3fSUN
      glReplacementCodeuiColor4ubVertex3fvSUN_c
      glReplacementCodeuiNormal3fVertex3fSUN
      glReplacementCodeuiNormal3fVertex3fvSUN_c
      glReplacementCodeuiSUN
      glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN
      glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN_c
      glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN
      glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN_c
      glReplacementCodeuiTexCoord2fVertex3fSUN
      glReplacementCodeuiTexCoord2fVertex3fvSUN_c
      glReplacementCodeuiVertex3fSUN
      glReplacementCodeuiVertex3fvSUN_c
      glReplacementCodeuivSUN_c
      glReplacementCodeusSUN
      glReplacementCodeusvSUN_c
      glRequestResidentProgramsNV_c
      glResetHistogram
      glResetHistogramEXT
      glResetMinmax
      glResetMinmaxEXT
      glResizeBuffersMESA
      glResumeTransformFeedback
      glResumeTransformFeedbackNV
      glRotated
      glRotatef
      glRotatex
      glSampleCoverage
      glSampleCoverageARB
      glSampleCoveragex
      glSampleMapATI
      glSampleMaskEXT
      glSampleMaski
      glSampleMaskIndexedNV
      glSampleMaskSGIS
      glSamplePatternEXT
      glSamplePatternSGIS
      glSamplerParameterf
      glSamplerParameterfv_c
      glSamplerParameteri
      glSamplerParameterIiv_c
      glSamplerParameterIuiv_c
      glSamplerParameteriv_c
      glScaled
      glScalef
      glScalex
      glScissor
      glScissorArrayv_c
      glScissorIndexed
      glScissorIndexedv_c
      glSecondaryColor3b
      glSecondaryColor3bEXT
      glSecondaryColor3bv_c
      glSecondaryColor3bvEXT_c
      glSecondaryColor3d
      glSecondaryColor3dEXT
      glSecondaryColor3dv_c
      glSecondaryColor3dvEXT_c
      glSecondaryColor3f
      glSecondaryColor3fEXT
      glSecondaryColor3fv_c
      glSecondaryColor3fvEXT_c
      glSecondaryColor3hNV
      glSecondaryColor3hvNV_c
      glSecondaryColor3i
      glSecondaryColor3iEXT
      glSecondaryColor3iv_c
      glSecondaryColor3ivEXT_c
      glSecondaryColor3s
      glSecondaryColor3sEXT
      glSecondaryColor3sv_c
      glSecondaryColor3svEXT_c
      glSecondaryColor3ub
      glSecondaryColor3ubEXT
      glSecondaryColor3ubv_c
      glSecondaryColor3ubvEXT_c
      glSecondaryColor3ui
      glSecondaryColor3uiEXT
      glSecondaryColor3uiv_c
      glSecondaryColor3uivEXT_c
      glSecondaryColor3us
      glSecondaryColor3usEXT
      glSecondaryColor3usv_c
      glSecondaryColor3usvEXT_c
      glSecondaryColorFormatNV
      glSecondaryColorP3ui
      glSecondaryColorP3uiv_c
      glSecondaryColorPointer_c
      glSecondaryColorPointerEXT_c
      glSecondaryColorPointerListIBM_c
      glSelectBuffer_c
      glSelectPerfMonitorCountersAMD_c
      glSeparableFilter2D_c
      glSeparableFilter2DEXT_c
      glSetFenceAPPLE
      glSetFenceNV
      glSetFragmentShaderConstantATI_c
      glSetInvariantEXT_c
      glSetLocalConstantEXT_c
      glSetMultisamplefvAMD_c
      glShadeModel
      glShaderBinary_c
      glShaderOp1EXT
      glShaderOp2EXT
      glShaderOp3EXT
      glShaderSource_c
      glShaderSourceARB_c
      glShaderStorageBlockBinding
      glSharpenTexFuncSGIS_c
      glSignalVkFenceNV
      glSignalVkSemaphoreNV
      glSpecializeShaderARB_c
      glSpriteParameterfSGIX
      glSpriteParameterfvSGIX_c
      glSpriteParameteriSGIX
      glSpriteParameterivSGIX_c
      glStateCaptureNV
      glStencilFillPathInstancedNV_c
      glStencilFillPathNV
      glStencilFunc
      glStencilFuncSeparate
      glStencilFuncSeparateATI
      glStencilMask
      glStencilMaskSeparate
      glStencilOp
      glStencilOpSeparate
      glStencilOpSeparateATI
      glStencilOpValueAMD
      glStencilStrokePathInstancedNV_c
      glStencilStrokePathNV
      glStencilThenCoverFillPathInstancedNV_c
      glStencilThenCoverFillPathNV
      glStencilThenCoverStrokePathInstancedNV_c
      glStencilThenCoverStrokePathNV
      glStringMarkerGREMEDY_c
      glSubpixelPrecisionBiasNV
      glSwizzleEXT
      glSyncTextureINTEL
      glTagSampleBufferSGIX
      glTangentPointerEXT_c
      glTbufferMask3DFX
      glTessellationFactorAMD
      glTessellationModeAMD
      glTestFenceAPPLE
      glTestFenceNV
      glTestObjectAPPLE
      glTexBuffer
      glTexBufferARB
      glTexBufferEXT
      glTexBufferRange
      glTexBumpParameterfvATI_c
      glTexBumpParameterivATI_c
      glTexCoord1d
      glTexCoord1dv_c
      glTexCoord1f
      glTexCoord1fv_c
      glTexCoord1hNV
      glTexCoord1hvNV_c
      glTexCoord1i
      glTexCoord1iv_c
      glTexCoord1s
      glTexCoord1sv_c
      glTexCoord2d
      glTexCoord2dv_c
      glTexCoord2f
      glTexCoord2fColor3fVertex3fSUN
      glTexCoord2fColor3fVertex3fvSUN_c
      glTexCoord2fColor4fNormal3fVertex3fSUN
      glTexCoord2fColor4fNormal3fVertex3fvSUN_c
      glTexCoord2fColor4ubVertex3fSUN
      glTexCoord2fColor4ubVertex3fvSUN_c
      glTexCoord2fNormal3fVertex3fSUN
      glTexCoord2fNormal3fVertex3fvSUN_c
      glTexCoord2fv_c
      glTexCoord2fVertex3fSUN
      glTexCoord2fVertex3fvSUN_c
      glTexCoord2hNV
      glTexCoord2hvNV_c
      glTexCoord2i
      glTexCoord2iv_c
      glTexCoord2s
      glTexCoord2sv_c
      glTexCoord3d
      glTexCoord3dv_c
      glTexCoord3f
      glTexCoord3fv_c
      glTexCoord3hNV
      glTexCoord3hvNV_c
      glTexCoord3i
      glTexCoord3iv_c
      glTexCoord3s
      glTexCoord3sv_c
      glTexCoord4d
      glTexCoord4dv_c
      glTexCoord4f
      glTexCoord4fColor4fNormal3fVertex4fSUN
      glTexCoord4fColor4fNormal3fVertex4fvSUN_c
      glTexCoord4fv_c
      glTexCoord4fVertex4fSUN
      glTexCoord4fVertex4fvSUN_c
      glTexCoord4hNV
      glTexCoord4hvNV_c
      glTexCoord4i
      glTexCoord4iv_c
      glTexCoord4s
      glTexCoord4sv_c
      glTexCoordFormatNV
      glTexCoordP1ui
      glTexCoordP1uiv_c
      glTexCoordP2ui
      glTexCoordP2uiv_c
      glTexCoordP3ui
      glTexCoordP3uiv_c
      glTexCoordP4ui
      glTexCoordP4uiv_c
      glTexCoordPointer_c
      glTexCoordPointerEXT_c
      glTexCoordPointerListIBM_c
      glTexCoordPointervINTEL_c
      glTexEnvf
      glTexEnvfv_c
      glTexEnvi
      glTexEnviv_c
      glTexEnvx
      glTexEnvxv_c
      glTexFilterFuncSGIS_c
      glTexGend
      glTexGendv_c
      glTexGenf
      glTexGenfv_c
      glTexGeni
      glTexGeniv_c
      glTexImage1D_c
      glTexImage2D_c
      glTexImage2DMultisample
      glTexImage2DMultisampleCoverageNV
      glTexImage3D_c
      glTexImage3DEXT_c
      glTexImage3DMultisample
      glTexImage3DMultisampleCoverageNV
      glTexImage4DSGIS_c
      glTexPageCommitmentARB
      glTexParameterf
      glTexParameterfv_c
      glTexParameteri
      glTexParameterIiv_c
      glTexParameterIivEXT_c
      glTexParameterIuiv_c
      glTexParameterIuivEXT_c
      glTexParameteriv_c
      glTexParameterx
      glTexParameterxv_c
      glTexRenderbufferNV
      glTexScissorFuncINTEL
      glTexScissorINTEL
      glTexStorage1D
      glTexStorage2D
      glTexStorage2DMultisample
      glTexStorage3D
      glTexStorage3DMultisample
      glTexStorageSparseAMD
      glTexSubImage1D_c
      glTexSubImage1DEXT_c
      glTexSubImage2D_c
      glTexSubImage2DEXT_c
      glTexSubImage3D_c
      glTexSubImage3DEXT_c
      glTexSubImage4DSGIS_c
      glTextureBarrier
      glTextureBarrierNV
      glTextureBuffer
      glTextureBufferEXT
      glTextureBufferRange
      glTextureBufferRangeEXT
      glTextureFogSGIX
      glTextureImage1DEXT_c
      glTextureImage2DEXT_c
      glTextureImage2DMultisampleCoverageNV
      glTextureImage2DMultisampleNV
      glTextureImage3DEXT_c
      glTextureImage3DMultisampleCoverageNV
      glTextureImage3DMultisampleNV
      glTextureLightEXT
      glTextureMaterialEXT
      glTextureNormalEXT
      glTexturePageCommitmentEXT
      glTextureParameterf
      glTextureParameterfEXT
      glTextureParameterfv_c
      glTextureParameterfvEXT_c
      glTextureParameteri
      glTextureParameteriEXT
      glTextureParameterIiv_c
      glTextureParameterIivEXT_c
      glTextureParameterIuiv_c
      glTextureParameterIuivEXT_c
      glTextureParameteriv_c
      glTextureParameterivEXT_c
      glTextureRangeAPPLE_c
      glTextureRenderbufferEXT
      glTextureStorage1D
      glTextureStorage1DEXT
      glTextureStorage2D
      glTextureStorage2DEXT
      glTextureStorage2DMultisample
      glTextureStorage2DMultisampleEXT
      glTextureStorage3D
      glTextureStorage3DEXT
      glTextureStorage3DMultisample
      glTextureStorage3DMultisampleEXT
      glTextureStorageSparseAMD
      glTextureSubImage1D_c
      glTextureSubImage1DEXT_c
      glTextureSubImage2D_c
      glTextureSubImage2DEXT_c
      glTextureSubImage3D_c
      glTextureSubImage3DEXT_c
      glTextureView
      glTrackMatrixNV
      glTransformFeedbackAttribsNV_c
      glTransformFeedbackBufferBase
      glTransformFeedbackBufferRange
      glTransformFeedbackVaryings_c
      glTransformFeedbackVaryingsEXT_c
      glTransformFeedbackVaryingsNV_c
      glTransformPathNV_c
      glTranslated
      glTranslatef
      glTranslatex
      glUniform1d
      glUniform1dv_c
      glUniform1f
      glUniform1fARB
      glUniform1fv_c
      glUniform1fvARB_c
      glUniform1i
      glUniform1i64ARB
      glUniform1i64NV
      glUniform1i64vARB_c
      glUniform1i64vNV_c
      glUniform1iARB
      glUniform1iv_c
      glUniform1ivARB_c
      glUniform1ui
      glUniform1ui64ARB
      glUniform1ui64NV
      glUniform1ui64vARB_c
      glUniform1ui64vNV_c
      glUniform1uiEXT
      glUniform1uiv_c
      glUniform1uivEXT_c
      glUniform2d
      glUniform2dv_c
      glUniform2f
      glUniform2fARB
      glUniform2fv_c
      glUniform2fvARB_c
      glUniform2i
      glUniform2i64ARB
      glUniform2i64NV
      glUniform2i64vARB_c
      glUniform2i64vNV_c
      glUniform2iARB
      glUniform2iv_c
      glUniform2ivARB_c
      glUniform2ui
      glUniform2ui64ARB
      glUniform2ui64NV
      glUniform2ui64vARB_c
      glUniform2ui64vNV_c
      glUniform2uiEXT
      glUniform2uiv_c
      glUniform2uivEXT_c
      glUniform3d
      glUniform3dv_c
      glUniform3f
      glUniform3fARB
      glUniform3fv_c
      glUniform3fvARB_c
      glUniform3i
      glUniform3i64ARB
      glUniform3i64NV
      glUniform3i64vARB_c
      glUniform3i64vNV_c
      glUniform3iARB
      glUniform3iv_c
      glUniform3ivARB_c
      glUniform3ui
      glUniform3ui64ARB
      glUniform3ui64NV
      glUniform3ui64vARB_c
      glUniform3ui64vNV_c
      glUniform3uiEXT
      glUniform3uiv_c
      glUniform3uivEXT_c
      glUniform4d
      glUniform4dv_c
      glUniform4f
      glUniform4fARB
      glUniform4fv_c
      glUniform4fvARB_c
      glUniform4i
      glUniform4i64ARB
      glUniform4i64NV
      glUniform4i64vARB_c
      glUniform4i64vNV_c
      glUniform4iARB
      glUniform4iv_c
      glUniform4ivARB_c
      glUniform4ui
      glUniform4ui64ARB
      glUniform4ui64NV
      glUniform4ui64vARB_c
      glUniform4ui64vNV_c
      glUniform4uiEXT
      glUniform4uiv_c
      glUniform4uivEXT_c
      glUniformBlockBinding
      glUniformBufferEXT
      glUniformHandleui64ARB
      glUniformHandleui64NV
      glUniformHandleui64vARB_c
      glUniformHandleui64vNV_c
      glUniformMatrix2dv_c
      glUniformMatrix2fv_c
      glUniformMatrix2fvARB_c
      glUniformMatrix2x3dv_c
      glUniformMatrix2x3fv_c
      glUniformMatrix2x4dv_c
      glUniformMatrix2x4fv_c
      glUniformMatrix3dv_c
      glUniformMatrix3fv_c
      glUniformMatrix3fvARB_c
      glUniformMatrix3x2dv_c
      glUniformMatrix3x2fv_c
      glUniformMatrix3x4dv_c
      glUniformMatrix3x4fv_c
      glUniformMatrix4dv_c
      glUniformMatrix4fv_c
      glUniformMatrix4fvARB_c
      glUniformMatrix4x2dv_c
      glUniformMatrix4x2fv_c
      glUniformMatrix4x3dv_c
      glUniformMatrix4x3fv_c
      glUniformSubroutinesuiv_c
      glUniformui64NV
      glUniformui64vNV_c
      glUnlockArraysEXT
      glUnmapBuffer
      glUnmapBufferARB
      glUnmapNamedBuffer
      glUnmapNamedBufferEXT
      glUnmapObjectBufferATI
      glUnmapTexture2DINTEL
      glUpdateObjectBufferATI_c
      glUseProgram
      glUseProgramObjectARB
      glUseProgramStages
      glUseShaderProgramEXT
      glValidateProgram
      glValidateProgramARB
      glValidateProgramPipeline
      glVariantArrayObjectATI
      glVariantbvEXT_c
      glVariantdvEXT_c
      glVariantfvEXT_c
      glVariantivEXT_c
      glVariantPointerEXT_c
      glVariantsvEXT_c
      glVariantubvEXT_c
      glVariantuivEXT_c
      glVariantusvEXT_c
      glVDPAUFiniNV
      glVDPAUGetSurfaceivNV_c
      glVDPAUInitNV_c
      glVDPAUIsSurfaceNV
      glVDPAUMapSurfacesNV_c
      glVDPAURegisterOutputSurfaceNV_c
      glVDPAURegisterVideoSurfaceNV_c
      glVDPAUSurfaceAccessNV
      glVDPAUUnmapSurfacesNV_c
      glVDPAUUnregisterSurfaceNV
      glVertex2d
      glVertex2dv_c
      glVertex2f
      glVertex2fv_c
      glVertex2hNV
      glVertex2hvNV_c
      glVertex2i
      glVertex2iv_c
      glVertex2s
      glVertex2sv_c
      glVertex3d
      glVertex3dv_c
      glVertex3f
      glVertex3fv_c
      glVertex3hNV
      glVertex3hvNV_c
      glVertex3i
      glVertex3iv_c
      glVertex3s
      glVertex3sv_c
      glVertex4d
      glVertex4dv_c
      glVertex4f
      glVertex4fv_c
      glVertex4hNV
      glVertex4hvNV_c
      glVertex4i
      glVertex4iv_c
      glVertex4s
      glVertex4sv_c
      glVertexArrayAttribBinding
      glVertexArrayAttribFormat
      glVertexArrayAttribIFormat
      glVertexArrayAttribLFormat
      glVertexArrayBindingDivisor
      glVertexArrayBindVertexBufferEXT
      glVertexArrayColorOffsetEXT
      glVertexArrayEdgeFlagOffsetEXT
      glVertexArrayElementBuffer
      glVertexArrayFogCoordOffsetEXT
      glVertexArrayIndexOffsetEXT
      glVertexArrayMultiTexCoordOffsetEXT
      glVertexArrayNormalOffsetEXT
      glVertexArrayParameteriAPPLE
      glVertexArrayRangeAPPLE_c
      glVertexArrayRangeNV_c
      glVertexArraySecondaryColorOffsetEXT
      glVertexArrayTexCoordOffsetEXT
      glVertexArrayVertexAttribBindingEXT
      glVertexArrayVertexAttribDivisorEXT
      glVertexArrayVertexAttribFormatEXT
      glVertexArrayVertexAttribIFormatEXT
      glVertexArrayVertexAttribIOffsetEXT
      glVertexArrayVertexAttribLFormatEXT
      glVertexArrayVertexAttribLOffsetEXT
      glVertexArrayVertexAttribOffsetEXT
      glVertexArrayVertexBindingDivisorEXT
      glVertexArrayVertexBuffer
      glVertexArrayVertexBuffers_c
      glVertexArrayVertexOffsetEXT
      glVertexAttrib1d
      glVertexAttrib1dARB
      glVertexAttrib1dNV
      glVertexAttrib1dv_c
      glVertexAttrib1dvARB_c
      glVertexAttrib1dvNV_c
      glVertexAttrib1f
      glVertexAttrib1fARB
      glVertexAttrib1fNV
      glVertexAttrib1fv_c
      glVertexAttrib1fvARB_c
      glVertexAttrib1fvNV_c
      glVertexAttrib1hNV
      glVertexAttrib1hvNV_c
      glVertexAttrib1s
      glVertexAttrib1sARB
      glVertexAttrib1sNV
      glVertexAttrib1sv_c
      glVertexAttrib1svARB_c
      glVertexAttrib1svNV_c
      glVertexAttrib2d
      glVertexAttrib2dARB
      glVertexAttrib2dNV
      glVertexAttrib2dv_c
      glVertexAttrib2dvARB_c
      glVertexAttrib2dvNV_c
      glVertexAttrib2f
      glVertexAttrib2fARB
      glVertexAttrib2fNV
      glVertexAttrib2fv_c
      glVertexAttrib2fvARB_c
      glVertexAttrib2fvNV_c
      glVertexAttrib2hNV
      glVertexAttrib2hvNV_c
      glVertexAttrib2s
      glVertexAttrib2sARB
      glVertexAttrib2sNV
      glVertexAttrib2sv_c
      glVertexAttrib2svARB_c
      glVertexAttrib2svNV_c
      glVertexAttrib3d
      glVertexAttrib3dARB
      glVertexAttrib3dNV
      glVertexAttrib3dv_c
      glVertexAttrib3dvARB_c
      glVertexAttrib3dvNV_c
      glVertexAttrib3f
      glVertexAttrib3fARB
      glVertexAttrib3fNV
      glVertexAttrib3fv_c
      glVertexAttrib3fvARB_c
      glVertexAttrib3fvNV_c
      glVertexAttrib3hNV
      glVertexAttrib3hvNV_c
      glVertexAttrib3s
      glVertexAttrib3sARB
      glVertexAttrib3sNV
      glVertexAttrib3sv_c
      glVertexAttrib3svARB_c
      glVertexAttrib3svNV_c
      glVertexAttrib4bv_c
      glVertexAttrib4bvARB_c
      glVertexAttrib4d
      glVertexAttrib4dARB
      glVertexAttrib4dNV
      glVertexAttrib4dv_c
      glVertexAttrib4dvARB_c
      glVertexAttrib4dvNV_c
      glVertexAttrib4f
      glVertexAttrib4fARB
      glVertexAttrib4fNV
      glVertexAttrib4fv_c
      glVertexAttrib4fvARB_c
      glVertexAttrib4fvNV_c
      glVertexAttrib4hNV
      glVertexAttrib4hvNV_c
      glVertexAttrib4iv_c
      glVertexAttrib4ivARB_c
      glVertexAttrib4Nbv_c
      glVertexAttrib4NbvARB_c
      glVertexAttrib4Niv_c
      glVertexAttrib4NivARB_c
      glVertexAttrib4Nsv_c
      glVertexAttrib4NsvARB_c
      glVertexAttrib4Nub
      glVertexAttrib4NubARB
      glVertexAttrib4Nubv_c
      glVertexAttrib4NubvARB_c
      glVertexAttrib4Nuiv_c
      glVertexAttrib4NuivARB_c
      glVertexAttrib4Nusv_c
      glVertexAttrib4NusvARB_c
      glVertexAttrib4s
      glVertexAttrib4sARB
      glVertexAttrib4sNV
      glVertexAttrib4sv_c
      glVertexAttrib4svARB_c
      glVertexAttrib4svNV_c
      glVertexAttrib4ubNV
      glVertexAttrib4ubv_c
      glVertexAttrib4ubvARB_c
      glVertexAttrib4ubvNV_c
      glVertexAttrib4uiv_c
      glVertexAttrib4uivARB_c
      glVertexAttrib4usv_c
      glVertexAttrib4usvARB_c
      glVertexAttribArrayObjectATI
      glVertexAttribBinding
      glVertexAttribDivisor
      glVertexAttribDivisorANGLE
      glVertexAttribDivisorARB
      glVertexAttribFormat
      glVertexAttribFormatNV
      glVertexAttribI1i
      glVertexAttribI1iEXT
      glVertexAttribI1iv_c
      glVertexAttribI1ivEXT_c
      glVertexAttribI1ui
      glVertexAttribI1uiEXT
      glVertexAttribI1uiv_c
      glVertexAttribI1uivEXT_c
      glVertexAttribI2i
      glVertexAttribI2iEXT
      glVertexAttribI2iv_c
      glVertexAttribI2ivEXT_c
      glVertexAttribI2ui
      glVertexAttribI2uiEXT
      glVertexAttribI2uiv_c
      glVertexAttribI2uivEXT_c
      glVertexAttribI3i
      glVertexAttribI3iEXT
      glVertexAttribI3iv_c
      glVertexAttribI3ivEXT_c
      glVertexAttribI3ui
      glVertexAttribI3uiEXT
      glVertexAttribI3uiv_c
      glVertexAttribI3uivEXT_c
      glVertexAttribI4bv_c
      glVertexAttribI4bvEXT_c
      glVertexAttribI4i
      glVertexAttribI4iEXT
      glVertexAttribI4iv_c
      glVertexAttribI4ivEXT_c
      glVertexAttribI4sv_c
      glVertexAttribI4svEXT_c
      glVertexAttribI4ubv_c
      glVertexAttribI4ubvEXT_c
      glVertexAttribI4ui
      glVertexAttribI4uiEXT
      glVertexAttribI4uiv_c
      glVertexAttribI4uivEXT_c
      glVertexAttribI4usv_c
      glVertexAttribI4usvEXT_c
      glVertexAttribIFormat
      glVertexAttribIFormatNV
      glVertexAttribIPointer_c
      glVertexAttribIPointerEXT_c
      glVertexAttribL1d
      glVertexAttribL1dEXT
      glVertexAttribL1dv_c
      glVertexAttribL1dvEXT_c
      glVertexAttribL1i64NV
      glVertexAttribL1i64vNV_c
      glVertexAttribL1ui64ARB
      glVertexAttribL1ui64NV
      glVertexAttribL1ui64vARB_c
      glVertexAttribL1ui64vNV_c
      glVertexAttribL2d
      glVertexAttribL2dEXT
      glVertexAttribL2dv_c
      glVertexAttribL2dvEXT_c
      glVertexAttribL2i64NV
      glVertexAttribL2i64vNV_c
      glVertexAttribL2ui64NV
      glVertexAttribL2ui64vNV_c
      glVertexAttribL3d
      glVertexAttribL3dEXT
      glVertexAttribL3dv_c
      glVertexAttribL3dvEXT_c
      glVertexAttribL3i64NV
      glVertexAttribL3i64vNV_c
      glVertexAttribL3ui64NV
      glVertexAttribL3ui64vNV_c
      glVertexAttribL4d
      glVertexAttribL4dEXT
      glVertexAttribL4dv_c
      glVertexAttribL4dvEXT_c
      glVertexAttribL4i64NV
      glVertexAttribL4i64vNV_c
      glVertexAttribL4ui64NV
      glVertexAttribL4ui64vNV_c
      glVertexAttribLFormat
      glVertexAttribLFormatNV
      glVertexAttribLPointer_c
      glVertexAttribLPointerEXT_c
      glVertexAttribP1ui
      glVertexAttribP1uiv_c
      glVertexAttribP2ui
      glVertexAttribP2uiv_c
      glVertexAttribP3ui
      glVertexAttribP3uiv_c
      glVertexAttribP4ui
      glVertexAttribP4uiv_c
      glVertexAttribParameteriAMD
      glVertexAttribPointer_c
      glVertexAttribPointerARB_c
      glVertexAttribPointerNV_c
      glVertexAttribs1dvNV_c
      glVertexAttribs1fvNV_c
      glVertexAttribs1hvNV_c
      glVertexAttribs1svNV_c
      glVertexAttribs2dvNV_c
      glVertexAttribs2fvNV_c
      glVertexAttribs2hvNV_c
      glVertexAttribs2svNV_c
      glVertexAttribs3dvNV_c
      glVertexAttribs3fvNV_c
      glVertexAttribs3hvNV_c
      glVertexAttribs3svNV_c
      glVertexAttribs4dvNV_c
      glVertexAttribs4fvNV_c
      glVertexAttribs4hvNV_c
      glVertexAttribs4svNV_c
      glVertexAttribs4ubvNV_c
      glVertexBindingDivisor
      glVertexBlendARB
      glVertexBlendEnvfATI
      glVertexBlendEnviATI
      glVertexFormatNV
      glVertexP2ui
      glVertexP2uiv_c
      glVertexP3ui
      glVertexP3uiv_c
      glVertexP4ui
      glVertexP4uiv_c
      glVertexPointer_c
      glVertexPointerEXT_c
      glVertexPointerListIBM_c
      glVertexPointervINTEL_c
      glVertexStream1dATI
      glVertexStream1dvATI_c
      glVertexStream1fATI
      glVertexStream1fvATI_c
      glVertexStream1iATI
      glVertexStream1ivATI_c
      glVertexStream1sATI
      glVertexStream1svATI_c
      glVertexStream2dATI
      glVertexStream2dvATI_c
      glVertexStream2fATI
      glVertexStream2fvATI_c
      glVertexStream2iATI
      glVertexStream2ivATI_c
      glVertexStream2sATI
      glVertexStream2svATI_c
      glVertexStream3dATI
      glVertexStream3dvATI_c
      glVertexStream3fATI
      glVertexStream3fvATI_c
      glVertexStream3iATI
      glVertexStream3ivATI_c
      glVertexStream3sATI
      glVertexStream3svATI_c
      glVertexStream4dATI
      glVertexStream4dvATI_c
      glVertexStream4fATI
      glVertexStream4fvATI_c
      glVertexStream4iATI
      glVertexStream4ivATI_c
      glVertexStream4sATI
      glVertexStream4svATI_c
      glVertexWeightfEXT
      glVertexWeightfvEXT_c
      glVertexWeighthNV
      glVertexWeighthvNV_c
      glVertexWeightPointerEXT_c
      glVideoCaptureNV_c
      glVideoCaptureStreamParameterdvNV_c
      glVideoCaptureStreamParameterfvNV_c
      glVideoCaptureStreamParameterivNV_c
      glViewport
      glViewportArrayv_c
      glViewportIndexedf
      glViewportIndexedfv_c
      glViewportPositionWScaleNV
      glViewportSwizzleNV
      glWaitSync
      glWaitVkSemaphoreNV
      glWeightbvARB_c
      glWeightdvARB_c
      glWeightfvARB_c
      glWeightivARB_c
      glWeightPathsNV_c
      glWeightPointerARB_c
      glWeightsvARB_c
      glWeightubvARB_c
      glWeightuivARB_c
      glWeightusvARB_c
      glWindowPos2d
      glWindowPos2dARB
      glWindowPos2dMESA
      glWindowPos2dv_c
      glWindowPos2dvARB_c
      glWindowPos2dvMESA_c
      glWindowPos2f
      glWindowPos2fARB
      glWindowPos2fMESA
      glWindowPos2fv_c
      glWindowPos2fvARB_c
      glWindowPos2fvMESA_c
      glWindowPos2i
      glWindowPos2iARB
      glWindowPos2iMESA
      glWindowPos2iv_c
      glWindowPos2ivARB_c
      glWindowPos2ivMESA_c
      glWindowPos2s
      glWindowPos2sARB
      glWindowPos2sMESA
      glWindowPos2sv_c
      glWindowPos2svARB_c
      glWindowPos2svMESA_c
      glWindowPos3d
      glWindowPos3dARB
      glWindowPos3dMESA
      glWindowPos3dv_c
      glWindowPos3dvARB_c
      glWindowPos3dvMESA_c
      glWindowPos3f
      glWindowPos3fARB
      glWindowPos3fMESA
      glWindowPos3fv_c
      glWindowPos3fvARB_c
      glWindowPos3fvMESA_c
      glWindowPos3i
      glWindowPos3iARB
      glWindowPos3iMESA
      glWindowPos3iv_c
      glWindowPos3ivARB_c
      glWindowPos3ivMESA_c
      glWindowPos3s
      glWindowPos3sARB
      glWindowPos3sMESA
      glWindowPos3sv_c
      glWindowPos3svARB_c
      glWindowPos3svMESA_c
      glWindowPos4dMESA
      glWindowPos4dvMESA_c
      glWindowPos4fMESA
      glWindowPos4fvMESA_c
      glWindowPos4iMESA
      glWindowPos4ivMESA_c
      glWindowPos4sMESA
      glWindowPos4svMESA_c
      glWindowRectanglesEXT_c
      glWriteMaskEXT
    );
}

sub EXPORT_TAGS_GL {
    (
          'GL_3DFX_tbuffer' => [
                                 'glTbufferMask3DFX'
                               ],
          'GL_AMD_debug_output' => [
                                     'glDebugMessageCallbackAMD',
                                     'glDebugMessageEnableAMD',
                                     'glDebugMessageInsertAMD',
                                     'glGetDebugMessageLogAMD'
                                   ],
          'GL_AMD_draw_buffers_blend' => [
                                           'glBlendEquationIndexedAMD',
                                           'glBlendEquationSeparateIndexedAMD',
                                           'glBlendFuncIndexedAMD',
                                           'glBlendFuncSeparateIndexedAMD'
                                         ],
          'GL_AMD_interleaved_elements' => [
                                             'glVertexAttribParameteriAMD'
                                           ],
          'GL_AMD_multi_draw_indirect' => [
                                            'glMultiDrawArraysIndirectAMD',
                                            'glMultiDrawElementsIndirectAMD'
                                          ],
          'GL_AMD_name_gen_delete' => [
                                        'glDeleteNamesAMD',
                                        'glGenNamesAMD',
                                        'glIsNameAMD'
                                      ],
          'GL_AMD_occlusion_query_event' => [
                                              'glQueryObjectParameteruiAMD'
                                            ],
          'GL_AMD_performance_monitor' => [
                                            'glBeginPerfMonitorAMD',
                                            'glDeletePerfMonitorsAMD',
                                            'glEndPerfMonitorAMD',
                                            'glGenPerfMonitorsAMD',
                                            'glGetPerfMonitorCounterDataAMD',
                                            'glGetPerfMonitorCounterInfoAMD',
                                            'glGetPerfMonitorCounterStringAMD',
                                            'glGetPerfMonitorCountersAMD',
                                            'glGetPerfMonitorGroupStringAMD',
                                            'glGetPerfMonitorGroupsAMD',
                                            'glSelectPerfMonitorCountersAMD'
                                          ],
          'GL_AMD_sample_positions' => [
                                         'glSetMultisamplefvAMD'
                                       ],
          'GL_AMD_sparse_texture' => [
                                       'glTexStorageSparseAMD',
                                       'glTextureStorageSparseAMD'
                                     ],
          'GL_AMD_stencil_operation_extended' => [
                                                   'glStencilOpValueAMD'
                                                 ],
          'GL_AMD_vertex_shader_tessellator' => [
                                                  'glTessellationFactorAMD',
                                                  'glTessellationModeAMD'
                                                ],
          'GL_ANGLE_framebuffer_blit' => [
                                           'glBlitFramebufferANGLE'
                                         ],
          'GL_ANGLE_framebuffer_multisample' => [
                                                  'glRenderbufferStorageMultisampleANGLE'
                                                ],
          'GL_ANGLE_instanced_arrays' => [
                                           'glDrawArraysInstancedANGLE',
                                           'glDrawElementsInstancedANGLE',
                                           'glVertexAttribDivisorANGLE'
                                         ],
          'GL_ANGLE_timer_query' => [
                                      'glBeginQueryANGLE',
                                      'glDeleteQueriesANGLE',
                                      'glEndQueryANGLE',
                                      'glGenQueriesANGLE',
                                      'glGetQueryObjecti64vANGLE',
                                      'glGetQueryObjectivANGLE',
                                      'glGetQueryObjectui64vANGLE',
                                      'glGetQueryObjectuivANGLE',
                                      'glGetQueryivANGLE',
                                      'glIsQueryANGLE',
                                      'glQueryCounterANGLE'
                                    ],
          'GL_ANGLE_translated_shader_source' => [
                                                   'glGetTranslatedShaderSourceANGLE'
                                                 ],
          'GL_APPLE_element_array' => [
                                        'glDrawElementArrayAPPLE',
                                        'glDrawRangeElementArrayAPPLE',
                                        'glElementPointerAPPLE',
                                        'glMultiDrawElementArrayAPPLE',
                                        'glMultiDrawRangeElementArrayAPPLE'
                                      ],
          'GL_APPLE_fence' => [
                                'glDeleteFencesAPPLE',
                                'glFinishFenceAPPLE',
                                'glFinishObjectAPPLE',
                                'glGenFencesAPPLE',
                                'glIsFenceAPPLE',
                                'glSetFenceAPPLE',
                                'glTestFenceAPPLE',
                                'glTestObjectAPPLE'
                              ],
          'GL_APPLE_flush_buffer_range' => [
                                             'glBufferParameteriAPPLE',
                                             'glFlushMappedBufferRangeAPPLE'
                                           ],
          'GL_APPLE_object_purgeable' => [
                                           'glGetObjectParameterivAPPLE',
                                           'glObjectPurgeableAPPLE',
                                           'glObjectUnpurgeableAPPLE'
                                         ],
          'GL_APPLE_texture_range' => [
                                        'glGetTexParameterPointervAPPLE',
                                        'glTextureRangeAPPLE'
                                      ],
          'GL_APPLE_vertex_array_object' => [
                                              'glBindVertexArrayAPPLE',
                                              'glDeleteVertexArraysAPPLE',
                                              'glGenVertexArraysAPPLE',
                                              'glIsVertexArrayAPPLE'
                                            ],
          'GL_APPLE_vertex_array_range' => [
                                             'glFlushVertexArrayRangeAPPLE',
                                             'glVertexArrayParameteriAPPLE',
                                             'glVertexArrayRangeAPPLE'
                                           ],
          'GL_APPLE_vertex_program_evaluators' => [
                                                    'glDisableVertexAttribAPPLE',
                                                    'glEnableVertexAttribAPPLE',
                                                    'glIsVertexAttribEnabledAPPLE',
                                                    'glMapVertexAttrib1dAPPLE',
                                                    'glMapVertexAttrib1fAPPLE',
                                                    'glMapVertexAttrib2dAPPLE',
                                                    'glMapVertexAttrib2fAPPLE'
                                                  ],
          'GL_ARB_ES2_compatibility' => [
                                          'glClearDepthf',
                                          'glDepthRangef',
                                          'glGetShaderPrecisionFormat',
                                          'glReleaseShaderCompiler',
                                          'glShaderBinary'
                                        ],
          'GL_ARB_ES3_1_compatibility' => [
                                            'glMemoryBarrierByRegion'
                                          ],
          'GL_ARB_ES3_2_compatibility' => [
                                            'glPrimitiveBoundingBoxARB'
                                          ],
          'GL_ARB_base_instance' => [
                                      'glDrawArraysInstancedBaseInstance',
                                      'glDrawElementsInstancedBaseInstance',
                                      'glDrawElementsInstancedBaseVertexBaseInstance'
                                    ],
          'GL_ARB_bindless_texture' => [
                                         'glGetImageHandleARB',
                                         'glGetTextureHandleARB',
                                         'glGetTextureSamplerHandleARB',
                                         'glGetVertexAttribLui64vARB',
                                         'glIsImageHandleResidentARB',
                                         'glIsTextureHandleResidentARB',
                                         'glMakeImageHandleNonResidentARB',
                                         'glMakeImageHandleResidentARB',
                                         'glMakeTextureHandleNonResidentARB',
                                         'glMakeTextureHandleResidentARB',
                                         'glProgramUniformHandleui64ARB',
                                         'glProgramUniformHandleui64vARB',
                                         'glUniformHandleui64ARB',
                                         'glUniformHandleui64vARB',
                                         'glVertexAttribL1ui64ARB',
                                         'glVertexAttribL1ui64vARB'
                                       ],
          'GL_ARB_blend_func_extended' => [
                                            'glBindFragDataLocationIndexed',
                                            'glGetFragDataIndex'
                                          ],
          'GL_ARB_buffer_storage' => [
                                       'glBufferStorage',
                                       'glNamedBufferStorageEXT'
                                     ],
          'GL_ARB_cl_event' => [
                                 'glCreateSyncFromCLeventARB'
                               ],
          'GL_ARB_clear_buffer_object' => [
                                            'glClearBufferData',
                                            'glClearBufferSubData',
                                            'glClearNamedBufferDataEXT',
                                            'glClearNamedBufferSubDataEXT'
                                          ],
          'GL_ARB_clear_texture' => [
                                      'glClearTexImage',
                                      'glClearTexSubImage'
                                    ],
          'GL_ARB_clip_control' => [
                                     'glClipControl'
                                   ],
          'GL_ARB_color_buffer_float' => [
                                           'glClampColorARB'
                                         ],
          'GL_ARB_compute_shader' => [
                                       'glDispatchCompute',
                                       'glDispatchComputeIndirect'
                                     ],
          'GL_ARB_compute_variable_group_size' => [
                                                    'glDispatchComputeGroupSizeARB'
                                                  ],
          'GL_ARB_copy_buffer' => [
                                    'glCopyBufferSubData'
                                  ],
          'GL_ARB_copy_image' => [
                                   'glCopyImageSubData'
                                 ],
          'GL_ARB_debug_output' => [
                                     'glDebugMessageCallbackARB',
                                     'glDebugMessageControlARB',
                                     'glDebugMessageInsertARB',
                                     'glGetDebugMessageLogARB'
                                   ],
          'GL_ARB_direct_state_access' => [
                                            'glBindTextureUnit',
                                            'glBlitNamedFramebuffer',
                                            'glCheckNamedFramebufferStatus',
                                            'glClearNamedBufferData',
                                            'glClearNamedBufferSubData',
                                            'glClearNamedFramebufferfi',
                                            'glClearNamedFramebufferfv',
                                            'glClearNamedFramebufferiv',
                                            'glClearNamedFramebufferuiv',
                                            'glCompressedTextureSubImage1D',
                                            'glCompressedTextureSubImage2D',
                                            'glCompressedTextureSubImage3D',
                                            'glCopyNamedBufferSubData',
                                            'glCopyTextureSubImage1D',
                                            'glCopyTextureSubImage2D',
                                            'glCopyTextureSubImage3D',
                                            'glCreateBuffers',
                                            'glCreateFramebuffers',
                                            'glCreateProgramPipelines',
                                            'glCreateQueries',
                                            'glCreateRenderbuffers',
                                            'glCreateSamplers',
                                            'glCreateTextures',
                                            'glCreateTransformFeedbacks',
                                            'glCreateVertexArrays',
                                            'glDisableVertexArrayAttrib',
                                            'glEnableVertexArrayAttrib',
                                            'glFlushMappedNamedBufferRange',
                                            'glGenerateTextureMipmap',
                                            'glGetCompressedTextureImage',
                                            'glGetNamedBufferParameteri64v',
                                            'glGetNamedBufferParameteriv',
                                            'glGetNamedBufferPointerv',
                                            'glGetNamedBufferSubData',
                                            'glGetNamedFramebufferAttachmentParameteriv',
                                            'glGetNamedFramebufferParameteriv',
                                            'glGetNamedRenderbufferParameteriv',
                                            'glGetQueryBufferObjecti64v',
                                            'glGetQueryBufferObjectiv',
                                            'glGetQueryBufferObjectui64v',
                                            'glGetQueryBufferObjectuiv',
                                            'glGetTextureImage',
                                            'glGetTextureLevelParameterfv',
                                            'glGetTextureLevelParameteriv',
                                            'glGetTextureParameterIiv',
                                            'glGetTextureParameterIuiv',
                                            'glGetTextureParameterfv',
                                            'glGetTextureParameteriv',
                                            'glGetTransformFeedbacki64_v',
                                            'glGetTransformFeedbacki_v',
                                            'glGetTransformFeedbackiv',
                                            'glGetVertexArrayIndexed64iv',
                                            'glGetVertexArrayIndexediv',
                                            'glGetVertexArrayiv',
                                            'glInvalidateNamedFramebufferData',
                                            'glInvalidateNamedFramebufferSubData',
                                            'glMapNamedBuffer',
                                            'glMapNamedBufferRange',
                                            'glNamedBufferData',
                                            'glNamedBufferStorage',
                                            'glNamedBufferSubData',
                                            'glNamedFramebufferDrawBuffer',
                                            'glNamedFramebufferDrawBuffers',
                                            'glNamedFramebufferParameteri',
                                            'glNamedFramebufferReadBuffer',
                                            'glNamedFramebufferRenderbuffer',
                                            'glNamedFramebufferTexture',
                                            'glNamedFramebufferTextureLayer',
                                            'glNamedRenderbufferStorage',
                                            'glNamedRenderbufferStorageMultisample',
                                            'glTextureBuffer',
                                            'glTextureBufferRange',
                                            'glTextureParameterIiv',
                                            'glTextureParameterIuiv',
                                            'glTextureParameterf',
                                            'glTextureParameterfv',
                                            'glTextureParameteri',
                                            'glTextureParameteriv',
                                            'glTextureStorage1D',
                                            'glTextureStorage2D',
                                            'glTextureStorage2DMultisample',
                                            'glTextureStorage3D',
                                            'glTextureStorage3DMultisample',
                                            'glTextureSubImage1D',
                                            'glTextureSubImage2D',
                                            'glTextureSubImage3D',
                                            'glTransformFeedbackBufferBase',
                                            'glTransformFeedbackBufferRange',
                                            'glUnmapNamedBuffer',
                                            'glVertexArrayAttribBinding',
                                            'glVertexArrayAttribFormat',
                                            'glVertexArrayAttribIFormat',
                                            'glVertexArrayAttribLFormat',
                                            'glVertexArrayBindingDivisor',
                                            'glVertexArrayElementBuffer',
                                            'glVertexArrayVertexBuffer',
                                            'glVertexArrayVertexBuffers'
                                          ],
          'GL_ARB_draw_buffers' => [
                                     'glDrawBuffersARB'
                                   ],
          'GL_ARB_draw_buffers_blend' => [
                                           'glBlendEquationSeparateiARB',
                                           'glBlendEquationiARB',
                                           'glBlendFuncSeparateiARB',
                                           'glBlendFunciARB'
                                         ],
          'GL_ARB_draw_elements_base_vertex' => [
                                                  'glDrawElementsBaseVertex',
                                                  'glDrawElementsInstancedBaseVertex',
                                                  'glDrawRangeElementsBaseVertex',
                                                  'glMultiDrawElementsBaseVertex'
                                                ],
          'GL_ARB_draw_indirect' => [
                                      'glDrawArraysIndirect',
                                      'glDrawElementsIndirect'
                                    ],
          'GL_ARB_framebuffer_no_attachments' => [
                                                   'glFramebufferParameteri',
                                                   'glGetFramebufferParameteriv',
                                                   'glGetNamedFramebufferParameterivEXT',
                                                   'glNamedFramebufferParameteriEXT'
                                                 ],
          'GL_ARB_framebuffer_object' => [
                                           'glBindFramebuffer',
                                           'glBindRenderbuffer',
                                           'glBlitFramebuffer',
                                           'glCheckFramebufferStatus',
                                           'glDeleteFramebuffers',
                                           'glDeleteRenderbuffers',
                                           'glFramebufferRenderbuffer',
                                           'glFramebufferTexture1D',
                                           'glFramebufferTexture2D',
                                           'glFramebufferTexture3D',
                                           'glFramebufferTextureLayer',
                                           'glGenFramebuffers',
                                           'glGenRenderbuffers',
                                           'glGenerateMipmap',
                                           'glGetFramebufferAttachmentParameteriv',
                                           'glGetRenderbufferParameteriv',
                                           'glIsFramebuffer',
                                           'glIsRenderbuffer',
                                           'glRenderbufferStorage',
                                           'glRenderbufferStorageMultisample'
                                         ],
          'GL_ARB_geometry_shader4' => [
                                         'glFramebufferTextureARB',
                                         'glFramebufferTextureFaceARB',
                                         'glFramebufferTextureLayerARB',
                                         'glProgramParameteriARB'
                                       ],
          'GL_ARB_get_program_binary' => [
                                           'glGetProgramBinary',
                                           'glProgramBinary',
                                           'glProgramParameteri'
                                         ],
          'GL_ARB_get_texture_sub_image' => [
                                              'glGetCompressedTextureSubImage',
                                              'glGetTextureSubImage'
                                            ],
          'GL_ARB_gl_spirv' => [
                                 'glSpecializeShaderARB'
                               ],
          'GL_ARB_gpu_shader_fp64' => [
                                        'glGetUniformdv',
                                        'glUniform1d',
                                        'glUniform1dv',
                                        'glUniform2d',
                                        'glUniform2dv',
                                        'glUniform3d',
                                        'glUniform3dv',
                                        'glUniform4d',
                                        'glUniform4dv',
                                        'glUniformMatrix2dv',
                                        'glUniformMatrix2x3dv',
                                        'glUniformMatrix2x4dv',
                                        'glUniformMatrix3dv',
                                        'glUniformMatrix3x2dv',
                                        'glUniformMatrix3x4dv',
                                        'glUniformMatrix4dv',
                                        'glUniformMatrix4x2dv',
                                        'glUniformMatrix4x3dv'
                                      ],
          'GL_ARB_gpu_shader_int64' => [
                                         'glGetUniformi64vARB',
                                         'glGetUniformui64vARB',
                                         'glGetnUniformi64vARB',
                                         'glGetnUniformui64vARB',
                                         'glProgramUniform1i64ARB',
                                         'glProgramUniform1i64vARB',
                                         'glProgramUniform1ui64ARB',
                                         'glProgramUniform1ui64vARB',
                                         'glProgramUniform2i64ARB',
                                         'glProgramUniform2i64vARB',
                                         'glProgramUniform2ui64ARB',
                                         'glProgramUniform2ui64vARB',
                                         'glProgramUniform3i64ARB',
                                         'glProgramUniform3i64vARB',
                                         'glProgramUniform3ui64ARB',
                                         'glProgramUniform3ui64vARB',
                                         'glProgramUniform4i64ARB',
                                         'glProgramUniform4i64vARB',
                                         'glProgramUniform4ui64ARB',
                                         'glProgramUniform4ui64vARB',
                                         'glUniform1i64ARB',
                                         'glUniform1i64vARB',
                                         'glUniform1ui64ARB',
                                         'glUniform1ui64vARB',
                                         'glUniform2i64ARB',
                                         'glUniform2i64vARB',
                                         'glUniform2ui64ARB',
                                         'glUniform2ui64vARB',
                                         'glUniform3i64ARB',
                                         'glUniform3i64vARB',
                                         'glUniform3ui64ARB',
                                         'glUniform3ui64vARB',
                                         'glUniform4i64ARB',
                                         'glUniform4i64vARB',
                                         'glUniform4ui64ARB',
                                         'glUniform4ui64vARB'
                                       ],
          'GL_ARB_imaging' => [
                                'glColorSubTable',
                                'glColorTable',
                                'glColorTableParameterfv',
                                'glColorTableParameteriv',
                                'glConvolutionFilter1D',
                                'glConvolutionFilter2D',
                                'glConvolutionParameterf',
                                'glConvolutionParameterfv',
                                'glConvolutionParameteri',
                                'glConvolutionParameteriv',
                                'glCopyColorSubTable',
                                'glCopyColorTable',
                                'glCopyConvolutionFilter1D',
                                'glCopyConvolutionFilter2D',
                                'glGetColorTable',
                                'glGetColorTableParameterfv',
                                'glGetColorTableParameteriv',
                                'glGetConvolutionFilter',
                                'glGetConvolutionParameterfv',
                                'glGetConvolutionParameteriv',
                                'glGetHistogram',
                                'glGetHistogramParameterfv',
                                'glGetHistogramParameteriv',
                                'glGetMinmax',
                                'glGetMinmaxParameterfv',
                                'glGetMinmaxParameteriv',
                                'glGetSeparableFilter',
                                'glHistogram',
                                'glMinmax',
                                'glResetHistogram',
                                'glResetMinmax',
                                'glSeparableFilter2D'
                              ],
          'GL_ARB_indirect_parameters' => [
                                            'glMultiDrawArraysIndirectCountARB',
                                            'glMultiDrawElementsIndirectCountARB'
                                          ],
          'GL_ARB_instanced_arrays' => [
                                         'glDrawArraysInstancedARB',
                                         'glDrawElementsInstancedARB',
                                         'glVertexAttribDivisorARB'
                                       ],
          'GL_ARB_internalformat_query' => [
                                             'glGetInternalformativ'
                                           ],
          'GL_ARB_internalformat_query2' => [
                                              'glGetInternalformati64v'
                                            ],
          'GL_ARB_invalidate_subdata' => [
                                           'glInvalidateBufferData',
                                           'glInvalidateBufferSubData',
                                           'glInvalidateFramebuffer',
                                           'glInvalidateSubFramebuffer',
                                           'glInvalidateTexImage',
                                           'glInvalidateTexSubImage'
                                         ],
          'GL_ARB_map_buffer_range' => [
                                         'glFlushMappedBufferRange',
                                         'glMapBufferRange'
                                       ],
          'GL_ARB_matrix_palette' => [
                                       'glCurrentPaletteMatrixARB',
                                       'glMatrixIndexPointerARB',
                                       'glMatrixIndexubvARB',
                                       'glMatrixIndexuivARB',
                                       'glMatrixIndexusvARB'
                                     ],
          'GL_ARB_multi_bind' => [
                                   'glBindBuffersBase',
                                   'glBindBuffersRange',
                                   'glBindImageTextures',
                                   'glBindSamplers',
                                   'glBindTextures',
                                   'glBindVertexBuffers'
                                 ],
          'GL_ARB_multi_draw_indirect' => [
                                            'glMultiDrawArraysIndirect',
                                            'glMultiDrawElementsIndirect'
                                          ],
          'GL_ARB_multisample' => [
                                    'glSampleCoverageARB'
                                  ],
          'GL_ARB_multitexture' => [
                                     'glActiveTextureARB',
                                     'glClientActiveTextureARB',
                                     'glMultiTexCoord1dARB',
                                     'glMultiTexCoord1dvARB',
                                     'glMultiTexCoord1fARB',
                                     'glMultiTexCoord1fvARB',
                                     'glMultiTexCoord1iARB',
                                     'glMultiTexCoord1ivARB',
                                     'glMultiTexCoord1sARB',
                                     'glMultiTexCoord1svARB',
                                     'glMultiTexCoord2dARB',
                                     'glMultiTexCoord2dvARB',
                                     'glMultiTexCoord2fARB',
                                     'glMultiTexCoord2fvARB',
                                     'glMultiTexCoord2iARB',
                                     'glMultiTexCoord2ivARB',
                                     'glMultiTexCoord2sARB',
                                     'glMultiTexCoord2svARB',
                                     'glMultiTexCoord3dARB',
                                     'glMultiTexCoord3dvARB',
                                     'glMultiTexCoord3fARB',
                                     'glMultiTexCoord3fvARB',
                                     'glMultiTexCoord3iARB',
                                     'glMultiTexCoord3ivARB',
                                     'glMultiTexCoord3sARB',
                                     'glMultiTexCoord3svARB',
                                     'glMultiTexCoord4dARB',
                                     'glMultiTexCoord4dvARB',
                                     'glMultiTexCoord4fARB',
                                     'glMultiTexCoord4fvARB',
                                     'glMultiTexCoord4iARB',
                                     'glMultiTexCoord4ivARB',
                                     'glMultiTexCoord4sARB',
                                     'glMultiTexCoord4svARB'
                                   ],
          'GL_ARB_occlusion_query' => [
                                        'glBeginQueryARB',
                                        'glDeleteQueriesARB',
                                        'glEndQueryARB',
                                        'glGenQueriesARB',
                                        'glGetQueryObjectivARB',
                                        'glGetQueryObjectuivARB',
                                        'glGetQueryivARB',
                                        'glIsQueryARB'
                                      ],
          'GL_ARB_parallel_shader_compile' => [
                                                'glMaxShaderCompilerThreadsARB'
                                              ],
          'GL_ARB_point_parameters' => [
                                         'glPointParameterfARB',
                                         'glPointParameterfvARB'
                                       ],
          'GL_ARB_program_interface_query' => [
                                                'glGetProgramInterfaceiv',
                                                'glGetProgramResourceIndex',
                                                'glGetProgramResourceLocation',
                                                'glGetProgramResourceLocationIndex',
                                                'glGetProgramResourceName',
                                                'glGetProgramResourceiv'
                                              ],
          'GL_ARB_provoking_vertex' => [
                                         'glProvokingVertex'
                                       ],
          'GL_ARB_robustness' => [
                                   'glGetGraphicsResetStatusARB',
                                   'glGetnColorTableARB',
                                   'glGetnCompressedTexImageARB',
                                   'glGetnConvolutionFilterARB',
                                   'glGetnHistogramARB',
                                   'glGetnMapdvARB',
                                   'glGetnMapfvARB',
                                   'glGetnMapivARB',
                                   'glGetnMinmaxARB',
                                   'glGetnPixelMapfvARB',
                                   'glGetnPixelMapuivARB',
                                   'glGetnPixelMapusvARB',
                                   'glGetnPolygonStippleARB',
                                   'glGetnSeparableFilterARB',
                                   'glGetnTexImageARB',
                                   'glGetnUniformdvARB',
                                   'glGetnUniformfvARB',
                                   'glGetnUniformivARB',
                                   'glGetnUniformuivARB',
                                   'glReadnPixelsARB'
                                 ],
          'GL_ARB_sample_locations' => [
                                         'glFramebufferSampleLocationsfvARB',
                                         'glNamedFramebufferSampleLocationsfvARB'
                                       ],
          'GL_ARB_sample_shading' => [
                                       'glMinSampleShadingARB'
                                     ],
          'GL_ARB_sampler_objects' => [
                                        'glBindSampler',
                                        'glDeleteSamplers',
                                        'glGenSamplers',
                                        'glGetSamplerParameterIiv',
                                        'glGetSamplerParameterIuiv',
                                        'glGetSamplerParameterfv',
                                        'glGetSamplerParameteriv',
                                        'glIsSampler',
                                        'glSamplerParameterIiv',
                                        'glSamplerParameterIuiv',
                                        'glSamplerParameterf',
                                        'glSamplerParameterfv',
                                        'glSamplerParameteri',
                                        'glSamplerParameteriv'
                                      ],
          'GL_ARB_separate_shader_objects' => [
                                                'glActiveShaderProgram',
                                                'glBindProgramPipeline',
                                                'glCreateShaderProgramv',
                                                'glDeleteProgramPipelines',
                                                'glGenProgramPipelines',
                                                'glGetProgramPipelineInfoLog',
                                                'glGetProgramPipelineiv',
                                                'glIsProgramPipeline',
                                                'glProgramUniform1d',
                                                'glProgramUniform1dv',
                                                'glProgramUniform1f',
                                                'glProgramUniform1fv',
                                                'glProgramUniform1i',
                                                'glProgramUniform1iv',
                                                'glProgramUniform1ui',
                                                'glProgramUniform1uiv',
                                                'glProgramUniform2d',
                                                'glProgramUniform2dv',
                                                'glProgramUniform2f',
                                                'glProgramUniform2fv',
                                                'glProgramUniform2i',
                                                'glProgramUniform2iv',
                                                'glProgramUniform2ui',
                                                'glProgramUniform2uiv',
                                                'glProgramUniform3d',
                                                'glProgramUniform3dv',
                                                'glProgramUniform3f',
                                                'glProgramUniform3fv',
                                                'glProgramUniform3i',
                                                'glProgramUniform3iv',
                                                'glProgramUniform3ui',
                                                'glProgramUniform3uiv',
                                                'glProgramUniform4d',
                                                'glProgramUniform4dv',
                                                'glProgramUniform4f',
                                                'glProgramUniform4fv',
                                                'glProgramUniform4i',
                                                'glProgramUniform4iv',
                                                'glProgramUniform4ui',
                                                'glProgramUniform4uiv',
                                                'glProgramUniformMatrix2dv',
                                                'glProgramUniformMatrix2fv',
                                                'glProgramUniformMatrix2x3dv',
                                                'glProgramUniformMatrix2x3fv',
                                                'glProgramUniformMatrix2x4dv',
                                                'glProgramUniformMatrix2x4fv',
                                                'glProgramUniformMatrix3dv',
                                                'glProgramUniformMatrix3fv',
                                                'glProgramUniformMatrix3x2dv',
                                                'glProgramUniformMatrix3x2fv',
                                                'glProgramUniformMatrix3x4dv',
                                                'glProgramUniformMatrix3x4fv',
                                                'glProgramUniformMatrix4dv',
                                                'glProgramUniformMatrix4fv',
                                                'glProgramUniformMatrix4x2dv',
                                                'glProgramUniformMatrix4x2fv',
                                                'glProgramUniformMatrix4x3dv',
                                                'glProgramUniformMatrix4x3fv',
                                                'glUseProgramStages',
                                                'glValidateProgramPipeline'
                                              ],
          'GL_ARB_shader_atomic_counters' => [
                                               'glGetActiveAtomicCounterBufferiv'
                                             ],
          'GL_ARB_shader_image_load_store' => [
                                                'glBindImageTexture',
                                                'glMemoryBarrier'
                                              ],
          'GL_ARB_shader_objects' => [
                                       'glAttachObjectARB',
                                       'glCompileShaderARB',
                                       'glCreateProgramObjectARB',
                                       'glCreateShaderObjectARB',
                                       'glDeleteObjectARB',
                                       'glDetachObjectARB',
                                       'glGetActiveUniformARB',
                                       'glGetAttachedObjectsARB',
                                       'glGetHandleARB',
                                       'glGetInfoLogARB',
                                       'glGetObjectParameterfvARB',
                                       'glGetObjectParameterivARB',
                                       'glGetShaderSourceARB',
                                       'glGetUniformLocationARB',
                                       'glGetUniformfvARB',
                                       'glGetUniformivARB',
                                       'glLinkProgramARB',
                                       'glShaderSourceARB',
                                       'glUniform1fARB',
                                       'glUniform1fvARB',
                                       'glUniform1iARB',
                                       'glUniform1ivARB',
                                       'glUniform2fARB',
                                       'glUniform2fvARB',
                                       'glUniform2iARB',
                                       'glUniform2ivARB',
                                       'glUniform3fARB',
                                       'glUniform3fvARB',
                                       'glUniform3iARB',
                                       'glUniform3ivARB',
                                       'glUniform4fARB',
                                       'glUniform4fvARB',
                                       'glUniform4iARB',
                                       'glUniform4ivARB',
                                       'glUniformMatrix2fvARB',
                                       'glUniformMatrix3fvARB',
                                       'glUniformMatrix4fvARB',
                                       'glUseProgramObjectARB',
                                       'glValidateProgramARB'
                                     ],
          'GL_ARB_shader_storage_buffer_object' => [
                                                     'glShaderStorageBlockBinding'
                                                   ],
          'GL_ARB_shader_subroutine' => [
                                          'glGetActiveSubroutineName',
                                          'glGetActiveSubroutineUniformName',
                                          'glGetActiveSubroutineUniformiv',
                                          'glGetProgramStageiv',
                                          'glGetSubroutineIndex',
                                          'glGetSubroutineUniformLocation',
                                          'glGetUniformSubroutineuiv',
                                          'glUniformSubroutinesuiv'
                                        ],
          'GL_ARB_shading_language_include' => [
                                                 'glCompileShaderIncludeARB',
                                                 'glDeleteNamedStringARB',
                                                 'glGetNamedStringARB',
                                                 'glGetNamedStringivARB',
                                                 'glIsNamedStringARB',
                                                 'glNamedStringARB'
                                               ],
          'GL_ARB_sparse_buffer' => [
                                      'glBufferPageCommitmentARB'
                                    ],
          'GL_ARB_sparse_texture' => [
                                       'glTexPageCommitmentARB',
                                       'glTexturePageCommitmentEXT'
                                     ],
          'GL_ARB_sync' => [
                             'glClientWaitSync',
                             'glDeleteSync',
                             'glFenceSync',
                             'glGetInteger64v',
                             'glGetSynciv',
                             'glIsSync',
                             'glWaitSync'
                           ],
          'GL_ARB_tessellation_shader' => [
                                            'glPatchParameterfv',
                                            'glPatchParameteri'
                                          ],
          'GL_ARB_texture_barrier' => [
                                        'glTextureBarrier'
                                      ],
          'GL_ARB_texture_buffer_object' => [
                                              'glTexBufferARB'
                                            ],
          'GL_ARB_texture_buffer_range' => [
                                             'glTexBufferRange',
                                             'glTextureBufferRangeEXT'
                                           ],
          'GL_ARB_texture_compression' => [
                                            'glCompressedTexImage1DARB',
                                            'glCompressedTexImage2DARB',
                                            'glCompressedTexImage3DARB',
                                            'glCompressedTexSubImage1DARB',
                                            'glCompressedTexSubImage2DARB',
                                            'glCompressedTexSubImage3DARB',
                                            'glGetCompressedTexImageARB'
                                          ],
          'GL_ARB_texture_multisample' => [
                                            'glGetMultisamplefv',
                                            'glSampleMaski',
                                            'glTexImage2DMultisample',
                                            'glTexImage3DMultisample'
                                          ],
          'GL_ARB_texture_storage' => [
                                        'glTexStorage1D',
                                        'glTexStorage2D',
                                        'glTexStorage3D',
                                        'glTextureStorage1DEXT',
                                        'glTextureStorage2DEXT',
                                        'glTextureStorage3DEXT'
                                      ],
          'GL_ARB_texture_storage_multisample' => [
                                                    'glTexStorage2DMultisample',
                                                    'glTexStorage3DMultisample',
                                                    'glTextureStorage2DMultisampleEXT',
                                                    'glTextureStorage3DMultisampleEXT'
                                                  ],
          'GL_ARB_texture_view' => [
                                     'glTextureView'
                                   ],
          'GL_ARB_timer_query' => [
                                    'glGetQueryObjecti64v',
                                    'glGetQueryObjectui64v',
                                    'glQueryCounter'
                                  ],
          'GL_ARB_transform_feedback2' => [
                                            'glBindTransformFeedback',
                                            'glDeleteTransformFeedbacks',
                                            'glDrawTransformFeedback',
                                            'glGenTransformFeedbacks',
                                            'glIsTransformFeedback',
                                            'glPauseTransformFeedback',
                                            'glResumeTransformFeedback'
                                          ],
          'GL_ARB_transform_feedback3' => [
                                            'glBeginQueryIndexed',
                                            'glDrawTransformFeedbackStream',
                                            'glEndQueryIndexed',
                                            'glGetQueryIndexediv'
                                          ],
          'GL_ARB_transform_feedback_instanced' => [
                                                     'glDrawTransformFeedbackInstanced',
                                                     'glDrawTransformFeedbackStreamInstanced'
                                                   ],
          'GL_ARB_transpose_matrix' => [
                                         'glLoadTransposeMatrixdARB',
                                         'glLoadTransposeMatrixfARB',
                                         'glMultTransposeMatrixdARB',
                                         'glMultTransposeMatrixfARB'
                                       ],
          'GL_ARB_uniform_buffer_object' => [
                                              'glBindBufferBase',
                                              'glBindBufferRange',
                                              'glGetActiveUniformBlockName',
                                              'glGetActiveUniformBlockiv',
                                              'glGetActiveUniformName',
                                              'glGetActiveUniformsiv',
                                              'glGetIntegeri_v',
                                              'glGetUniformBlockIndex',
                                              'glGetUniformIndices',
                                              'glUniformBlockBinding'
                                            ],
          'GL_ARB_vertex_array_object' => [
                                            'glBindVertexArray',
                                            'glDeleteVertexArrays',
                                            'glGenVertexArrays',
                                            'glIsVertexArray'
                                          ],
          'GL_ARB_vertex_attrib_64bit' => [
                                            'glGetVertexAttribLdv',
                                            'glVertexAttribL1d',
                                            'glVertexAttribL1dv',
                                            'glVertexAttribL2d',
                                            'glVertexAttribL2dv',
                                            'glVertexAttribL3d',
                                            'glVertexAttribL3dv',
                                            'glVertexAttribL4d',
                                            'glVertexAttribL4dv',
                                            'glVertexAttribLPointer'
                                          ],
          'GL_ARB_vertex_attrib_binding' => [
                                              'glBindVertexBuffer',
                                              'glVertexArrayBindVertexBufferEXT',
                                              'glVertexArrayVertexAttribBindingEXT',
                                              'glVertexArrayVertexAttribFormatEXT',
                                              'glVertexArrayVertexAttribIFormatEXT',
                                              'glVertexArrayVertexAttribLFormatEXT',
                                              'glVertexArrayVertexBindingDivisorEXT',
                                              'glVertexAttribBinding',
                                              'glVertexAttribFormat',
                                              'glVertexAttribIFormat',
                                              'glVertexAttribLFormat',
                                              'glVertexBindingDivisor'
                                            ],
          'GL_ARB_vertex_blend' => [
                                     'glVertexBlendARB',
                                     'glWeightPointerARB',
                                     'glWeightbvARB',
                                     'glWeightdvARB',
                                     'glWeightfvARB',
                                     'glWeightivARB',
                                     'glWeightsvARB',
                                     'glWeightubvARB',
                                     'glWeightuivARB',
                                     'glWeightusvARB'
                                   ],
          'GL_ARB_vertex_buffer_object' => [
                                             'glBindBufferARB',
                                             'glBufferDataARB',
                                             'glBufferSubDataARB',
                                             'glDeleteBuffersARB',
                                             'glGenBuffersARB',
                                             'glGetBufferParameterivARB',
                                             'glGetBufferPointervARB',
                                             'glGetBufferSubDataARB',
                                             'glIsBufferARB',
                                             'glMapBufferARB',
                                             'glUnmapBufferARB'
                                           ],
          'GL_ARB_vertex_program' => [
                                       'glBindProgramARB',
                                       'glDeleteProgramsARB',
                                       'glDisableVertexAttribArrayARB',
                                       'glEnableVertexAttribArrayARB',
                                       'glGenProgramsARB',
                                       'glGetProgramEnvParameterdvARB',
                                       'glGetProgramEnvParameterfvARB',
                                       'glGetProgramLocalParameterdvARB',
                                       'glGetProgramLocalParameterfvARB',
                                       'glGetProgramStringARB',
                                       'glGetProgramivARB',
                                       'glGetVertexAttribPointervARB',
                                       'glGetVertexAttribdvARB',
                                       'glGetVertexAttribfvARB',
                                       'glGetVertexAttribivARB',
                                       'glIsProgramARB',
                                       'glProgramEnvParameter4dARB',
                                       'glProgramEnvParameter4dvARB',
                                       'glProgramEnvParameter4fARB',
                                       'glProgramEnvParameter4fvARB',
                                       'glProgramLocalParameter4dARB',
                                       'glProgramLocalParameter4dvARB',
                                       'glProgramLocalParameter4fARB',
                                       'glProgramLocalParameter4fvARB',
                                       'glProgramStringARB',
                                       'glVertexAttrib1dARB',
                                       'glVertexAttrib1dvARB',
                                       'glVertexAttrib1fARB',
                                       'glVertexAttrib1fvARB',
                                       'glVertexAttrib1sARB',
                                       'glVertexAttrib1svARB',
                                       'glVertexAttrib2dARB',
                                       'glVertexAttrib2dvARB',
                                       'glVertexAttrib2fARB',
                                       'glVertexAttrib2fvARB',
                                       'glVertexAttrib2sARB',
                                       'glVertexAttrib2svARB',
                                       'glVertexAttrib3dARB',
                                       'glVertexAttrib3dvARB',
                                       'glVertexAttrib3fARB',
                                       'glVertexAttrib3fvARB',
                                       'glVertexAttrib3sARB',
                                       'glVertexAttrib3svARB',
                                       'glVertexAttrib4NbvARB',
                                       'glVertexAttrib4NivARB',
                                       'glVertexAttrib4NsvARB',
                                       'glVertexAttrib4NubARB',
                                       'glVertexAttrib4NubvARB',
                                       'glVertexAttrib4NuivARB',
                                       'glVertexAttrib4NusvARB',
                                       'glVertexAttrib4bvARB',
                                       'glVertexAttrib4dARB',
                                       'glVertexAttrib4dvARB',
                                       'glVertexAttrib4fARB',
                                       'glVertexAttrib4fvARB',
                                       'glVertexAttrib4ivARB',
                                       'glVertexAttrib4sARB',
                                       'glVertexAttrib4svARB',
                                       'glVertexAttrib4ubvARB',
                                       'glVertexAttrib4uivARB',
                                       'glVertexAttrib4usvARB',
                                       'glVertexAttribPointerARB'
                                     ],
          'GL_ARB_vertex_shader' => [
                                      'glBindAttribLocationARB',
                                      'glGetActiveAttribARB',
                                      'glGetAttribLocationARB'
                                    ],
          'GL_ARB_vertex_type_2_10_10_10_rev' => [
                                                   'glColorP3ui',
                                                   'glColorP3uiv',
                                                   'glColorP4ui',
                                                   'glColorP4uiv',
                                                   'glMultiTexCoordP1ui',
                                                   'glMultiTexCoordP1uiv',
                                                   'glMultiTexCoordP2ui',
                                                   'glMultiTexCoordP2uiv',
                                                   'glMultiTexCoordP3ui',
                                                   'glMultiTexCoordP3uiv',
                                                   'glMultiTexCoordP4ui',
                                                   'glMultiTexCoordP4uiv',
                                                   'glNormalP3ui',
                                                   'glNormalP3uiv',
                                                   'glSecondaryColorP3ui',
                                                   'glSecondaryColorP3uiv',
                                                   'glTexCoordP1ui',
                                                   'glTexCoordP1uiv',
                                                   'glTexCoordP2ui',
                                                   'glTexCoordP2uiv',
                                                   'glTexCoordP3ui',
                                                   'glTexCoordP3uiv',
                                                   'glTexCoordP4ui',
                                                   'glTexCoordP4uiv',
                                                   'glVertexAttribP1ui',
                                                   'glVertexAttribP1uiv',
                                                   'glVertexAttribP2ui',
                                                   'glVertexAttribP2uiv',
                                                   'glVertexAttribP3ui',
                                                   'glVertexAttribP3uiv',
                                                   'glVertexAttribP4ui',
                                                   'glVertexAttribP4uiv',
                                                   'glVertexP2ui',
                                                   'glVertexP2uiv',
                                                   'glVertexP3ui',
                                                   'glVertexP3uiv',
                                                   'glVertexP4ui',
                                                   'glVertexP4uiv'
                                                 ],
          'GL_ARB_viewport_array' => [
                                       'glDepthRangeArrayv',
                                       'glDepthRangeIndexed',
                                       'glGetDoublei_v',
                                       'glGetFloati_v',
                                       'glScissorArrayv',
                                       'glScissorIndexed',
                                       'glScissorIndexedv',
                                       'glViewportArrayv',
                                       'glViewportIndexedf',
                                       'glViewportIndexedfv'
                                     ],
          'GL_ARB_window_pos' => [
                                   'glWindowPos2dARB',
                                   'glWindowPos2dvARB',
                                   'glWindowPos2fARB',
                                   'glWindowPos2fvARB',
                                   'glWindowPos2iARB',
                                   'glWindowPos2ivARB',
                                   'glWindowPos2sARB',
                                   'glWindowPos2svARB',
                                   'glWindowPos3dARB',
                                   'glWindowPos3dvARB',
                                   'glWindowPos3fARB',
                                   'glWindowPos3fvARB',
                                   'glWindowPos3iARB',
                                   'glWindowPos3ivARB',
                                   'glWindowPos3sARB',
                                   'glWindowPos3svARB'
                                 ],
          'GL_ATI_draw_buffers' => [
                                     'glDrawBuffersATI'
                                   ],
          'GL_ATI_element_array' => [
                                      'glDrawElementArrayATI',
                                      'glDrawRangeElementArrayATI',
                                      'glElementPointerATI'
                                    ],
          'GL_ATI_envmap_bumpmap' => [
                                       'glGetTexBumpParameterfvATI',
                                       'glGetTexBumpParameterivATI',
                                       'glTexBumpParameterfvATI',
                                       'glTexBumpParameterivATI'
                                     ],
          'GL_ATI_fragment_shader' => [
                                        'glAlphaFragmentOp1ATI',
                                        'glAlphaFragmentOp2ATI',
                                        'glAlphaFragmentOp3ATI',
                                        'glBeginFragmentShaderATI',
                                        'glBindFragmentShaderATI',
                                        'glColorFragmentOp1ATI',
                                        'glColorFragmentOp2ATI',
                                        'glColorFragmentOp3ATI',
                                        'glDeleteFragmentShaderATI',
                                        'glEndFragmentShaderATI',
                                        'glGenFragmentShadersATI',
                                        'glPassTexCoordATI',
                                        'glSampleMapATI',
                                        'glSetFragmentShaderConstantATI'
                                      ],
          'GL_ATI_map_object_buffer' => [
                                          'glMapObjectBufferATI',
                                          'glUnmapObjectBufferATI'
                                        ],
          'GL_ATI_pn_triangles' => [
                                     'glPNTrianglesfATI',
                                     'glPNTrianglesiATI'
                                   ],
          'GL_ATI_separate_stencil' => [
                                         'glStencilFuncSeparateATI',
                                         'glStencilOpSeparateATI'
                                       ],
          'GL_ATI_vertex_array_object' => [
                                            'glArrayObjectATI',
                                            'glFreeObjectBufferATI',
                                            'glGetArrayObjectfvATI',
                                            'glGetArrayObjectivATI',
                                            'glGetObjectBufferfvATI',
                                            'glGetObjectBufferivATI',
                                            'glGetVariantArrayObjectfvATI',
                                            'glGetVariantArrayObjectivATI',
                                            'glIsObjectBufferATI',
                                            'glNewObjectBufferATI',
                                            'glUpdateObjectBufferATI',
                                            'glVariantArrayObjectATI'
                                          ],
          'GL_ATI_vertex_attrib_array_object' => [
                                                   'glGetVertexAttribArrayObjectfvATI',
                                                   'glGetVertexAttribArrayObjectivATI',
                                                   'glVertexAttribArrayObjectATI'
                                                 ],
          'GL_ATI_vertex_streams' => [
                                       'glClientActiveVertexStreamATI',
                                       'glNormalStream3bATI',
                                       'glNormalStream3bvATI',
                                       'glNormalStream3dATI',
                                       'glNormalStream3dvATI',
                                       'glNormalStream3fATI',
                                       'glNormalStream3fvATI',
                                       'glNormalStream3iATI',
                                       'glNormalStream3ivATI',
                                       'glNormalStream3sATI',
                                       'glNormalStream3svATI',
                                       'glVertexBlendEnvfATI',
                                       'glVertexBlendEnviATI',
                                       'glVertexStream1dATI',
                                       'glVertexStream1dvATI',
                                       'glVertexStream1fATI',
                                       'glVertexStream1fvATI',
                                       'glVertexStream1iATI',
                                       'glVertexStream1ivATI',
                                       'glVertexStream1sATI',
                                       'glVertexStream1svATI',
                                       'glVertexStream2dATI',
                                       'glVertexStream2dvATI',
                                       'glVertexStream2fATI',
                                       'glVertexStream2fvATI',
                                       'glVertexStream2iATI',
                                       'glVertexStream2ivATI',
                                       'glVertexStream2sATI',
                                       'glVertexStream2svATI',
                                       'glVertexStream3dATI',
                                       'glVertexStream3dvATI',
                                       'glVertexStream3fATI',
                                       'glVertexStream3fvATI',
                                       'glVertexStream3iATI',
                                       'glVertexStream3ivATI',
                                       'glVertexStream3sATI',
                                       'glVertexStream3svATI',
                                       'glVertexStream4dATI',
                                       'glVertexStream4dvATI',
                                       'glVertexStream4fATI',
                                       'glVertexStream4fvATI',
                                       'glVertexStream4iATI',
                                       'glVertexStream4ivATI',
                                       'glVertexStream4sATI',
                                       'glVertexStream4svATI'
                                     ],
          'GL_EXT_bindable_uniform' => [
                                         'glGetUniformBufferSizeEXT',
                                         'glGetUniformOffsetEXT',
                                         'glUniformBufferEXT'
                                       ],
          'GL_EXT_blend_color' => [
                                    'glBlendColorEXT'
                                  ],
          'GL_EXT_blend_equation_separate' => [
                                                'glBlendEquationSeparateEXT'
                                              ],
          'GL_EXT_blend_func_separate' => [
                                            'glBlendFuncSeparateEXT'
                                          ],
          'GL_EXT_blend_minmax' => [
                                     'glBlendEquationEXT'
                                   ],
          'GL_EXT_color_subtable' => [
                                       'glColorSubTableEXT',
                                       'glCopyColorSubTableEXT'
                                     ],
          'GL_EXT_compiled_vertex_array' => [
                                              'glLockArraysEXT',
                                              'glUnlockArraysEXT'
                                            ],
          'GL_EXT_convolution' => [
                                    'glConvolutionFilter1DEXT',
                                    'glConvolutionFilter2DEXT',
                                    'glConvolutionParameterfEXT',
                                    'glConvolutionParameterfvEXT',
                                    'glConvolutionParameteriEXT',
                                    'glConvolutionParameterivEXT',
                                    'glCopyConvolutionFilter1DEXT',
                                    'glCopyConvolutionFilter2DEXT',
                                    'glGetConvolutionFilterEXT',
                                    'glGetConvolutionParameterfvEXT',
                                    'glGetConvolutionParameterivEXT',
                                    'glGetSeparableFilterEXT',
                                    'glSeparableFilter2DEXT'
                                  ],
          'GL_EXT_coordinate_frame' => [
                                         'glBinormalPointerEXT',
                                         'glTangentPointerEXT'
                                       ],
          'GL_EXT_copy_texture' => [
                                     'glCopyTexImage1DEXT',
                                     'glCopyTexImage2DEXT',
                                     'glCopyTexSubImage1DEXT',
                                     'glCopyTexSubImage2DEXT',
                                     'glCopyTexSubImage3DEXT'
                                   ],
          'GL_EXT_cull_vertex' => [
                                    'glCullParameterdvEXT',
                                    'glCullParameterfvEXT'
                                  ],
          'GL_EXT_debug_label' => [
                                    'glGetObjectLabelEXT',
                                    'glLabelObjectEXT'
                                  ],
          'GL_EXT_debug_marker' => [
                                     'glInsertEventMarkerEXT',
                                     'glPopGroupMarkerEXT',
                                     'glPushGroupMarkerEXT'
                                   ],
          'GL_EXT_depth_bounds_test' => [
                                          'glDepthBoundsEXT'
                                        ],
          'GL_EXT_direct_state_access' => [
                                            'glBindMultiTextureEXT',
                                            'glCheckNamedFramebufferStatusEXT',
                                            'glClientAttribDefaultEXT',
                                            'glCompressedMultiTexImage1DEXT',
                                            'glCompressedMultiTexImage2DEXT',
                                            'glCompressedMultiTexImage3DEXT',
                                            'glCompressedMultiTexSubImage1DEXT',
                                            'glCompressedMultiTexSubImage2DEXT',
                                            'glCompressedMultiTexSubImage3DEXT',
                                            'glCompressedTextureImage1DEXT',
                                            'glCompressedTextureImage2DEXT',
                                            'glCompressedTextureImage3DEXT',
                                            'glCompressedTextureSubImage1DEXT',
                                            'glCompressedTextureSubImage2DEXT',
                                            'glCompressedTextureSubImage3DEXT',
                                            'glCopyMultiTexImage1DEXT',
                                            'glCopyMultiTexImage2DEXT',
                                            'glCopyMultiTexSubImage1DEXT',
                                            'glCopyMultiTexSubImage2DEXT',
                                            'glCopyMultiTexSubImage3DEXT',
                                            'glCopyTextureImage1DEXT',
                                            'glCopyTextureImage2DEXT',
                                            'glCopyTextureSubImage1DEXT',
                                            'glCopyTextureSubImage2DEXT',
                                            'glCopyTextureSubImage3DEXT',
                                            'glDisableClientStateIndexedEXT',
                                            'glDisableClientStateiEXT',
                                            'glDisableVertexArrayAttribEXT',
                                            'glDisableVertexArrayEXT',
                                            'glEnableClientStateIndexedEXT',
                                            'glEnableClientStateiEXT',
                                            'glEnableVertexArrayAttribEXT',
                                            'glEnableVertexArrayEXT',
                                            'glFlushMappedNamedBufferRangeEXT',
                                            'glFramebufferDrawBufferEXT',
                                            'glFramebufferDrawBuffersEXT',
                                            'glFramebufferReadBufferEXT',
                                            'glGenerateMultiTexMipmapEXT',
                                            'glGenerateTextureMipmapEXT',
                                            'glGetCompressedMultiTexImageEXT',
                                            'glGetCompressedTextureImageEXT',
                                            'glGetDoubleIndexedvEXT',
                                            'glGetDoublei_vEXT',
                                            'glGetFloatIndexedvEXT',
                                            'glGetFloati_vEXT',
                                            'glGetFramebufferParameterivEXT',
                                            'glGetMultiTexEnvfvEXT',
                                            'glGetMultiTexEnvivEXT',
                                            'glGetMultiTexGendvEXT',
                                            'glGetMultiTexGenfvEXT',
                                            'glGetMultiTexGenivEXT',
                                            'glGetMultiTexImageEXT',
                                            'glGetMultiTexLevelParameterfvEXT',
                                            'glGetMultiTexLevelParameterivEXT',
                                            'glGetMultiTexParameterIivEXT',
                                            'glGetMultiTexParameterIuivEXT',
                                            'glGetMultiTexParameterfvEXT',
                                            'glGetMultiTexParameterivEXT',
                                            'glGetNamedBufferParameterivEXT',
                                            'glGetNamedBufferPointervEXT',
                                            'glGetNamedBufferSubDataEXT',
                                            'glGetNamedFramebufferAttachmentParameterivEXT',
                                            'glGetNamedProgramLocalParameterIivEXT',
                                            'glGetNamedProgramLocalParameterIuivEXT',
                                            'glGetNamedProgramLocalParameterdvEXT',
                                            'glGetNamedProgramLocalParameterfvEXT',
                                            'glGetNamedProgramStringEXT',
                                            'glGetNamedProgramivEXT',
                                            'glGetNamedRenderbufferParameterivEXT',
                                            'glGetPointerIndexedvEXT',
                                            'glGetPointeri_vEXT',
                                            'glGetTextureImageEXT',
                                            'glGetTextureLevelParameterfvEXT',
                                            'glGetTextureLevelParameterivEXT',
                                            'glGetTextureParameterIivEXT',
                                            'glGetTextureParameterIuivEXT',
                                            'glGetTextureParameterfvEXT',
                                            'glGetTextureParameterivEXT',
                                            'glGetVertexArrayIntegeri_vEXT',
                                            'glGetVertexArrayIntegervEXT',
                                            'glGetVertexArrayPointeri_vEXT',
                                            'glGetVertexArrayPointervEXT',
                                            'glMapNamedBufferEXT',
                                            'glMapNamedBufferRangeEXT',
                                            'glMatrixFrustumEXT',
                                            'glMatrixLoadIdentityEXT',
                                            'glMatrixLoadTransposedEXT',
                                            'glMatrixLoadTransposefEXT',
                                            'glMatrixLoaddEXT',
                                            'glMatrixLoadfEXT',
                                            'glMatrixMultTransposedEXT',
                                            'glMatrixMultTransposefEXT',
                                            'glMatrixMultdEXT',
                                            'glMatrixMultfEXT',
                                            'glMatrixOrthoEXT',
                                            'glMatrixPopEXT',
                                            'glMatrixPushEXT',
                                            'glMatrixRotatedEXT',
                                            'glMatrixRotatefEXT',
                                            'glMatrixScaledEXT',
                                            'glMatrixScalefEXT',
                                            'glMatrixTranslatedEXT',
                                            'glMatrixTranslatefEXT',
                                            'glMultiTexBufferEXT',
                                            'glMultiTexCoordPointerEXT',
                                            'glMultiTexEnvfEXT',
                                            'glMultiTexEnvfvEXT',
                                            'glMultiTexEnviEXT',
                                            'glMultiTexEnvivEXT',
                                            'glMultiTexGendEXT',
                                            'glMultiTexGendvEXT',
                                            'glMultiTexGenfEXT',
                                            'glMultiTexGenfvEXT',
                                            'glMultiTexGeniEXT',
                                            'glMultiTexGenivEXT',
                                            'glMultiTexImage1DEXT',
                                            'glMultiTexImage2DEXT',
                                            'glMultiTexImage3DEXT',
                                            'glMultiTexParameterIivEXT',
                                            'glMultiTexParameterIuivEXT',
                                            'glMultiTexParameterfEXT',
                                            'glMultiTexParameterfvEXT',
                                            'glMultiTexParameteriEXT',
                                            'glMultiTexParameterivEXT',
                                            'glMultiTexRenderbufferEXT',
                                            'glMultiTexSubImage1DEXT',
                                            'glMultiTexSubImage2DEXT',
                                            'glMultiTexSubImage3DEXT',
                                            'glNamedBufferDataEXT',
                                            'glNamedBufferSubDataEXT',
                                            'glNamedCopyBufferSubDataEXT',
                                            'glNamedFramebufferRenderbufferEXT',
                                            'glNamedFramebufferTexture1DEXT',
                                            'glNamedFramebufferTexture2DEXT',
                                            'glNamedFramebufferTexture3DEXT',
                                            'glNamedFramebufferTextureEXT',
                                            'glNamedFramebufferTextureFaceEXT',
                                            'glNamedFramebufferTextureLayerEXT',
                                            'glNamedProgramLocalParameter4dEXT',
                                            'glNamedProgramLocalParameter4dvEXT',
                                            'glNamedProgramLocalParameter4fEXT',
                                            'glNamedProgramLocalParameter4fvEXT',
                                            'glNamedProgramLocalParameterI4iEXT',
                                            'glNamedProgramLocalParameterI4ivEXT',
                                            'glNamedProgramLocalParameterI4uiEXT',
                                            'glNamedProgramLocalParameterI4uivEXT',
                                            'glNamedProgramLocalParameters4fvEXT',
                                            'glNamedProgramLocalParametersI4ivEXT',
                                            'glNamedProgramLocalParametersI4uivEXT',
                                            'glNamedProgramStringEXT',
                                            'glNamedRenderbufferStorageEXT',
                                            'glNamedRenderbufferStorageMultisampleCoverageEXT',
                                            'glNamedRenderbufferStorageMultisampleEXT',
                                            'glProgramUniform1fEXT',
                                            'glProgramUniform1fvEXT',
                                            'glProgramUniform1iEXT',
                                            'glProgramUniform1ivEXT',
                                            'glProgramUniform1uiEXT',
                                            'glProgramUniform1uivEXT',
                                            'glProgramUniform2fEXT',
                                            'glProgramUniform2fvEXT',
                                            'glProgramUniform2iEXT',
                                            'glProgramUniform2ivEXT',
                                            'glProgramUniform2uiEXT',
                                            'glProgramUniform2uivEXT',
                                            'glProgramUniform3fEXT',
                                            'glProgramUniform3fvEXT',
                                            'glProgramUniform3iEXT',
                                            'glProgramUniform3ivEXT',
                                            'glProgramUniform3uiEXT',
                                            'glProgramUniform3uivEXT',
                                            'glProgramUniform4fEXT',
                                            'glProgramUniform4fvEXT',
                                            'glProgramUniform4iEXT',
                                            'glProgramUniform4ivEXT',
                                            'glProgramUniform4uiEXT',
                                            'glProgramUniform4uivEXT',
                                            'glProgramUniformMatrix2fvEXT',
                                            'glProgramUniformMatrix2x3fvEXT',
                                            'glProgramUniformMatrix2x4fvEXT',
                                            'glProgramUniformMatrix3fvEXT',
                                            'glProgramUniformMatrix3x2fvEXT',
                                            'glProgramUniformMatrix3x4fvEXT',
                                            'glProgramUniformMatrix4fvEXT',
                                            'glProgramUniformMatrix4x2fvEXT',
                                            'glProgramUniformMatrix4x3fvEXT',
                                            'glPushClientAttribDefaultEXT',
                                            'glTextureBufferEXT',
                                            'glTextureImage1DEXT',
                                            'glTextureImage2DEXT',
                                            'glTextureImage3DEXT',
                                            'glTextureParameterIivEXT',
                                            'glTextureParameterIuivEXT',
                                            'glTextureParameterfEXT',
                                            'glTextureParameterfvEXT',
                                            'glTextureParameteriEXT',
                                            'glTextureParameterivEXT',
                                            'glTextureRenderbufferEXT',
                                            'glTextureSubImage1DEXT',
                                            'glTextureSubImage2DEXT',
                                            'glTextureSubImage3DEXT',
                                            'glUnmapNamedBufferEXT',
                                            'glVertexArrayColorOffsetEXT',
                                            'glVertexArrayEdgeFlagOffsetEXT',
                                            'glVertexArrayFogCoordOffsetEXT',
                                            'glVertexArrayIndexOffsetEXT',
                                            'glVertexArrayMultiTexCoordOffsetEXT',
                                            'glVertexArrayNormalOffsetEXT',
                                            'glVertexArraySecondaryColorOffsetEXT',
                                            'glVertexArrayTexCoordOffsetEXT',
                                            'glVertexArrayVertexAttribDivisorEXT',
                                            'glVertexArrayVertexAttribIOffsetEXT',
                                            'glVertexArrayVertexAttribOffsetEXT',
                                            'glVertexArrayVertexOffsetEXT'
                                          ],
          'GL_EXT_draw_buffers2' => [
                                      'glColorMaskIndexedEXT',
                                      'glDisableIndexedEXT',
                                      'glEnableIndexedEXT',
                                      'glGetBooleanIndexedvEXT',
                                      'glGetIntegerIndexedvEXT',
                                      'glIsEnabledIndexedEXT'
                                    ],
          'GL_EXT_draw_instanced' => [
                                       'glDrawArraysInstancedEXT',
                                       'glDrawElementsInstancedEXT'
                                     ],
          'GL_EXT_draw_range_elements' => [
                                            'glDrawRangeElementsEXT'
                                          ],
          'GL_EXT_fog_coord' => [
                                  'glFogCoordPointerEXT',
                                  'glFogCoorddEXT',
                                  'glFogCoorddvEXT',
                                  'glFogCoordfEXT',
                                  'glFogCoordfvEXT'
                                ],
          'GL_EXT_fragment_lighting' => [
                                          'glFragmentColorMaterialEXT',
                                          'glFragmentLightModelfEXT',
                                          'glFragmentLightModelfvEXT',
                                          'glFragmentLightModeliEXT',
                                          'glFragmentLightModelivEXT',
                                          'glFragmentLightfEXT',
                                          'glFragmentLightfvEXT',
                                          'glFragmentLightiEXT',
                                          'glFragmentLightivEXT',
                                          'glFragmentMaterialfEXT',
                                          'glFragmentMaterialfvEXT',
                                          'glFragmentMaterialiEXT',
                                          'glFragmentMaterialivEXT',
                                          'glGetFragmentLightfvEXT',
                                          'glGetFragmentLightivEXT',
                                          'glGetFragmentMaterialfvEXT',
                                          'glGetFragmentMaterialivEXT',
                                          'glLightEnviEXT'
                                        ],
          'GL_EXT_framebuffer_blit' => [
                                         'glBlitFramebufferEXT'
                                       ],
          'GL_EXT_framebuffer_multisample' => [
                                                'glRenderbufferStorageMultisampleEXT'
                                              ],
          'GL_EXT_framebuffer_object' => [
                                           'glBindFramebufferEXT',
                                           'glBindRenderbufferEXT',
                                           'glCheckFramebufferStatusEXT',
                                           'glDeleteFramebuffersEXT',
                                           'glDeleteRenderbuffersEXT',
                                           'glFramebufferRenderbufferEXT',
                                           'glFramebufferTexture1DEXT',
                                           'glFramebufferTexture2DEXT',
                                           'glFramebufferTexture3DEXT',
                                           'glGenFramebuffersEXT',
                                           'glGenRenderbuffersEXT',
                                           'glGenerateMipmapEXT',
                                           'glGetFramebufferAttachmentParameterivEXT',
                                           'glGetRenderbufferParameterivEXT',
                                           'glIsFramebufferEXT',
                                           'glIsRenderbufferEXT',
                                           'glRenderbufferStorageEXT'
                                         ],
          'GL_EXT_geometry_shader4' => [
                                         'glFramebufferTextureEXT',
                                         'glFramebufferTextureFaceEXT',
                                         'glProgramParameteriEXT'
                                       ],
          'GL_EXT_gpu_program_parameters' => [
                                               'glProgramEnvParameters4fvEXT',
                                               'glProgramLocalParameters4fvEXT'
                                             ],
          'GL_EXT_gpu_shader4' => [
                                    'glBindFragDataLocationEXT',
                                    'glGetFragDataLocationEXT',
                                    'glGetUniformuivEXT',
                                    'glGetVertexAttribIivEXT',
                                    'glGetVertexAttribIuivEXT',
                                    'glUniform1uiEXT',
                                    'glUniform1uivEXT',
                                    'glUniform2uiEXT',
                                    'glUniform2uivEXT',
                                    'glUniform3uiEXT',
                                    'glUniform3uivEXT',
                                    'glUniform4uiEXT',
                                    'glUniform4uivEXT',
                                    'glVertexAttribI1iEXT',
                                    'glVertexAttribI1ivEXT',
                                    'glVertexAttribI1uiEXT',
                                    'glVertexAttribI1uivEXT',
                                    'glVertexAttribI2iEXT',
                                    'glVertexAttribI2ivEXT',
                                    'glVertexAttribI2uiEXT',
                                    'glVertexAttribI2uivEXT',
                                    'glVertexAttribI3iEXT',
                                    'glVertexAttribI3ivEXT',
                                    'glVertexAttribI3uiEXT',
                                    'glVertexAttribI3uivEXT',
                                    'glVertexAttribI4bvEXT',
                                    'glVertexAttribI4iEXT',
                                    'glVertexAttribI4ivEXT',
                                    'glVertexAttribI4svEXT',
                                    'glVertexAttribI4ubvEXT',
                                    'glVertexAttribI4uiEXT',
                                    'glVertexAttribI4uivEXT',
                                    'glVertexAttribI4usvEXT',
                                    'glVertexAttribIPointerEXT'
                                  ],
          'GL_EXT_histogram' => [
                                  'glGetHistogramEXT',
                                  'glGetHistogramParameterfvEXT',
                                  'glGetHistogramParameterivEXT',
                                  'glGetMinmaxEXT',
                                  'glGetMinmaxParameterfvEXT',
                                  'glGetMinmaxParameterivEXT',
                                  'glHistogramEXT',
                                  'glMinmaxEXT',
                                  'glResetHistogramEXT',
                                  'glResetMinmaxEXT'
                                ],
          'GL_EXT_index_func' => [
                                   'glIndexFuncEXT'
                                 ],
          'GL_EXT_index_material' => [
                                       'glIndexMaterialEXT'
                                     ],
          'GL_EXT_light_texture' => [
                                      'glApplyTextureEXT',
                                      'glTextureLightEXT',
                                      'glTextureMaterialEXT'
                                    ],
          'GL_EXT_multi_draw_arrays' => [
                                          'glMultiDrawArraysEXT',
                                          'glMultiDrawElementsEXT'
                                        ],
          'GL_EXT_multisample' => [
                                    'glSampleMaskEXT',
                                    'glSamplePatternEXT'
                                  ],
          'GL_EXT_paletted_texture' => [
                                         'glColorTableEXT',
                                         'glGetColorTableEXT',
                                         'glGetColorTableParameterfvEXT',
                                         'glGetColorTableParameterivEXT'
                                       ],
          'GL_EXT_pixel_transform' => [
                                        'glGetPixelTransformParameterfvEXT',
                                        'glGetPixelTransformParameterivEXT',
                                        'glPixelTransformParameterfEXT',
                                        'glPixelTransformParameterfvEXT',
                                        'glPixelTransformParameteriEXT',
                                        'glPixelTransformParameterivEXT'
                                      ],
          'GL_EXT_point_parameters' => [
                                         'glPointParameterfEXT',
                                         'glPointParameterfvEXT'
                                       ],
          'GL_EXT_polygon_offset' => [
                                       'glPolygonOffsetEXT'
                                     ],
          'GL_EXT_polygon_offset_clamp' => [
                                             'glPolygonOffsetClampEXT'
                                           ],
          'GL_EXT_provoking_vertex' => [
                                         'glProvokingVertexEXT'
                                       ],
          'GL_EXT_raster_multisample' => [
                                           'glCoverageModulationNV',
                                           'glCoverageModulationTableNV',
                                           'glGetCoverageModulationTableNV',
                                           'glRasterSamplesEXT'
                                         ],
          'GL_EXT_scene_marker' => [
                                     'glBeginSceneEXT',
                                     'glEndSceneEXT'
                                   ],
          'GL_EXT_secondary_color' => [
                                        'glSecondaryColor3bEXT',
                                        'glSecondaryColor3bvEXT',
                                        'glSecondaryColor3dEXT',
                                        'glSecondaryColor3dvEXT',
                                        'glSecondaryColor3fEXT',
                                        'glSecondaryColor3fvEXT',
                                        'glSecondaryColor3iEXT',
                                        'glSecondaryColor3ivEXT',
                                        'glSecondaryColor3sEXT',
                                        'glSecondaryColor3svEXT',
                                        'glSecondaryColor3ubEXT',
                                        'glSecondaryColor3ubvEXT',
                                        'glSecondaryColor3uiEXT',
                                        'glSecondaryColor3uivEXT',
                                        'glSecondaryColor3usEXT',
                                        'glSecondaryColor3usvEXT',
                                        'glSecondaryColorPointerEXT'
                                      ],
          'GL_EXT_separate_shader_objects' => [
                                                'glActiveProgramEXT',
                                                'glCreateShaderProgramEXT',
                                                'glUseShaderProgramEXT'
                                              ],
          'GL_EXT_shader_image_load_store' => [
                                                'glBindImageTextureEXT',
                                                'glMemoryBarrierEXT'
                                              ],
          'GL_EXT_stencil_two_side' => [
                                         'glActiveStencilFaceEXT'
                                       ],
          'GL_EXT_subtexture' => [
                                   'glTexSubImage1DEXT',
                                   'glTexSubImage2DEXT',
                                   'glTexSubImage3DEXT'
                                 ],
          'GL_EXT_texture3D' => [
                                  'glTexImage3DEXT'
                                ],
          'GL_EXT_texture_array' => [
                                      'glFramebufferTextureLayerEXT'
                                    ],
          'GL_EXT_texture_buffer_object' => [
                                              'glTexBufferEXT'
                                            ],
          'GL_EXT_texture_integer' => [
                                        'glClearColorIiEXT',
                                        'glClearColorIuiEXT',
                                        'glGetTexParameterIivEXT',
                                        'glGetTexParameterIuivEXT',
                                        'glTexParameterIivEXT',
                                        'glTexParameterIuivEXT'
                                      ],
          'GL_EXT_texture_object' => [
                                       'glAreTexturesResidentEXT',
                                       'glBindTextureEXT',
                                       'glDeleteTexturesEXT',
                                       'glGenTexturesEXT',
                                       'glIsTextureEXT',
                                       'glPrioritizeTexturesEXT'
                                     ],
          'GL_EXT_texture_perturb_normal' => [
                                               'glTextureNormalEXT'
                                             ],
          'GL_EXT_timer_query' => [
                                    'glGetQueryObjecti64vEXT',
                                    'glGetQueryObjectui64vEXT'
                                  ],
          'GL_EXT_transform_feedback' => [
                                           'glBeginTransformFeedbackEXT',
                                           'glBindBufferBaseEXT',
                                           'glBindBufferOffsetEXT',
                                           'glBindBufferRangeEXT',
                                           'glEndTransformFeedbackEXT',
                                           'glGetTransformFeedbackVaryingEXT',
                                           'glTransformFeedbackVaryingsEXT'
                                         ],
          'GL_EXT_vertex_array' => [
                                     'glArrayElementEXT',
                                     'glColorPointerEXT',
                                     'glDrawArraysEXT',
                                     'glEdgeFlagPointerEXT',
                                     'glIndexPointerEXT',
                                     'glNormalPointerEXT',
                                     'glTexCoordPointerEXT',
                                     'glVertexPointerEXT'
                                   ],
          'GL_EXT_vertex_attrib_64bit' => [
                                            'glGetVertexAttribLdvEXT',
                                            'glVertexArrayVertexAttribLOffsetEXT',
                                            'glVertexAttribL1dEXT',
                                            'glVertexAttribL1dvEXT',
                                            'glVertexAttribL2dEXT',
                                            'glVertexAttribL2dvEXT',
                                            'glVertexAttribL3dEXT',
                                            'glVertexAttribL3dvEXT',
                                            'glVertexAttribL4dEXT',
                                            'glVertexAttribL4dvEXT',
                                            'glVertexAttribLPointerEXT'
                                          ],
          'GL_EXT_vertex_shader' => [
                                      'glBeginVertexShaderEXT',
                                      'glBindLightParameterEXT',
                                      'glBindMaterialParameterEXT',
                                      'glBindParameterEXT',
                                      'glBindTexGenParameterEXT',
                                      'glBindTextureUnitParameterEXT',
                                      'glBindVertexShaderEXT',
                                      'glDeleteVertexShaderEXT',
                                      'glDisableVariantClientStateEXT',
                                      'glEnableVariantClientStateEXT',
                                      'glEndVertexShaderEXT',
                                      'glExtractComponentEXT',
                                      'glGenSymbolsEXT',
                                      'glGenVertexShadersEXT',
                                      'glGetInvariantBooleanvEXT',
                                      'glGetInvariantFloatvEXT',
                                      'glGetInvariantIntegervEXT',
                                      'glGetLocalConstantBooleanvEXT',
                                      'glGetLocalConstantFloatvEXT',
                                      'glGetLocalConstantIntegervEXT',
                                      'glGetVariantBooleanvEXT',
                                      'glGetVariantFloatvEXT',
                                      'glGetVariantIntegervEXT',
                                      'glGetVariantPointervEXT',
                                      'glInsertComponentEXT',
                                      'glIsVariantEnabledEXT',
                                      'glSetInvariantEXT',
                                      'glSetLocalConstantEXT',
                                      'glShaderOp1EXT',
                                      'glShaderOp2EXT',
                                      'glShaderOp3EXT',
                                      'glSwizzleEXT',
                                      'glVariantPointerEXT',
                                      'glVariantbvEXT',
                                      'glVariantdvEXT',
                                      'glVariantfvEXT',
                                      'glVariantivEXT',
                                      'glVariantsvEXT',
                                      'glVariantubvEXT',
                                      'glVariantuivEXT',
                                      'glVariantusvEXT',
                                      'glWriteMaskEXT'
                                    ],
          'GL_EXT_vertex_weighting' => [
                                         'glVertexWeightPointerEXT',
                                         'glVertexWeightfEXT',
                                         'glVertexWeightfvEXT'
                                       ],
          'GL_EXT_window_rectangles' => [
                                          'glWindowRectanglesEXT'
                                        ],
          'GL_EXT_x11_sync_object' => [
                                        'glImportSyncEXT'
                                      ],
          'GL_GREMEDY_frame_terminator' => [
                                             'glFrameTerminatorGREMEDY'
                                           ],
          'GL_GREMEDY_string_marker' => [
                                          'glStringMarkerGREMEDY'
                                        ],
          'GL_HP_image_transform' => [
                                       'glGetImageTransformParameterfvHP',
                                       'glGetImageTransformParameterivHP',
                                       'glImageTransformParameterfHP',
                                       'glImageTransformParameterfvHP',
                                       'glImageTransformParameteriHP',
                                       'glImageTransformParameterivHP'
                                     ],
          'GL_IBM_multimode_draw_arrays' => [
                                              'glMultiModeDrawArraysIBM',
                                              'glMultiModeDrawElementsIBM'
                                            ],
          'GL_IBM_vertex_array_lists' => [
                                           'glColorPointerListIBM',
                                           'glEdgeFlagPointerListIBM',
                                           'glFogCoordPointerListIBM',
                                           'glIndexPointerListIBM',
                                           'glNormalPointerListIBM',
                                           'glSecondaryColorPointerListIBM',
                                           'glTexCoordPointerListIBM',
                                           'glVertexPointerListIBM'
                                         ],
          'GL_INTEL_parallel_arrays' => [
                                          'glColorPointervINTEL',
                                          'glNormalPointervINTEL',
                                          'glTexCoordPointervINTEL',
                                          'glVertexPointervINTEL'
                                        ],
          'GL_INTEL_performance_query' => [
                                            'glBeginPerfQueryINTEL',
                                            'glCreatePerfQueryINTEL',
                                            'glDeletePerfQueryINTEL',
                                            'glEndPerfQueryINTEL',
                                            'glGetFirstPerfQueryIdINTEL',
                                            'glGetNextPerfQueryIdINTEL',
                                            'glGetPerfCounterInfoINTEL',
                                            'glGetPerfQueryDataINTEL',
                                            'glGetPerfQueryIdByNameINTEL',
                                            'glGetPerfQueryInfoINTEL'
                                          ],
          'GL_INTEL_texture_scissor' => [
                                          'glTexScissorFuncINTEL',
                                          'glTexScissorINTEL'
                                        ],
          'GL_KHR_blend_equation_advanced' => [
                                                'glBlendBarrierKHR'
                                              ],
          'GL_KHR_debug' => [
                              'glDebugMessageCallback',
                              'glDebugMessageControl',
                              'glDebugMessageInsert',
                              'glGetDebugMessageLog',
                              'glGetObjectLabel',
                              'glGetObjectPtrLabel',
                              'glObjectLabel',
                              'glObjectPtrLabel',
                              'glPopDebugGroup',
                              'glPushDebugGroup'
                            ],
          'GL_KHR_robustness' => [
                                   'glGetnUniformfv',
                                   'glGetnUniformiv',
                                   'glGetnUniformuiv',
                                   'glReadnPixels'
                                 ],
          'GL_KTX_buffer_region' => [
                                      'glBufferRegionEnabled',
                                      'glDeleteBufferRegion',
                                      'glDrawBufferRegion',
                                      'glNewBufferRegion',
                                      'glReadBufferRegion'
                                    ],
          'GL_LAYOUT_LINEAR_INTEL' => [
                                        'glMapTexture2DINTEL',
                                        'glSyncTextureINTEL',
                                        'glUnmapTexture2DINTEL'
                                      ],
          'GL_MESA_resize_buffers' => [
                                        'glResizeBuffersMESA'
                                      ],
          'GL_MESA_window_pos' => [
                                    'glWindowPos2dMESA',
                                    'glWindowPos2dvMESA',
                                    'glWindowPos2fMESA',
                                    'glWindowPos2fvMESA',
                                    'glWindowPos2iMESA',
                                    'glWindowPos2ivMESA',
                                    'glWindowPos2sMESA',
                                    'glWindowPos2svMESA',
                                    'glWindowPos3dMESA',
                                    'glWindowPos3dvMESA',
                                    'glWindowPos3fMESA',
                                    'glWindowPos3fvMESA',
                                    'glWindowPos3iMESA',
                                    'glWindowPos3ivMESA',
                                    'glWindowPos3sMESA',
                                    'glWindowPos3svMESA',
                                    'glWindowPos4dMESA',
                                    'glWindowPos4dvMESA',
                                    'glWindowPos4fMESA',
                                    'glWindowPos4fvMESA',
                                    'glWindowPos4iMESA',
                                    'glWindowPos4ivMESA',
                                    'glWindowPos4sMESA',
                                    'glWindowPos4svMESA'
                                  ],
          'GL_NVX_conditional_render' => [
                                           'glBeginConditionalRenderNVX',
                                           'glEndConditionalRenderNVX'
                                         ],
          'GL_NVX_linked_gpu_multicast' => [
                                             'glLGPUCopyImageSubDataNVX',
                                             'glLGPUInterlockNVX',
                                             'glLGPUNamedBufferSubDataNVX'
                                           ],
          'GL_NV_bindless_multi_draw_indirect' => [
                                                    'glMultiDrawArraysIndirectBindlessNV',
                                                    'glMultiDrawElementsIndirectBindlessNV'
                                                  ],
          'GL_NV_bindless_multi_draw_indirect_count' => [
                                                          'glMultiDrawArraysIndirectBindlessCountNV',
                                                          'glMultiDrawElementsIndirectBindlessCountNV'
                                                        ],
          'GL_NV_bindless_texture' => [
                                        'glGetImageHandleNV',
                                        'glGetTextureHandleNV',
                                        'glGetTextureSamplerHandleNV',
                                        'glIsImageHandleResidentNV',
                                        'glIsTextureHandleResidentNV',
                                        'glMakeImageHandleNonResidentNV',
                                        'glMakeImageHandleResidentNV',
                                        'glMakeTextureHandleNonResidentNV',
                                        'glMakeTextureHandleResidentNV',
                                        'glProgramUniformHandleui64NV',
                                        'glProgramUniformHandleui64vNV',
                                        'glUniformHandleui64NV',
                                        'glUniformHandleui64vNV'
                                      ],
          'GL_NV_blend_equation_advanced' => [
                                               'glBlendBarrierNV',
                                               'glBlendParameteriNV'
                                             ],
          'GL_NV_clip_space_w_scaling' => [
                                            'glViewportPositionWScaleNV'
                                          ],
          'GL_NV_command_list' => [
                                    'glCallCommandListNV',
                                    'glCommandListSegmentsNV',
                                    'glCompileCommandListNV',
                                    'glCreateCommandListsNV',
                                    'glCreateStatesNV',
                                    'glDeleteCommandListsNV',
                                    'glDeleteStatesNV',
                                    'glDrawCommandsAddressNV',
                                    'glDrawCommandsNV',
                                    'glDrawCommandsStatesAddressNV',
                                    'glDrawCommandsStatesNV',
                                    'glGetCommandHeaderNV',
                                    'glGetStageIndexNV',
                                    'glIsCommandListNV',
                                    'glIsStateNV',
                                    'glListDrawCommandsStatesClientNV',
                                    'glStateCaptureNV'
                                  ],
          'GL_NV_conditional_render' => [
                                          'glBeginConditionalRenderNV',
                                          'glEndConditionalRenderNV'
                                        ],
          'GL_NV_conservative_raster' => [
                                           'glSubpixelPrecisionBiasNV'
                                         ],
          'GL_NV_conservative_raster_dilate' => [
                                                  'glConservativeRasterParameterfNV'
                                                ],
          'GL_NV_conservative_raster_pre_snap_triangles' => [
                                                              'glConservativeRasterParameteriNV'
                                                            ],
          'GL_NV_copy_image' => [
                                  'glCopyImageSubDataNV'
                                ],
          'GL_NV_depth_buffer_float' => [
                                          'glClearDepthdNV',
                                          'glDepthBoundsdNV',
                                          'glDepthRangedNV'
                                        ],
          'GL_NV_draw_texture' => [
                                    'glDrawTextureNV'
                                  ],
          'GL_NV_draw_vulkan_image' => [
                                         'glDrawVkImageNV',
                                         'glGetVkProcAddrNV',
                                         'glSignalVkFenceNV',
                                         'glSignalVkSemaphoreNV',
                                         'glWaitVkSemaphoreNV'
                                       ],
          'GL_NV_evaluators' => [
                                  'glEvalMapsNV',
                                  'glGetMapAttribParameterfvNV',
                                  'glGetMapAttribParameterivNV',
                                  'glGetMapControlPointsNV',
                                  'glGetMapParameterfvNV',
                                  'glGetMapParameterivNV',
                                  'glMapControlPointsNV',
                                  'glMapParameterfvNV',
                                  'glMapParameterivNV'
                                ],
          'GL_NV_explicit_multisample' => [
                                            'glGetMultisamplefvNV',
                                            'glSampleMaskIndexedNV',
                                            'glTexRenderbufferNV'
                                          ],
          'GL_NV_fence' => [
                             'glDeleteFencesNV',
                             'glFinishFenceNV',
                             'glGenFencesNV',
                             'glGetFenceivNV',
                             'glIsFenceNV',
                             'glSetFenceNV',
                             'glTestFenceNV'
                           ],
          'GL_NV_fragment_coverage_to_color' => [
                                                  'glFragmentCoverageColorNV'
                                                ],
          'GL_NV_fragment_program' => [
                                        'glGetProgramNamedParameterdvNV',
                                        'glGetProgramNamedParameterfvNV',
                                        'glProgramNamedParameter4dNV',
                                        'glProgramNamedParameter4dvNV',
                                        'glProgramNamedParameter4fNV',
                                        'glProgramNamedParameter4fvNV'
                                      ],
          'GL_NV_framebuffer_multisample_coverage' => [
                                                        'glRenderbufferStorageMultisampleCoverageNV'
                                                      ],
          'GL_NV_geometry_program4' => [
                                         'glProgramVertexLimitNV'
                                       ],
          'GL_NV_gpu_multicast' => [
                                     'glMulticastBarrierNV',
                                     'glMulticastBlitFramebufferNV',
                                     'glMulticastBufferSubDataNV',
                                     'glMulticastCopyBufferSubDataNV',
                                     'glMulticastCopyImageSubDataNV',
                                     'glMulticastFramebufferSampleLocationsfvNV',
                                     'glMulticastGetQueryObjecti64vNV',
                                     'glMulticastGetQueryObjectivNV',
                                     'glMulticastGetQueryObjectui64vNV',
                                     'glMulticastGetQueryObjectuivNV',
                                     'glMulticastWaitSyncNV',
                                     'glRenderGpuMaskNV'
                                   ],
          'GL_NV_gpu_program4' => [
                                    'glProgramEnvParameterI4iNV',
                                    'glProgramEnvParameterI4ivNV',
                                    'glProgramEnvParameterI4uiNV',
                                    'glProgramEnvParameterI4uivNV',
                                    'glProgramEnvParametersI4ivNV',
                                    'glProgramEnvParametersI4uivNV',
                                    'glProgramLocalParameterI4iNV',
                                    'glProgramLocalParameterI4ivNV',
                                    'glProgramLocalParameterI4uiNV',
                                    'glProgramLocalParameterI4uivNV',
                                    'glProgramLocalParametersI4ivNV',
                                    'glProgramLocalParametersI4uivNV'
                                  ],
          'GL_NV_gpu_shader5' => [
                                   'glGetUniformi64vNV',
                                   'glGetUniformui64vNV',
                                   'glProgramUniform1i64NV',
                                   'glProgramUniform1i64vNV',
                                   'glProgramUniform1ui64NV',
                                   'glProgramUniform1ui64vNV',
                                   'glProgramUniform2i64NV',
                                   'glProgramUniform2i64vNV',
                                   'glProgramUniform2ui64NV',
                                   'glProgramUniform2ui64vNV',
                                   'glProgramUniform3i64NV',
                                   'glProgramUniform3i64vNV',
                                   'glProgramUniform3ui64NV',
                                   'glProgramUniform3ui64vNV',
                                   'glProgramUniform4i64NV',
                                   'glProgramUniform4i64vNV',
                                   'glProgramUniform4ui64NV',
                                   'glProgramUniform4ui64vNV',
                                   'glUniform1i64NV',
                                   'glUniform1i64vNV',
                                   'glUniform1ui64NV',
                                   'glUniform1ui64vNV',
                                   'glUniform2i64NV',
                                   'glUniform2i64vNV',
                                   'glUniform2ui64NV',
                                   'glUniform2ui64vNV',
                                   'glUniform3i64NV',
                                   'glUniform3i64vNV',
                                   'glUniform3ui64NV',
                                   'glUniform3ui64vNV',
                                   'glUniform4i64NV',
                                   'glUniform4i64vNV',
                                   'glUniform4ui64NV',
                                   'glUniform4ui64vNV'
                                 ],
          'GL_NV_half_float' => [
                                  'glColor3hNV',
                                  'glColor3hvNV',
                                  'glColor4hNV',
                                  'glColor4hvNV',
                                  'glFogCoordhNV',
                                  'glFogCoordhvNV',
                                  'glMultiTexCoord1hNV',
                                  'glMultiTexCoord1hvNV',
                                  'glMultiTexCoord2hNV',
                                  'glMultiTexCoord2hvNV',
                                  'glMultiTexCoord3hNV',
                                  'glMultiTexCoord3hvNV',
                                  'glMultiTexCoord4hNV',
                                  'glMultiTexCoord4hvNV',
                                  'glNormal3hNV',
                                  'glNormal3hvNV',
                                  'glSecondaryColor3hNV',
                                  'glSecondaryColor3hvNV',
                                  'glTexCoord1hNV',
                                  'glTexCoord1hvNV',
                                  'glTexCoord2hNV',
                                  'glTexCoord2hvNV',
                                  'glTexCoord3hNV',
                                  'glTexCoord3hvNV',
                                  'glTexCoord4hNV',
                                  'glTexCoord4hvNV',
                                  'glVertex2hNV',
                                  'glVertex2hvNV',
                                  'glVertex3hNV',
                                  'glVertex3hvNV',
                                  'glVertex4hNV',
                                  'glVertex4hvNV',
                                  'glVertexAttrib1hNV',
                                  'glVertexAttrib1hvNV',
                                  'glVertexAttrib2hNV',
                                  'glVertexAttrib2hvNV',
                                  'glVertexAttrib3hNV',
                                  'glVertexAttrib3hvNV',
                                  'glVertexAttrib4hNV',
                                  'glVertexAttrib4hvNV',
                                  'glVertexAttribs1hvNV',
                                  'glVertexAttribs2hvNV',
                                  'glVertexAttribs3hvNV',
                                  'glVertexAttribs4hvNV',
                                  'glVertexWeighthNV',
                                  'glVertexWeighthvNV'
                                ],
          'GL_NV_internalformat_sample_query' => [
                                                   'glGetInternalformatSampleivNV'
                                                 ],
          'GL_NV_occlusion_query' => [
                                       'glBeginOcclusionQueryNV',
                                       'glDeleteOcclusionQueriesNV',
                                       'glEndOcclusionQueryNV',
                                       'glGenOcclusionQueriesNV',
                                       'glGetOcclusionQueryivNV',
                                       'glGetOcclusionQueryuivNV',
                                       'glIsOcclusionQueryNV'
                                     ],
          'GL_NV_parameter_buffer_object' => [
                                               'glProgramBufferParametersIivNV',
                                               'glProgramBufferParametersIuivNV',
                                               'glProgramBufferParametersfvNV'
                                             ],
          'GL_NV_path_rendering' => [
                                      'glCopyPathNV',
                                      'glCoverFillPathInstancedNV',
                                      'glCoverFillPathNV',
                                      'glCoverStrokePathInstancedNV',
                                      'glCoverStrokePathNV',
                                      'glDeletePathsNV',
                                      'glGenPathsNV',
                                      'glGetPathColorGenfvNV',
                                      'glGetPathColorGenivNV',
                                      'glGetPathCommandsNV',
                                      'glGetPathCoordsNV',
                                      'glGetPathDashArrayNV',
                                      'glGetPathLengthNV',
                                      'glGetPathMetricRangeNV',
                                      'glGetPathMetricsNV',
                                      'glGetPathParameterfvNV',
                                      'glGetPathParameterivNV',
                                      'glGetPathSpacingNV',
                                      'glGetPathTexGenfvNV',
                                      'glGetPathTexGenivNV',
                                      'glGetProgramResourcefvNV',
                                      'glInterpolatePathsNV',
                                      'glIsPathNV',
                                      'glIsPointInFillPathNV',
                                      'glIsPointInStrokePathNV',
                                      'glMatrixLoad3x2fNV',
                                      'glMatrixLoad3x3fNV',
                                      'glMatrixLoadTranspose3x3fNV',
                                      'glMatrixMult3x2fNV',
                                      'glMatrixMult3x3fNV',
                                      'glMatrixMultTranspose3x3fNV',
                                      'glPathColorGenNV',
                                      'glPathCommandsNV',
                                      'glPathCoordsNV',
                                      'glPathCoverDepthFuncNV',
                                      'glPathDashArrayNV',
                                      'glPathFogGenNV',
                                      'glPathGlyphIndexArrayNV',
                                      'glPathGlyphIndexRangeNV',
                                      'glPathGlyphRangeNV',
                                      'glPathGlyphsNV',
                                      'glPathMemoryGlyphIndexArrayNV',
                                      'glPathParameterfNV',
                                      'glPathParameterfvNV',
                                      'glPathParameteriNV',
                                      'glPathParameterivNV',
                                      'glPathStencilDepthOffsetNV',
                                      'glPathStencilFuncNV',
                                      'glPathStringNV',
                                      'glPathSubCommandsNV',
                                      'glPathSubCoordsNV',
                                      'glPathTexGenNV',
                                      'glPointAlongPathNV',
                                      'glProgramPathFragmentInputGenNV',
                                      'glStencilFillPathInstancedNV',
                                      'glStencilFillPathNV',
                                      'glStencilStrokePathInstancedNV',
                                      'glStencilStrokePathNV',
                                      'glStencilThenCoverFillPathInstancedNV',
                                      'glStencilThenCoverFillPathNV',
                                      'glStencilThenCoverStrokePathInstancedNV',
                                      'glStencilThenCoverStrokePathNV',
                                      'glTransformPathNV',
                                      'glWeightPathsNV'
                                    ],
          'GL_NV_pixel_data_range' => [
                                        'glFlushPixelDataRangeNV',
                                        'glPixelDataRangeNV'
                                      ],
          'GL_NV_point_sprite' => [
                                    'glPointParameteriNV',
                                    'glPointParameterivNV'
                                  ],
          'GL_NV_present_video' => [
                                     'glGetVideoi64vNV',
                                     'glGetVideoivNV',
                                     'glGetVideoui64vNV',
                                     'glGetVideouivNV',
                                     'glPresentFrameDualFillNV',
                                     'glPresentFrameKeyedNV'
                                   ],
          'GL_NV_primitive_restart' => [
                                         'glPrimitiveRestartIndexNV',
                                         'glPrimitiveRestartNV'
                                       ],
          'GL_NV_register_combiners' => [
                                          'glCombinerInputNV',
                                          'glCombinerOutputNV',
                                          'glCombinerParameterfNV',
                                          'glCombinerParameterfvNV',
                                          'glCombinerParameteriNV',
                                          'glCombinerParameterivNV',
                                          'glFinalCombinerInputNV',
                                          'glGetCombinerInputParameterfvNV',
                                          'glGetCombinerInputParameterivNV',
                                          'glGetCombinerOutputParameterfvNV',
                                          'glGetCombinerOutputParameterivNV',
                                          'glGetFinalCombinerInputParameterfvNV',
                                          'glGetFinalCombinerInputParameterivNV'
                                        ],
          'GL_NV_register_combiners2' => [
                                           'glCombinerStageParameterfvNV',
                                           'glGetCombinerStageParameterfvNV'
                                         ],
          'GL_NV_sample_locations' => [
                                        'glFramebufferSampleLocationsfvNV',
                                        'glNamedFramebufferSampleLocationsfvNV'
                                      ],
          'GL_NV_shader_buffer_load' => [
                                          'glGetBufferParameterui64vNV',
                                          'glGetIntegerui64vNV',
                                          'glGetNamedBufferParameterui64vNV',
                                          'glIsBufferResidentNV',
                                          'glIsNamedBufferResidentNV',
                                          'glMakeBufferNonResidentNV',
                                          'glMakeBufferResidentNV',
                                          'glMakeNamedBufferNonResidentNV',
                                          'glMakeNamedBufferResidentNV',
                                          'glProgramUniformui64NV',
                                          'glProgramUniformui64vNV',
                                          'glUniformui64NV',
                                          'glUniformui64vNV'
                                        ],
          'GL_NV_texture_barrier' => [
                                       'glTextureBarrierNV'
                                     ],
          'GL_NV_texture_multisample' => [
                                           'glTexImage2DMultisampleCoverageNV',
                                           'glTexImage3DMultisampleCoverageNV',
                                           'glTextureImage2DMultisampleCoverageNV',
                                           'glTextureImage2DMultisampleNV',
                                           'glTextureImage3DMultisampleCoverageNV',
                                           'glTextureImage3DMultisampleNV'
                                         ],
          'GL_NV_transform_feedback' => [
                                          'glActiveVaryingNV',
                                          'glBeginTransformFeedbackNV',
                                          'glBindBufferBaseNV',
                                          'glBindBufferOffsetNV',
                                          'glBindBufferRangeNV',
                                          'glEndTransformFeedbackNV',
                                          'glGetActiveVaryingNV',
                                          'glGetTransformFeedbackVaryingNV',
                                          'glGetVaryingLocationNV',
                                          'glTransformFeedbackAttribsNV',
                                          'glTransformFeedbackVaryingsNV'
                                        ],
          'GL_NV_transform_feedback2' => [
                                           'glBindTransformFeedbackNV',
                                           'glDeleteTransformFeedbacksNV',
                                           'glDrawTransformFeedbackNV',
                                           'glGenTransformFeedbacksNV',
                                           'glIsTransformFeedbackNV',
                                           'glPauseTransformFeedbackNV',
                                           'glResumeTransformFeedbackNV'
                                         ],
          'GL_NV_vdpau_interop' => [
                                     'glVDPAUFiniNV',
                                     'glVDPAUGetSurfaceivNV',
                                     'glVDPAUInitNV',
                                     'glVDPAUIsSurfaceNV',
                                     'glVDPAUMapSurfacesNV',
                                     'glVDPAURegisterOutputSurfaceNV',
                                     'glVDPAURegisterVideoSurfaceNV',
                                     'glVDPAUSurfaceAccessNV',
                                     'glVDPAUUnmapSurfacesNV',
                                     'glVDPAUUnregisterSurfaceNV'
                                   ],
          'GL_NV_vertex_array_range' => [
                                          'glFlushVertexArrayRangeNV',
                                          'glVertexArrayRangeNV'
                                        ],
          'GL_NV_vertex_attrib_integer_64bit' => [
                                                   'glGetVertexAttribLi64vNV',
                                                   'glGetVertexAttribLui64vNV',
                                                   'glVertexAttribL1i64NV',
                                                   'glVertexAttribL1i64vNV',
                                                   'glVertexAttribL1ui64NV',
                                                   'glVertexAttribL1ui64vNV',
                                                   'glVertexAttribL2i64NV',
                                                   'glVertexAttribL2i64vNV',
                                                   'glVertexAttribL2ui64NV',
                                                   'glVertexAttribL2ui64vNV',
                                                   'glVertexAttribL3i64NV',
                                                   'glVertexAttribL3i64vNV',
                                                   'glVertexAttribL3ui64NV',
                                                   'glVertexAttribL3ui64vNV',
                                                   'glVertexAttribL4i64NV',
                                                   'glVertexAttribL4i64vNV',
                                                   'glVertexAttribL4ui64NV',
                                                   'glVertexAttribL4ui64vNV',
                                                   'glVertexAttribLFormatNV'
                                                 ],
          'GL_NV_vertex_buffer_unified_memory' => [
                                                    'glBufferAddressRangeNV',
                                                    'glColorFormatNV',
                                                    'glEdgeFlagFormatNV',
                                                    'glFogCoordFormatNV',
                                                    'glGetIntegerui64i_vNV',
                                                    'glIndexFormatNV',
                                                    'glNormalFormatNV',
                                                    'glSecondaryColorFormatNV',
                                                    'glTexCoordFormatNV',
                                                    'glVertexAttribFormatNV',
                                                    'glVertexAttribIFormatNV',
                                                    'glVertexFormatNV'
                                                  ],
          'GL_NV_vertex_program' => [
                                      'glAreProgramsResidentNV',
                                      'glBindProgramNV',
                                      'glDeleteProgramsNV',
                                      'glExecuteProgramNV',
                                      'glGenProgramsNV',
                                      'glGetProgramParameterdvNV',
                                      'glGetProgramParameterfvNV',
                                      'glGetProgramStringNV',
                                      'glGetProgramivNV',
                                      'glGetTrackMatrixivNV',
                                      'glGetVertexAttribPointervNV',
                                      'glGetVertexAttribdvNV',
                                      'glGetVertexAttribfvNV',
                                      'glGetVertexAttribivNV',
                                      'glIsProgramNV',
                                      'glLoadProgramNV',
                                      'glProgramParameter4dNV',
                                      'glProgramParameter4dvNV',
                                      'glProgramParameter4fNV',
                                      'glProgramParameter4fvNV',
                                      'glProgramParameters4dvNV',
                                      'glProgramParameters4fvNV',
                                      'glRequestResidentProgramsNV',
                                      'glTrackMatrixNV',
                                      'glVertexAttrib1dNV',
                                      'glVertexAttrib1dvNV',
                                      'glVertexAttrib1fNV',
                                      'glVertexAttrib1fvNV',
                                      'glVertexAttrib1sNV',
                                      'glVertexAttrib1svNV',
                                      'glVertexAttrib2dNV',
                                      'glVertexAttrib2dvNV',
                                      'glVertexAttrib2fNV',
                                      'glVertexAttrib2fvNV',
                                      'glVertexAttrib2sNV',
                                      'glVertexAttrib2svNV',
                                      'glVertexAttrib3dNV',
                                      'glVertexAttrib3dvNV',
                                      'glVertexAttrib3fNV',
                                      'glVertexAttrib3fvNV',
                                      'glVertexAttrib3sNV',
                                      'glVertexAttrib3svNV',
                                      'glVertexAttrib4dNV',
                                      'glVertexAttrib4dvNV',
                                      'glVertexAttrib4fNV',
                                      'glVertexAttrib4fvNV',
                                      'glVertexAttrib4sNV',
                                      'glVertexAttrib4svNV',
                                      'glVertexAttrib4ubNV',
                                      'glVertexAttrib4ubvNV',
                                      'glVertexAttribPointerNV',
                                      'glVertexAttribs1dvNV',
                                      'glVertexAttribs1fvNV',
                                      'glVertexAttribs1svNV',
                                      'glVertexAttribs2dvNV',
                                      'glVertexAttribs2fvNV',
                                      'glVertexAttribs2svNV',
                                      'glVertexAttribs3dvNV',
                                      'glVertexAttribs3fvNV',
                                      'glVertexAttribs3svNV',
                                      'glVertexAttribs4dvNV',
                                      'glVertexAttribs4fvNV',
                                      'glVertexAttribs4svNV',
                                      'glVertexAttribs4ubvNV'
                                    ],
          'GL_NV_video_capture' => [
                                     'glBeginVideoCaptureNV',
                                     'glBindVideoCaptureStreamBufferNV',
                                     'glBindVideoCaptureStreamTextureNV',
                                     'glEndVideoCaptureNV',
                                     'glGetVideoCaptureStreamdvNV',
                                     'glGetVideoCaptureStreamfvNV',
                                     'glGetVideoCaptureStreamivNV',
                                     'glGetVideoCaptureivNV',
                                     'glVideoCaptureNV',
                                     'glVideoCaptureStreamParameterdvNV',
                                     'glVideoCaptureStreamParameterfvNV',
                                     'glVideoCaptureStreamParameterivNV'
                                   ],
          'GL_NV_viewport_swizzle' => [
                                        'glViewportSwizzleNV'
                                      ],
          'GL_OES_single_precision' => [
                                         'glClearDepthfOES',
                                         'glClipPlanefOES',
                                         'glDepthRangefOES',
                                         'glFrustumfOES',
                                         'glGetClipPlanefOES',
                                         'glOrthofOES'
                                       ],
          'GL_OVR_multiview' => [
                                  'glFramebufferTextureMultiviewOVR'
                                ],
          'GL_REGAL_ES1_0_compatibility' => [
                                              'glAlphaFuncx',
                                              'glClearColorx',
                                              'glClearDepthx',
                                              'glColor4x',
                                              'glDepthRangex',
                                              'glFogx',
                                              'glFogxv',
                                              'glFrustumf',
                                              'glFrustumx',
                                              'glLightModelx',
                                              'glLightModelxv',
                                              'glLightx',
                                              'glLightxv',
                                              'glLineWidthx',
                                              'glLoadMatrixx',
                                              'glMaterialx',
                                              'glMaterialxv',
                                              'glMultMatrixx',
                                              'glMultiTexCoord4x',
                                              'glNormal3x',
                                              'glOrthof',
                                              'glOrthox',
                                              'glPointSizex',
                                              'glPolygonOffsetx',
                                              'glRotatex',
                                              'glSampleCoveragex',
                                              'glScalex',
                                              'glTexEnvx',
                                              'glTexEnvxv',
                                              'glTexParameterx',
                                              'glTranslatex'
                                            ],
          'GL_REGAL_ES1_1_compatibility' => [
                                              'glClipPlanef',
                                              'glClipPlanex',
                                              'glGetClipPlanef',
                                              'glGetClipPlanex',
                                              'glGetFixedv',
                                              'glGetLightxv',
                                              'glGetMaterialxv',
                                              'glGetTexEnvxv',
                                              'glGetTexParameterxv',
                                              'glPointParameterx',
                                              'glPointParameterxv',
                                              'glPointSizePointerOES',
                                              'glTexParameterxv'
                                            ],
          'GL_REGAL_extension_query' => [
                                          'glGetExtensionREGAL',
                                          'glIsSupportedREGAL'
                                        ],
          'GL_REGAL_log' => [
                              'glLogMessageCallbackREGAL'
                            ],
          'GL_REGAL_proc_address' => [
                                       'glGetProcAddressREGAL'
                                     ],
          'GL_SGIS_detail_texture' => [
                                        'glDetailTexFuncSGIS',
                                        'glGetDetailTexFuncSGIS'
                                      ],
          'GL_SGIS_fog_function' => [
                                      'glFogFuncSGIS',
                                      'glGetFogFuncSGIS'
                                    ],
          'GL_SGIS_multisample' => [
                                     'glSampleMaskSGIS',
                                     'glSamplePatternSGIS'
                                   ],
          'GL_SGIS_sharpen_texture' => [
                                         'glGetSharpenTexFuncSGIS',
                                         'glSharpenTexFuncSGIS'
                                       ],
          'GL_SGIS_texture4D' => [
                                   'glTexImage4DSGIS',
                                   'glTexSubImage4DSGIS'
                                 ],
          'GL_SGIS_texture_filter4' => [
                                         'glGetTexFilterFuncSGIS',
                                         'glTexFilterFuncSGIS'
                                       ],
          'GL_SGIX_async' => [
                               'glAsyncMarkerSGIX',
                               'glDeleteAsyncMarkersSGIX',
                               'glFinishAsyncSGIX',
                               'glGenAsyncMarkersSGIX',
                               'glIsAsyncMarkerSGIX',
                               'glPollAsyncSGIX'
                             ],
          'GL_SGIX_flush_raster' => [
                                      'glFlushRasterSGIX'
                                    ],
          'GL_SGIX_fog_texture' => [
                                     'glTextureFogSGIX'
                                   ],
          'GL_SGIX_fragment_specular_lighting' => [
                                                    'glFragmentColorMaterialSGIX',
                                                    'glFragmentLightModelfSGIX',
                                                    'glFragmentLightModelfvSGIX',
                                                    'glFragmentLightModeliSGIX',
                                                    'glFragmentLightModelivSGIX',
                                                    'glFragmentLightfSGIX',
                                                    'glFragmentLightfvSGIX',
                                                    'glFragmentLightiSGIX',
                                                    'glFragmentLightivSGIX',
                                                    'glFragmentMaterialfSGIX',
                                                    'glFragmentMaterialfvSGIX',
                                                    'glFragmentMaterialiSGIX',
                                                    'glFragmentMaterialivSGIX',
                                                    'glGetFragmentLightfvSGIX',
                                                    'glGetFragmentLightivSGIX',
                                                    'glGetFragmentMaterialfvSGIX',
                                                    'glGetFragmentMaterialivSGIX'
                                                  ],
          'GL_SGIX_framezoom' => [
                                   'glFrameZoomSGIX'
                                 ],
          'GL_SGIX_pixel_texture' => [
                                       'glPixelTexGenSGIX'
                                     ],
          'GL_SGIX_reference_plane' => [
                                         'glReferencePlaneSGIX'
                                       ],
          'GL_SGIX_sprite' => [
                                'glSpriteParameterfSGIX',
                                'glSpriteParameterfvSGIX',
                                'glSpriteParameteriSGIX',
                                'glSpriteParameterivSGIX'
                              ],
          'GL_SGIX_tag_sample_buffer' => [
                                           'glTagSampleBufferSGIX'
                                         ],
          'GL_SGI_color_table' => [
                                    'glColorTableParameterfvSGI',
                                    'glColorTableParameterivSGI',
                                    'glColorTableSGI',
                                    'glCopyColorTableSGI',
                                    'glGetColorTableParameterfvSGI',
                                    'glGetColorTableParameterivSGI',
                                    'glGetColorTableSGI'
                                  ],
          'GL_SUNX_constant_data' => [
                                       'glFinishTextureSUNX'
                                     ],
          'GL_SUN_global_alpha' => [
                                     'glGlobalAlphaFactorbSUN',
                                     'glGlobalAlphaFactordSUN',
                                     'glGlobalAlphaFactorfSUN',
                                     'glGlobalAlphaFactoriSUN',
                                     'glGlobalAlphaFactorsSUN',
                                     'glGlobalAlphaFactorubSUN',
                                     'glGlobalAlphaFactoruiSUN',
                                     'glGlobalAlphaFactorusSUN'
                                   ],
          'GL_SUN_read_video_pixels' => [
                                          'glReadVideoPixelsSUN'
                                        ],
          'GL_SUN_triangle_list' => [
                                      'glReplacementCodePointerSUN',
                                      'glReplacementCodeubSUN',
                                      'glReplacementCodeubvSUN',
                                      'glReplacementCodeuiSUN',
                                      'glReplacementCodeuivSUN',
                                      'glReplacementCodeusSUN',
                                      'glReplacementCodeusvSUN'
                                    ],
          'GL_SUN_vertex' => [
                               'glColor3fVertex3fSUN',
                               'glColor3fVertex3fvSUN',
                               'glColor4fNormal3fVertex3fSUN',
                               'glColor4fNormal3fVertex3fvSUN',
                               'glColor4ubVertex2fSUN',
                               'glColor4ubVertex2fvSUN',
                               'glColor4ubVertex3fSUN',
                               'glColor4ubVertex3fvSUN',
                               'glNormal3fVertex3fSUN',
                               'glNormal3fVertex3fvSUN',
                               'glReplacementCodeuiColor3fVertex3fSUN',
                               'glReplacementCodeuiColor3fVertex3fvSUN',
                               'glReplacementCodeuiColor4fNormal3fVertex3fSUN',
                               'glReplacementCodeuiColor4fNormal3fVertex3fvSUN',
                               'glReplacementCodeuiColor4ubVertex3fSUN',
                               'glReplacementCodeuiColor4ubVertex3fvSUN',
                               'glReplacementCodeuiNormal3fVertex3fSUN',
                               'glReplacementCodeuiNormal3fVertex3fvSUN',
                               'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN',
                               'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN',
                               'glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN',
                               'glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN',
                               'glReplacementCodeuiTexCoord2fVertex3fSUN',
                               'glReplacementCodeuiTexCoord2fVertex3fvSUN',
                               'glReplacementCodeuiVertex3fSUN',
                               'glReplacementCodeuiVertex3fvSUN',
                               'glTexCoord2fColor3fVertex3fSUN',
                               'glTexCoord2fColor3fVertex3fvSUN',
                               'glTexCoord2fColor4fNormal3fVertex3fSUN',
                               'glTexCoord2fColor4fNormal3fVertex3fvSUN',
                               'glTexCoord2fColor4ubVertex3fSUN',
                               'glTexCoord2fColor4ubVertex3fvSUN',
                               'glTexCoord2fNormal3fVertex3fSUN',
                               'glTexCoord2fNormal3fVertex3fvSUN',
                               'glTexCoord2fVertex3fSUN',
                               'glTexCoord2fVertex3fvSUN',
                               'glTexCoord4fColor4fNormal3fVertex4fSUN',
                               'glTexCoord4fColor4fNormal3fVertex4fvSUN',
                               'glTexCoord4fVertex4fSUN',
                               'glTexCoord4fVertex4fvSUN'
                             ],
          'GL_VERSION_1_1' => [
                                'glAccum',
                                'glAlphaFunc',
                                'glAreTexturesResident',
                                'glArrayElement',
                                'glBegin',
                                'glBindTexture',
                                'glBitmap',
                                'glBlendFunc',
                                'glCallList',
                                'glCallLists',
                                'glClear',
                                'glClearAccum',
                                'glClearColor',
                                'glClearDepth',
                                'glClearIndex',
                                'glClearStencil',
                                'glClipPlane',
                                'glColor3b',
                                'glColor3bv',
                                'glColor3d',
                                'glColor3dv',
                                'glColor3f',
                                'glColor3fv',
                                'glColor3i',
                                'glColor3iv',
                                'glColor3s',
                                'glColor3sv',
                                'glColor3ub',
                                'glColor3ubv',
                                'glColor3ui',
                                'glColor3uiv',
                                'glColor3us',
                                'glColor3usv',
                                'glColor4b',
                                'glColor4bv',
                                'glColor4d',
                                'glColor4dv',
                                'glColor4f',
                                'glColor4fv',
                                'glColor4i',
                                'glColor4iv',
                                'glColor4s',
                                'glColor4sv',
                                'glColor4ub',
                                'glColor4ubv',
                                'glColor4ui',
                                'glColor4uiv',
                                'glColor4us',
                                'glColor4usv',
                                'glColorMask',
                                'glColorMaterial',
                                'glColorPointer',
                                'glCopyPixels',
                                'glCopyTexImage1D',
                                'glCopyTexImage2D',
                                'glCopyTexSubImage1D',
                                'glCopyTexSubImage2D',
                                'glCullFace',
                                'glDeleteLists',
                                'glDeleteTextures',
                                'glDepthFunc',
                                'glDepthMask',
                                'glDepthRange',
                                'glDisable',
                                'glDisableClientState',
                                'glDrawArrays',
                                'glDrawBuffer',
                                'glDrawElements',
                                'glDrawPixels',
                                'glEdgeFlag',
                                'glEdgeFlagPointer',
                                'glEdgeFlagv',
                                'glEnable',
                                'glEnableClientState',
                                'glEnd',
                                'glEndList',
                                'glEvalCoord1d',
                                'glEvalCoord1dv',
                                'glEvalCoord1f',
                                'glEvalCoord1fv',
                                'glEvalCoord2d',
                                'glEvalCoord2dv',
                                'glEvalCoord2f',
                                'glEvalCoord2fv',
                                'glEvalMesh1',
                                'glEvalMesh2',
                                'glEvalPoint1',
                                'glEvalPoint2',
                                'glFeedbackBuffer',
                                'glFinish',
                                'glFlush',
                                'glFogf',
                                'glFogfv',
                                'glFogi',
                                'glFogiv',
                                'glFrontFace',
                                'glFrustum',
                                'glGenLists',
                                'glGenTextures',
                                'glGetBooleanv',
                                'glGetClipPlane',
                                'glGetDoublev',
                                'glGetError',
                                'glGetFloatv',
                                'glGetIntegerv',
                                'glGetLightfv',
                                'glGetLightiv',
                                'glGetMapdv',
                                'glGetMapfv',
                                'glGetMapiv',
                                'glGetMaterialfv',
                                'glGetMaterialiv',
                                'glGetPixelMapfv',
                                'glGetPixelMapuiv',
                                'glGetPixelMapusv',
                                'glGetPointerv',
                                'glGetPolygonStipple',
                                'glGetString',
                                'glGetTexEnvfv',
                                'glGetTexEnviv',
                                'glGetTexGendv',
                                'glGetTexGenfv',
                                'glGetTexGeniv',
                                'glGetTexImage',
                                'glGetTexLevelParameterfv',
                                'glGetTexLevelParameteriv',
                                'glGetTexParameterfv',
                                'glGetTexParameteriv',
                                'glHint',
                                'glIndexMask',
                                'glIndexPointer',
                                'glIndexd',
                                'glIndexdv',
                                'glIndexf',
                                'glIndexfv',
                                'glIndexi',
                                'glIndexiv',
                                'glIndexs',
                                'glIndexsv',
                                'glIndexub',
                                'glIndexubv',
                                'glInitNames',
                                'glInterleavedArrays',
                                'glIsEnabled',
                                'glIsList',
                                'glIsTexture',
                                'glLightModelf',
                                'glLightModelfv',
                                'glLightModeli',
                                'glLightModeliv',
                                'glLightf',
                                'glLightfv',
                                'glLighti',
                                'glLightiv',
                                'glLineStipple',
                                'glLineWidth',
                                'glListBase',
                                'glLoadIdentity',
                                'glLoadMatrixd',
                                'glLoadMatrixf',
                                'glLoadName',
                                'glLogicOp',
                                'glMap1d',
                                'glMap1f',
                                'glMap2d',
                                'glMap2f',
                                'glMapGrid1d',
                                'glMapGrid1f',
                                'glMapGrid2d',
                                'glMapGrid2f',
                                'glMaterialf',
                                'glMaterialfv',
                                'glMateriali',
                                'glMaterialiv',
                                'glMatrixMode',
                                'glMultMatrixd',
                                'glMultMatrixf',
                                'glNewList',
                                'glNormal3b',
                                'glNormal3bv',
                                'glNormal3d',
                                'glNormal3dv',
                                'glNormal3f',
                                'glNormal3fv',
                                'glNormal3i',
                                'glNormal3iv',
                                'glNormal3s',
                                'glNormal3sv',
                                'glNormalPointer',
                                'glOrtho',
                                'glPassThrough',
                                'glPixelMapfv',
                                'glPixelMapuiv',
                                'glPixelMapusv',
                                'glPixelStoref',
                                'glPixelStorei',
                                'glPixelTransferf',
                                'glPixelTransferi',
                                'glPixelZoom',
                                'glPointSize',
                                'glPolygonMode',
                                'glPolygonOffset',
                                'glPolygonStipple',
                                'glPopAttrib',
                                'glPopClientAttrib',
                                'glPopMatrix',
                                'glPopName',
                                'glPrioritizeTextures',
                                'glPushAttrib',
                                'glPushClientAttrib',
                                'glPushMatrix',
                                'glPushName',
                                'glRasterPos2d',
                                'glRasterPos2dv',
                                'glRasterPos2f',
                                'glRasterPos2fv',
                                'glRasterPos2i',
                                'glRasterPos2iv',
                                'glRasterPos2s',
                                'glRasterPos2sv',
                                'glRasterPos3d',
                                'glRasterPos3dv',
                                'glRasterPos3f',
                                'glRasterPos3fv',
                                'glRasterPos3i',
                                'glRasterPos3iv',
                                'glRasterPos3s',
                                'glRasterPos3sv',
                                'glRasterPos4d',
                                'glRasterPos4dv',
                                'glRasterPos4f',
                                'glRasterPos4fv',
                                'glRasterPos4i',
                                'glRasterPos4iv',
                                'glRasterPos4s',
                                'glRasterPos4sv',
                                'glReadBuffer',
                                'glReadPixels',
                                'glRectd',
                                'glRectdv',
                                'glRectf',
                                'glRectfv',
                                'glRecti',
                                'glRectiv',
                                'glRects',
                                'glRectsv',
                                'glRenderMode',
                                'glRotated',
                                'glRotatef',
                                'glScaled',
                                'glScalef',
                                'glScissor',
                                'glSelectBuffer',
                                'glShadeModel',
                                'glStencilFunc',
                                'glStencilMask',
                                'glStencilOp',
                                'glTexCoord1d',
                                'glTexCoord1dv',
                                'glTexCoord1f',
                                'glTexCoord1fv',
                                'glTexCoord1i',
                                'glTexCoord1iv',
                                'glTexCoord1s',
                                'glTexCoord1sv',
                                'glTexCoord2d',
                                'glTexCoord2dv',
                                'glTexCoord2f',
                                'glTexCoord2fv',
                                'glTexCoord2i',
                                'glTexCoord2iv',
                                'glTexCoord2s',
                                'glTexCoord2sv',
                                'glTexCoord3d',
                                'glTexCoord3dv',
                                'glTexCoord3f',
                                'glTexCoord3fv',
                                'glTexCoord3i',
                                'glTexCoord3iv',
                                'glTexCoord3s',
                                'glTexCoord3sv',
                                'glTexCoord4d',
                                'glTexCoord4dv',
                                'glTexCoord4f',
                                'glTexCoord4fv',
                                'glTexCoord4i',
                                'glTexCoord4iv',
                                'glTexCoord4s',
                                'glTexCoord4sv',
                                'glTexCoordPointer',
                                'glTexEnvf',
                                'glTexEnvfv',
                                'glTexEnvi',
                                'glTexEnviv',
                                'glTexGend',
                                'glTexGendv',
                                'glTexGenf',
                                'glTexGenfv',
                                'glTexGeni',
                                'glTexGeniv',
                                'glTexImage1D',
                                'glTexImage2D',
                                'glTexParameterf',
                                'glTexParameterfv',
                                'glTexParameteri',
                                'glTexParameteriv',
                                'glTexSubImage1D',
                                'glTexSubImage2D',
                                'glTranslated',
                                'glTranslatef',
                                'glVertex2d',
                                'glVertex2dv',
                                'glVertex2f',
                                'glVertex2fv',
                                'glVertex2i',
                                'glVertex2iv',
                                'glVertex2s',
                                'glVertex2sv',
                                'glVertex3d',
                                'glVertex3dv',
                                'glVertex3f',
                                'glVertex3fv',
                                'glVertex3i',
                                'glVertex3iv',
                                'glVertex3s',
                                'glVertex3sv',
                                'glVertex4d',
                                'glVertex4dv',
                                'glVertex4f',
                                'glVertex4fv',
                                'glVertex4i',
                                'glVertex4iv',
                                'glVertex4s',
                                'glVertex4sv',
                                'glVertexPointer',
                                'glViewport'
                              ],
          'GL_VERSION_1_2' => [
                                'glCopyTexSubImage3D',
                                'glDrawRangeElements',
                                'glTexImage3D',
                                'glTexSubImage3D'
                              ],
          'GL_VERSION_1_3' => [
                                'glActiveTexture',
                                'glClientActiveTexture',
                                'glCompressedTexImage1D',
                                'glCompressedTexImage2D',
                                'glCompressedTexImage3D',
                                'glCompressedTexSubImage1D',
                                'glCompressedTexSubImage2D',
                                'glCompressedTexSubImage3D',
                                'glGetCompressedTexImage',
                                'glLoadTransposeMatrixd',
                                'glLoadTransposeMatrixf',
                                'glMultTransposeMatrixd',
                                'glMultTransposeMatrixf',
                                'glMultiTexCoord1d',
                                'glMultiTexCoord1dv',
                                'glMultiTexCoord1f',
                                'glMultiTexCoord1fv',
                                'glMultiTexCoord1i',
                                'glMultiTexCoord1iv',
                                'glMultiTexCoord1s',
                                'glMultiTexCoord1sv',
                                'glMultiTexCoord2d',
                                'glMultiTexCoord2dv',
                                'glMultiTexCoord2f',
                                'glMultiTexCoord2fv',
                                'glMultiTexCoord2i',
                                'glMultiTexCoord2iv',
                                'glMultiTexCoord2s',
                                'glMultiTexCoord2sv',
                                'glMultiTexCoord3d',
                                'glMultiTexCoord3dv',
                                'glMultiTexCoord3f',
                                'glMultiTexCoord3fv',
                                'glMultiTexCoord3i',
                                'glMultiTexCoord3iv',
                                'glMultiTexCoord3s',
                                'glMultiTexCoord3sv',
                                'glMultiTexCoord4d',
                                'glMultiTexCoord4dv',
                                'glMultiTexCoord4f',
                                'glMultiTexCoord4fv',
                                'glMultiTexCoord4i',
                                'glMultiTexCoord4iv',
                                'glMultiTexCoord4s',
                                'glMultiTexCoord4sv',
                                'glSampleCoverage'
                              ],
          'GL_VERSION_1_4' => [
                                'glBlendColor',
                                'glBlendEquation',
                                'glBlendFuncSeparate',
                                'glFogCoordPointer',
                                'glFogCoordd',
                                'glFogCoorddv',
                                'glFogCoordf',
                                'glFogCoordfv',
                                'glMultiDrawArrays',
                                'glMultiDrawElements',
                                'glPointParameterf',
                                'glPointParameterfv',
                                'glPointParameteri',
                                'glPointParameteriv',
                                'glSecondaryColor3b',
                                'glSecondaryColor3bv',
                                'glSecondaryColor3d',
                                'glSecondaryColor3dv',
                                'glSecondaryColor3f',
                                'glSecondaryColor3fv',
                                'glSecondaryColor3i',
                                'glSecondaryColor3iv',
                                'glSecondaryColor3s',
                                'glSecondaryColor3sv',
                                'glSecondaryColor3ub',
                                'glSecondaryColor3ubv',
                                'glSecondaryColor3ui',
                                'glSecondaryColor3uiv',
                                'glSecondaryColor3us',
                                'glSecondaryColor3usv',
                                'glSecondaryColorPointer',
                                'glWindowPos2d',
                                'glWindowPos2dv',
                                'glWindowPos2f',
                                'glWindowPos2fv',
                                'glWindowPos2i',
                                'glWindowPos2iv',
                                'glWindowPos2s',
                                'glWindowPos2sv',
                                'glWindowPos3d',
                                'glWindowPos3dv',
                                'glWindowPos3f',
                                'glWindowPos3fv',
                                'glWindowPos3i',
                                'glWindowPos3iv',
                                'glWindowPos3s',
                                'glWindowPos3sv'
                              ],
          'GL_VERSION_1_5' => [
                                'glBeginQuery',
                                'glBindBuffer',
                                'glBufferData',
                                'glBufferSubData',
                                'glDeleteBuffers',
                                'glDeleteQueries',
                                'glEndQuery',
                                'glGenBuffers',
                                'glGenQueries',
                                'glGetBufferParameteriv',
                                'glGetBufferPointerv',
                                'glGetBufferSubData',
                                'glGetQueryObjectiv',
                                'glGetQueryObjectuiv',
                                'glGetQueryiv',
                                'glIsBuffer',
                                'glIsQuery',
                                'glMapBuffer',
                                'glUnmapBuffer'
                              ],
          'GL_VERSION_2_0' => [
                                'glAttachShader',
                                'glBindAttribLocation',
                                'glBlendEquationSeparate',
                                'glCompileShader',
                                'glCreateProgram',
                                'glCreateShader',
                                'glDeleteProgram',
                                'glDeleteShader',
                                'glDetachShader',
                                'glDisableVertexAttribArray',
                                'glDrawBuffers',
                                'glEnableVertexAttribArray',
                                'glGetActiveAttrib',
                                'glGetActiveUniform',
                                'glGetAttachedShaders',
                                'glGetAttribLocation',
                                'glGetProgramInfoLog',
                                'glGetProgramiv',
                                'glGetShaderInfoLog',
                                'glGetShaderSource',
                                'glGetShaderiv',
                                'glGetUniformLocation',
                                'glGetUniformfv',
                                'glGetUniformiv',
                                'glGetVertexAttribPointerv',
                                'glGetVertexAttribdv',
                                'glGetVertexAttribfv',
                                'glGetVertexAttribiv',
                                'glIsProgram',
                                'glIsShader',
                                'glLinkProgram',
                                'glShaderSource',
                                'glStencilFuncSeparate',
                                'glStencilMaskSeparate',
                                'glStencilOpSeparate',
                                'glUniform1f',
                                'glUniform1fv',
                                'glUniform1i',
                                'glUniform1iv',
                                'glUniform2f',
                                'glUniform2fv',
                                'glUniform2i',
                                'glUniform2iv',
                                'glUniform3f',
                                'glUniform3fv',
                                'glUniform3i',
                                'glUniform3iv',
                                'glUniform4f',
                                'glUniform4fv',
                                'glUniform4i',
                                'glUniform4iv',
                                'glUniformMatrix2fv',
                                'glUniformMatrix3fv',
                                'glUniformMatrix4fv',
                                'glUseProgram',
                                'glValidateProgram',
                                'glVertexAttrib1d',
                                'glVertexAttrib1dv',
                                'glVertexAttrib1f',
                                'glVertexAttrib1fv',
                                'glVertexAttrib1s',
                                'glVertexAttrib1sv',
                                'glVertexAttrib2d',
                                'glVertexAttrib2dv',
                                'glVertexAttrib2f',
                                'glVertexAttrib2fv',
                                'glVertexAttrib2s',
                                'glVertexAttrib2sv',
                                'glVertexAttrib3d',
                                'glVertexAttrib3dv',
                                'glVertexAttrib3f',
                                'glVertexAttrib3fv',
                                'glVertexAttrib3s',
                                'glVertexAttrib3sv',
                                'glVertexAttrib4Nbv',
                                'glVertexAttrib4Niv',
                                'glVertexAttrib4Nsv',
                                'glVertexAttrib4Nub',
                                'glVertexAttrib4Nubv',
                                'glVertexAttrib4Nuiv',
                                'glVertexAttrib4Nusv',
                                'glVertexAttrib4bv',
                                'glVertexAttrib4d',
                                'glVertexAttrib4dv',
                                'glVertexAttrib4f',
                                'glVertexAttrib4fv',
                                'glVertexAttrib4iv',
                                'glVertexAttrib4s',
                                'glVertexAttrib4sv',
                                'glVertexAttrib4ubv',
                                'glVertexAttrib4uiv',
                                'glVertexAttrib4usv',
                                'glVertexAttribPointer'
                              ],
          'GL_VERSION_2_1' => [
                                'glUniformMatrix2x3fv',
                                'glUniformMatrix2x4fv',
                                'glUniformMatrix3x2fv',
                                'glUniformMatrix3x4fv',
                                'glUniformMatrix4x2fv',
                                'glUniformMatrix4x3fv'
                              ],
          'GL_VERSION_3_0' => [
                                'glBeginConditionalRender',
                                'glBeginTransformFeedback',
                                'glBindFragDataLocation',
                                'glClampColor',
                                'glClearBufferfi',
                                'glClearBufferfv',
                                'glClearBufferiv',
                                'glClearBufferuiv',
                                'glColorMaski',
                                'glDisablei',
                                'glEnablei',
                                'glEndConditionalRender',
                                'glEndTransformFeedback',
                                'glGetBooleani_v',
                                'glGetFragDataLocation',
                                'glGetTexParameterIiv',
                                'glGetTexParameterIuiv',
                                'glGetTransformFeedbackVarying',
                                'glGetUniformuiv',
                                'glGetVertexAttribIiv',
                                'glGetVertexAttribIuiv',
                                'glIsEnabledi',
                                'glTexParameterIiv',
                                'glTexParameterIuiv',
                                'glTransformFeedbackVaryings',
                                'glUniform1ui',
                                'glUniform1uiv',
                                'glUniform2ui',
                                'glUniform2uiv',
                                'glUniform3ui',
                                'glUniform3uiv',
                                'glUniform4ui',
                                'glUniform4uiv',
                                'glVertexAttribI1i',
                                'glVertexAttribI1iv',
                                'glVertexAttribI1ui',
                                'glVertexAttribI1uiv',
                                'glVertexAttribI2i',
                                'glVertexAttribI2iv',
                                'glVertexAttribI2ui',
                                'glVertexAttribI2uiv',
                                'glVertexAttribI3i',
                                'glVertexAttribI3iv',
                                'glVertexAttribI3ui',
                                'glVertexAttribI3uiv',
                                'glVertexAttribI4bv',
                                'glVertexAttribI4i',
                                'glVertexAttribI4iv',
                                'glVertexAttribI4sv',
                                'glVertexAttribI4ubv',
                                'glVertexAttribI4ui',
                                'glVertexAttribI4uiv',
                                'glVertexAttribI4usv',
                                'glVertexAttribIPointer'
                              ],
          'GL_VERSION_3_1' => [
                                'glDrawArraysInstanced',
                                'glDrawElementsInstanced',
                                'glPrimitiveRestartIndex',
                                'glTexBuffer'
                              ],
          'GL_VERSION_3_2' => [
                                'glFramebufferTexture',
                                'glGetBufferParameteri64v',
                                'glGetInteger64i_v'
                              ],
          'GL_VERSION_3_3' => [
                                'glVertexAttribDivisor'
                              ],
          'GL_VERSION_4_0' => [
                                'glBlendEquationSeparatei',
                                'glBlendEquationi',
                                'glBlendFuncSeparatei',
                                'glBlendFunci',
                                'glMinSampleShading'
                              ],
          'GL_VERSION_4_5' => [
                                'glGetGraphicsResetStatus',
                                'glGetnCompressedTexImage',
                                'glGetnTexImage',
                                'glGetnUniformdv'
                              ],
          'GL_WIN_swap_hint' => [
                                  'glAddSwapHintRectWIN',
                                  'GLEW_VERSION_1_1',
                                  'GLEW_VERSION_1_2',
                                  'GLEW_VERSION_1_2_1',
                                  'GLEW_VERSION_1_3',
                                  'GLEW_VERSION_1_4',
                                  'GLEW_VERSION_1_5',
                                  'GLEW_VERSION_2_0',
                                  'GLEW_VERSION_2_1',
                                  'GLEW_VERSION_3_0',
                                  'GLEW_VERSION_3_1',
                                  'GLEW_VERSION_3_2',
                                  'GLEW_VERSION_3_3',
                                  'GLEW_VERSION_4_0',
                                  'GLEW_VERSION_4_1',
                                  'GLEW_VERSION_4_2',
                                  'GLEW_VERSION_4_3',
                                  'GLEW_VERSION_4_4',
                                  'GLEW_VERSION_4_5',
                                  'GLEW_3DFX_multisample',
                                  'GLEW_3DFX_tbuffer',
                                  'GLEW_3DFX_texture_compression_FXT1',
                                  'GLEW_AMD_blend_minmax_factor',
                                  'GLEW_AMD_conservative_depth',
                                  'GLEW_AMD_debug_output',
                                  'GLEW_AMD_depth_clamp_separate',
                                  'GLEW_AMD_draw_buffers_blend',
                                  'GLEW_AMD_gcn_shader',
                                  'GLEW_AMD_gpu_shader_int64',
                                  'GLEW_AMD_interleaved_elements',
                                  'GLEW_AMD_multi_draw_indirect',
                                  'GLEW_AMD_name_gen_delete',
                                  'GLEW_AMD_occlusion_query_event',
                                  'GLEW_AMD_performance_monitor',
                                  'GLEW_AMD_pinned_memory',
                                  'GLEW_AMD_query_buffer_object',
                                  'GLEW_AMD_sample_positions',
                                  'GLEW_AMD_seamless_cubemap_per_texture',
                                  'GLEW_AMD_shader_atomic_counter_ops',
                                  'GLEW_AMD_shader_explicit_vertex_parameter',
                                  'GLEW_AMD_shader_stencil_export',
                                  'GLEW_AMD_shader_stencil_value_export',
                                  'GLEW_AMD_shader_trinary_minmax',
                                  'GLEW_AMD_sparse_texture',
                                  'GLEW_AMD_stencil_operation_extended',
                                  'GLEW_AMD_texture_texture4',
                                  'GLEW_AMD_transform_feedback3_lines_triangles',
                                  'GLEW_AMD_transform_feedback4',
                                  'GLEW_AMD_vertex_shader_layer',
                                  'GLEW_AMD_vertex_shader_tessellator',
                                  'GLEW_AMD_vertex_shader_viewport_index',
                                  'GLEW_ANGLE_depth_texture',
                                  'GLEW_ANGLE_framebuffer_blit',
                                  'GLEW_ANGLE_framebuffer_multisample',
                                  'GLEW_ANGLE_instanced_arrays',
                                  'GLEW_ANGLE_pack_reverse_row_order',
                                  'GLEW_ANGLE_program_binary',
                                  'GLEW_ANGLE_texture_compression_dxt1',
                                  'GLEW_ANGLE_texture_compression_dxt3',
                                  'GLEW_ANGLE_texture_compression_dxt5',
                                  'GLEW_ANGLE_texture_usage',
                                  'GLEW_ANGLE_timer_query',
                                  'GLEW_ANGLE_translated_shader_source',
                                  'GLEW_APPLE_aux_depth_stencil',
                                  'GLEW_APPLE_client_storage',
                                  'GLEW_APPLE_element_array',
                                  'GLEW_APPLE_fence',
                                  'GLEW_APPLE_float_pixels',
                                  'GLEW_APPLE_flush_buffer_range',
                                  'GLEW_APPLE_object_purgeable',
                                  'GLEW_APPLE_pixel_buffer',
                                  'GLEW_APPLE_rgb_422',
                                  'GLEW_APPLE_row_bytes',
                                  'GLEW_APPLE_specular_vector',
                                  'GLEW_APPLE_texture_range',
                                  'GLEW_APPLE_transform_hint',
                                  'GLEW_APPLE_vertex_array_object',
                                  'GLEW_APPLE_vertex_array_range',
                                  'GLEW_APPLE_vertex_program_evaluators',
                                  'GLEW_APPLE_ycbcr_422',
                                  'GLEW_ARB_ES2_compatibility',
                                  'GLEW_ARB_ES3_1_compatibility',
                                  'GLEW_ARB_ES3_2_compatibility',
                                  'GLEW_ARB_ES3_compatibility',
                                  'GLEW_ARB_arrays_of_arrays',
                                  'GLEW_ARB_base_instance',
                                  'GLEW_ARB_bindless_texture',
                                  'GLEW_ARB_blend_func_extended',
                                  'GLEW_ARB_buffer_storage',
                                  'GLEW_ARB_cl_event',
                                  'GLEW_ARB_clear_buffer_object',
                                  'GLEW_ARB_clear_texture',
                                  'GLEW_ARB_clip_control',
                                  'GLEW_ARB_color_buffer_float',
                                  'GLEW_ARB_compatibility',
                                  'GLEW_ARB_compressed_texture_pixel_storage',
                                  'GLEW_ARB_compute_shader',
                                  'GLEW_ARB_compute_variable_group_size',
                                  'GLEW_ARB_conditional_render_inverted',
                                  'GLEW_ARB_conservative_depth',
                                  'GLEW_ARB_copy_buffer',
                                  'GLEW_ARB_copy_image',
                                  'GLEW_ARB_cull_distance',
                                  'GLEW_ARB_debug_output',
                                  'GLEW_ARB_depth_buffer_float',
                                  'GLEW_ARB_depth_clamp',
                                  'GLEW_ARB_depth_texture',
                                  'GLEW_ARB_derivative_control',
                                  'GLEW_ARB_direct_state_access',
                                  'GLEW_ARB_draw_buffers',
                                  'GLEW_ARB_draw_buffers_blend',
                                  'GLEW_ARB_draw_elements_base_vertex',
                                  'GLEW_ARB_draw_indirect',
                                  'GLEW_ARB_draw_instanced',
                                  'GLEW_ARB_enhanced_layouts',
                                  'GLEW_ARB_explicit_attrib_location',
                                  'GLEW_ARB_explicit_uniform_location',
                                  'GLEW_ARB_fragment_coord_conventions',
                                  'GLEW_ARB_fragment_layer_viewport',
                                  'GLEW_ARB_fragment_program',
                                  'GLEW_ARB_fragment_program_shadow',
                                  'GLEW_ARB_fragment_shader',
                                  'GLEW_ARB_fragment_shader_interlock',
                                  'GLEW_ARB_framebuffer_no_attachments',
                                  'GLEW_ARB_framebuffer_object',
                                  'GLEW_ARB_framebuffer_sRGB',
                                  'GLEW_ARB_geometry_shader4',
                                  'GLEW_ARB_get_program_binary',
                                  'GLEW_ARB_get_texture_sub_image',
                                  'GLEW_ARB_gl_spirv',
                                  'GLEW_ARB_gpu_shader5',
                                  'GLEW_ARB_gpu_shader_fp64',
                                  'GLEW_ARB_gpu_shader_int64',
                                  'GLEW_ARB_half_float_pixel',
                                  'GLEW_ARB_half_float_vertex',
                                  'GLEW_ARB_imaging',
                                  'GLEW_ARB_indirect_parameters',
                                  'GLEW_ARB_instanced_arrays',
                                  'GLEW_ARB_internalformat_query',
                                  'GLEW_ARB_internalformat_query2',
                                  'GLEW_ARB_invalidate_subdata',
                                  'GLEW_ARB_map_buffer_alignment',
                                  'GLEW_ARB_map_buffer_range',
                                  'GLEW_ARB_matrix_palette',
                                  'GLEW_ARB_multi_bind',
                                  'GLEW_ARB_multi_draw_indirect',
                                  'GLEW_ARB_multisample',
                                  'GLEW_ARB_multitexture',
                                  'GLEW_ARB_occlusion_query',
                                  'GLEW_ARB_occlusion_query2',
                                  'GLEW_ARB_parallel_shader_compile',
                                  'GLEW_ARB_pipeline_statistics_query',
                                  'GLEW_ARB_pixel_buffer_object',
                                  'GLEW_ARB_point_parameters',
                                  'GLEW_ARB_point_sprite',
                                  'GLEW_ARB_post_depth_coverage',
                                  'GLEW_ARB_program_interface_query',
                                  'GLEW_ARB_provoking_vertex',
                                  'GLEW_ARB_query_buffer_object',
                                  'GLEW_ARB_robust_buffer_access_behavior',
                                  'GLEW_ARB_robustness',
                                  'GLEW_ARB_robustness_application_isolation',
                                  'GLEW_ARB_robustness_share_group_isolation',
                                  'GLEW_ARB_sample_locations',
                                  'GLEW_ARB_sample_shading',
                                  'GLEW_ARB_sampler_objects',
                                  'GLEW_ARB_seamless_cube_map',
                                  'GLEW_ARB_seamless_cubemap_per_texture',
                                  'GLEW_ARB_separate_shader_objects',
                                  'GLEW_ARB_shader_atomic_counter_ops',
                                  'GLEW_ARB_shader_atomic_counters',
                                  'GLEW_ARB_shader_ballot',
                                  'GLEW_ARB_shader_bit_encoding',
                                  'GLEW_ARB_shader_clock',
                                  'GLEW_ARB_shader_draw_parameters',
                                  'GLEW_ARB_shader_group_vote',
                                  'GLEW_ARB_shader_image_load_store',
                                  'GLEW_ARB_shader_image_size',
                                  'GLEW_ARB_shader_objects',
                                  'GLEW_ARB_shader_precision',
                                  'GLEW_ARB_shader_stencil_export',
                                  'GLEW_ARB_shader_storage_buffer_object',
                                  'GLEW_ARB_shader_subroutine',
                                  'GLEW_ARB_shader_texture_image_samples',
                                  'GLEW_ARB_shader_texture_lod',
                                  'GLEW_ARB_shader_viewport_layer_array',
                                  'GLEW_ARB_shading_language_100',
                                  'GLEW_ARB_shading_language_420pack',
                                  'GLEW_ARB_shading_language_include',
                                  'GLEW_ARB_shading_language_packing',
                                  'GLEW_ARB_shadow',
                                  'GLEW_ARB_shadow_ambient',
                                  'GLEW_ARB_sparse_buffer',
                                  'GLEW_ARB_sparse_texture',
                                  'GLEW_ARB_sparse_texture2',
                                  'GLEW_ARB_sparse_texture_clamp',
                                  'GLEW_ARB_stencil_texturing',
                                  'GLEW_ARB_sync',
                                  'GLEW_ARB_tessellation_shader',
                                  'GLEW_ARB_texture_barrier',
                                  'GLEW_ARB_texture_border_clamp',
                                  'GLEW_ARB_texture_buffer_object',
                                  'GLEW_ARB_texture_buffer_object_rgb32',
                                  'GLEW_ARB_texture_buffer_range',
                                  'GLEW_ARB_texture_compression',
                                  'GLEW_ARB_texture_compression_bptc',
                                  'GLEW_ARB_texture_compression_rgtc',
                                  'GLEW_ARB_texture_cube_map',
                                  'GLEW_ARB_texture_cube_map_array',
                                  'GLEW_ARB_texture_env_add',
                                  'GLEW_ARB_texture_env_combine',
                                  'GLEW_ARB_texture_env_crossbar',
                                  'GLEW_ARB_texture_env_dot3',
                                  'GLEW_ARB_texture_filter_minmax',
                                  'GLEW_ARB_texture_float',
                                  'GLEW_ARB_texture_gather',
                                  'GLEW_ARB_texture_mirror_clamp_to_edge',
                                  'GLEW_ARB_texture_mirrored_repeat',
                                  'GLEW_ARB_texture_multisample',
                                  'GLEW_ARB_texture_non_power_of_two',
                                  'GLEW_ARB_texture_query_levels',
                                  'GLEW_ARB_texture_query_lod',
                                  'GLEW_ARB_texture_rectangle',
                                  'GLEW_ARB_texture_rg',
                                  'GLEW_ARB_texture_rgb10_a2ui',
                                  'GLEW_ARB_texture_stencil8',
                                  'GLEW_ARB_texture_storage',
                                  'GLEW_ARB_texture_storage_multisample',
                                  'GLEW_ARB_texture_swizzle',
                                  'GLEW_ARB_texture_view',
                                  'GLEW_ARB_timer_query',
                                  'GLEW_ARB_transform_feedback2',
                                  'GLEW_ARB_transform_feedback3',
                                  'GLEW_ARB_transform_feedback_instanced',
                                  'GLEW_ARB_transform_feedback_overflow_query',
                                  'GLEW_ARB_transpose_matrix',
                                  'GLEW_ARB_uniform_buffer_object',
                                  'GLEW_ARB_vertex_array_bgra',
                                  'GLEW_ARB_vertex_array_object',
                                  'GLEW_ARB_vertex_attrib_64bit',
                                  'GLEW_ARB_vertex_attrib_binding',
                                  'GLEW_ARB_vertex_blend',
                                  'GLEW_ARB_vertex_buffer_object',
                                  'GLEW_ARB_vertex_program',
                                  'GLEW_ARB_vertex_shader',
                                  'GLEW_ARB_vertex_type_10f_11f_11f_rev',
                                  'GLEW_ARB_vertex_type_2_10_10_10_rev',
                                  'GLEW_ARB_viewport_array',
                                  'GLEW_ARB_window_pos',
                                  'GLEW_ATIX_point_sprites',
                                  'GLEW_ATIX_texture_env_combine3',
                                  'GLEW_ATIX_texture_env_route',
                                  'GLEW_ATIX_vertex_shader_output_point_size',
                                  'GLEW_ATI_draw_buffers',
                                  'GLEW_ATI_element_array',
                                  'GLEW_ATI_envmap_bumpmap',
                                  'GLEW_ATI_fragment_shader',
                                  'GLEW_ATI_map_object_buffer',
                                  'GLEW_ATI_meminfo',
                                  'GLEW_ATI_pn_triangles',
                                  'GLEW_ATI_separate_stencil',
                                  'GLEW_ATI_shader_texture_lod',
                                  'GLEW_ATI_text_fragment_shader',
                                  'GLEW_ATI_texture_compression_3dc',
                                  'GLEW_ATI_texture_env_combine3',
                                  'GLEW_ATI_texture_float',
                                  'GLEW_ATI_texture_mirror_once',
                                  'GLEW_ATI_vertex_array_object',
                                  'GLEW_ATI_vertex_attrib_array_object',
                                  'GLEW_ATI_vertex_streams',
                                  'GLEW_EGL_NV_robustness_video_memory_purge',
                                  'GLEW_EXT_422_pixels',
                                  'GLEW_EXT_Cg_shader',
                                  'GLEW_EXT_abgr',
                                  'GLEW_EXT_bgra',
                                  'GLEW_EXT_bindable_uniform',
                                  'GLEW_EXT_blend_color',
                                  'GLEW_EXT_blend_equation_separate',
                                  'GLEW_EXT_blend_func_separate',
                                  'GLEW_EXT_blend_logic_op',
                                  'GLEW_EXT_blend_minmax',
                                  'GLEW_EXT_blend_subtract',
                                  'GLEW_EXT_clip_volume_hint',
                                  'GLEW_EXT_cmyka',
                                  'GLEW_EXT_color_subtable',
                                  'GLEW_EXT_compiled_vertex_array',
                                  'GLEW_EXT_convolution',
                                  'GLEW_EXT_coordinate_frame',
                                  'GLEW_EXT_copy_texture',
                                  'GLEW_EXT_cull_vertex',
                                  'GLEW_EXT_debug_label',
                                  'GLEW_EXT_debug_marker',
                                  'GLEW_EXT_depth_bounds_test',
                                  'GLEW_EXT_direct_state_access',
                                  'GLEW_EXT_draw_buffers2',
                                  'GLEW_EXT_draw_instanced',
                                  'GLEW_EXT_draw_range_elements',
                                  'GLEW_EXT_fog_coord',
                                  'GLEW_EXT_fragment_lighting',
                                  'GLEW_EXT_framebuffer_blit',
                                  'GLEW_EXT_framebuffer_multisample',
                                  'GLEW_EXT_framebuffer_multisample_blit_scaled',
                                  'GLEW_EXT_framebuffer_object',
                                  'GLEW_EXT_framebuffer_sRGB',
                                  'GLEW_EXT_geometry_shader4',
                                  'GLEW_EXT_gpu_program_parameters',
                                  'GLEW_EXT_gpu_shader4',
                                  'GLEW_EXT_histogram',
                                  'GLEW_EXT_index_array_formats',
                                  'GLEW_EXT_index_func',
                                  'GLEW_EXT_index_material',
                                  'GLEW_EXT_index_texture',
                                  'GLEW_EXT_light_texture',
                                  'GLEW_EXT_misc_attribute',
                                  'GLEW_EXT_multi_draw_arrays',
                                  'GLEW_EXT_multisample',
                                  'GLEW_EXT_packed_depth_stencil',
                                  'GLEW_EXT_packed_float',
                                  'GLEW_EXT_packed_pixels',
                                  'GLEW_EXT_paletted_texture',
                                  'GLEW_EXT_pixel_buffer_object',
                                  'GLEW_EXT_pixel_transform',
                                  'GLEW_EXT_pixel_transform_color_table',
                                  'GLEW_EXT_point_parameters',
                                  'GLEW_EXT_polygon_offset',
                                  'GLEW_EXT_polygon_offset_clamp',
                                  'GLEW_EXT_post_depth_coverage',
                                  'GLEW_EXT_provoking_vertex',
                                  'GLEW_EXT_raster_multisample',
                                  'GLEW_EXT_rescale_normal',
                                  'GLEW_EXT_scene_marker',
                                  'GLEW_EXT_secondary_color',
                                  'GLEW_EXT_separate_shader_objects',
                                  'GLEW_EXT_separate_specular_color',
                                  'GLEW_EXT_shader_image_load_formatted',
                                  'GLEW_EXT_shader_image_load_store',
                                  'GLEW_EXT_shader_integer_mix',
                                  'GLEW_EXT_shadow_funcs',
                                  'GLEW_EXT_shared_texture_palette',
                                  'GLEW_EXT_sparse_texture2',
                                  'GLEW_EXT_stencil_clear_tag',
                                  'GLEW_EXT_stencil_two_side',
                                  'GLEW_EXT_stencil_wrap',
                                  'GLEW_EXT_subtexture',
                                  'GLEW_EXT_texture',
                                  'GLEW_EXT_texture3D',
                                  'GLEW_EXT_texture_array',
                                  'GLEW_EXT_texture_buffer_object',
                                  'GLEW_EXT_texture_compression_dxt1',
                                  'GLEW_EXT_texture_compression_latc',
                                  'GLEW_EXT_texture_compression_rgtc',
                                  'GLEW_EXT_texture_compression_s3tc',
                                  'GLEW_EXT_texture_cube_map',
                                  'GLEW_EXT_texture_edge_clamp',
                                  'GLEW_EXT_texture_env',
                                  'GLEW_EXT_texture_env_add',
                                  'GLEW_EXT_texture_env_combine',
                                  'GLEW_EXT_texture_env_dot3',
                                  'GLEW_EXT_texture_filter_anisotropic',
                                  'GLEW_EXT_texture_filter_minmax',
                                  'GLEW_EXT_texture_integer',
                                  'GLEW_EXT_texture_lod_bias',
                                  'GLEW_EXT_texture_mirror_clamp',
                                  'GLEW_EXT_texture_object',
                                  'GLEW_EXT_texture_perturb_normal',
                                  'GLEW_EXT_texture_rectangle',
                                  'GLEW_EXT_texture_sRGB',
                                  'GLEW_EXT_texture_sRGB_decode',
                                  'GLEW_EXT_texture_shared_exponent',
                                  'GLEW_EXT_texture_snorm',
                                  'GLEW_EXT_texture_swizzle',
                                  'GLEW_EXT_timer_query',
                                  'GLEW_EXT_transform_feedback',
                                  'GLEW_EXT_vertex_array',
                                  'GLEW_EXT_vertex_array_bgra',
                                  'GLEW_EXT_vertex_attrib_64bit',
                                  'GLEW_EXT_vertex_shader',
                                  'GLEW_EXT_vertex_weighting',
                                  'GLEW_EXT_window_rectangles',
                                  'GLEW_EXT_x11_sync_object',
                                  'GLEW_GREMEDY_frame_terminator',
                                  'GLEW_GREMEDY_string_marker',
                                  'GLEW_HP_convolution_border_modes',
                                  'GLEW_HP_image_transform',
                                  'GLEW_HP_occlusion_test',
                                  'GLEW_HP_texture_lighting',
                                  'GLEW_IBM_cull_vertex',
                                  'GLEW_IBM_multimode_draw_arrays',
                                  'GLEW_IBM_rasterpos_clip',
                                  'GLEW_IBM_static_data',
                                  'GLEW_IBM_texture_mirrored_repeat',
                                  'GLEW_IBM_vertex_array_lists',
                                  'GLEW_INGR_color_clamp',
                                  'GLEW_INGR_interlace_read',
                                  'GLEW_INTEL_conservative_rasterization',
                                  'GLEW_INTEL_fragment_shader_ordering',
                                  'GLEW_INTEL_framebuffer_CMAA',
                                  'GLEW_INTEL_map_texture',
                                  'GLEW_INTEL_parallel_arrays',
                                  'GLEW_INTEL_performance_query',
                                  'GLEW_INTEL_texture_scissor',
                                  'GLEW_KHR_blend_equation_advanced',
                                  'GLEW_KHR_blend_equation_advanced_coherent',
                                  'GLEW_KHR_context_flush_control',
                                  'GLEW_KHR_debug',
                                  'GLEW_KHR_no_error',
                                  'GLEW_KHR_robust_buffer_access_behavior',
                                  'GLEW_KHR_robustness',
                                  'GLEW_KHR_texture_compression_astc_hdr',
                                  'GLEW_KHR_texture_compression_astc_ldr',
                                  'GLEW_KHR_texture_compression_astc_sliced_3d',
                                  'GLEW_KTX_buffer_region',
                                  'GLEW_MESAX_texture_stack',
                                  'GLEW_MESA_pack_invert',
                                  'GLEW_MESA_resize_buffers',
                                  'GLEW_MESA_shader_integer_functions',
                                  'GLEW_MESA_window_pos',
                                  'GLEW_MESA_ycbcr_texture',
                                  'GLEW_NVX_blend_equation_advanced_multi_draw_buffers',
                                  'GLEW_NVX_conditional_render',
                                  'GLEW_NVX_gpu_memory_info',
                                  'GLEW_NVX_linked_gpu_multicast',
                                  'GLEW_NV_bindless_multi_draw_indirect',
                                  'GLEW_NV_bindless_multi_draw_indirect_count',
                                  'GLEW_NV_bindless_texture',
                                  'GLEW_NV_blend_equation_advanced',
                                  'GLEW_NV_blend_equation_advanced_coherent',
                                  'GLEW_NV_blend_square',
                                  'GLEW_NV_clip_space_w_scaling',
                                  'GLEW_NV_command_list',
                                  'GLEW_NV_compute_program5',
                                  'GLEW_NV_conditional_render',
                                  'GLEW_NV_conservative_raster',
                                  'GLEW_NV_conservative_raster_dilate',
                                  'GLEW_NV_conservative_raster_pre_snap_triangles',
                                  'GLEW_NV_copy_depth_to_color',
                                  'GLEW_NV_copy_image',
                                  'GLEW_NV_deep_texture3D',
                                  'GLEW_NV_depth_buffer_float',
                                  'GLEW_NV_depth_clamp',
                                  'GLEW_NV_depth_range_unclamped',
                                  'GLEW_NV_draw_texture',
                                  'GLEW_NV_draw_vulkan_image',
                                  'GLEW_NV_evaluators',
                                  'GLEW_NV_explicit_multisample',
                                  'GLEW_NV_fence',
                                  'GLEW_NV_fill_rectangle',
                                  'GLEW_NV_float_buffer',
                                  'GLEW_NV_fog_distance',
                                  'GLEW_NV_fragment_coverage_to_color',
                                  'GLEW_NV_fragment_program',
                                  'GLEW_NV_fragment_program2',
                                  'GLEW_NV_fragment_program4',
                                  'GLEW_NV_fragment_program_option',
                                  'GLEW_NV_fragment_shader_interlock',
                                  'GLEW_NV_framebuffer_mixed_samples',
                                  'GLEW_NV_framebuffer_multisample_coverage',
                                  'GLEW_NV_geometry_program4',
                                  'GLEW_NV_geometry_shader4',
                                  'GLEW_NV_geometry_shader_passthrough',
                                  'GLEW_NV_gpu_multicast',
                                  'GLEW_NV_gpu_program4',
                                  'GLEW_NV_gpu_program5',
                                  'GLEW_NV_gpu_program5_mem_extended',
                                  'GLEW_NV_gpu_program_fp64',
                                  'GLEW_NV_gpu_shader5',
                                  'GLEW_NV_half_float',
                                  'GLEW_NV_internalformat_sample_query',
                                  'GLEW_NV_light_max_exponent',
                                  'GLEW_NV_multisample_coverage',
                                  'GLEW_NV_multisample_filter_hint',
                                  'GLEW_NV_occlusion_query',
                                  'GLEW_NV_packed_depth_stencil',
                                  'GLEW_NV_parameter_buffer_object',
                                  'GLEW_NV_parameter_buffer_object2',
                                  'GLEW_NV_path_rendering',
                                  'GLEW_NV_path_rendering_shared_edge',
                                  'GLEW_NV_pixel_data_range',
                                  'GLEW_NV_point_sprite',
                                  'GLEW_NV_present_video',
                                  'GLEW_NV_primitive_restart',
                                  'GLEW_NV_register_combiners',
                                  'GLEW_NV_register_combiners2',
                                  'GLEW_NV_robustness_video_memory_purge',
                                  'GLEW_NV_sample_locations',
                                  'GLEW_NV_sample_mask_override_coverage',
                                  'GLEW_NV_shader_atomic_counters',
                                  'GLEW_NV_shader_atomic_float',
                                  'GLEW_NV_shader_atomic_float64',
                                  'GLEW_NV_shader_atomic_fp16_vector',
                                  'GLEW_NV_shader_atomic_int64',
                                  'GLEW_NV_shader_buffer_load',
                                  'GLEW_NV_shader_storage_buffer_object',
                                  'GLEW_NV_shader_thread_group',
                                  'GLEW_NV_shader_thread_shuffle',
                                  'GLEW_NV_stereo_view_rendering',
                                  'GLEW_NV_tessellation_program5',
                                  'GLEW_NV_texgen_emboss',
                                  'GLEW_NV_texgen_reflection',
                                  'GLEW_NV_texture_barrier',
                                  'GLEW_NV_texture_compression_vtc',
                                  'GLEW_NV_texture_env_combine4',
                                  'GLEW_NV_texture_expand_normal',
                                  'GLEW_NV_texture_multisample',
                                  'GLEW_NV_texture_rectangle',
                                  'GLEW_NV_texture_shader',
                                  'GLEW_NV_texture_shader2',
                                  'GLEW_NV_texture_shader3',
                                  'GLEW_NV_transform_feedback',
                                  'GLEW_NV_transform_feedback2',
                                  'GLEW_NV_uniform_buffer_unified_memory',
                                  'GLEW_NV_vdpau_interop',
                                  'GLEW_NV_vertex_array_range',
                                  'GLEW_NV_vertex_array_range2',
                                  'GLEW_NV_vertex_attrib_integer_64bit',
                                  'GLEW_NV_vertex_buffer_unified_memory',
                                  'GLEW_NV_vertex_program',
                                  'GLEW_NV_vertex_program1_1',
                                  'GLEW_NV_vertex_program2',
                                  'GLEW_NV_vertex_program2_option',
                                  'GLEW_NV_vertex_program3',
                                  'GLEW_NV_vertex_program4',
                                  'GLEW_NV_video_capture',
                                  'GLEW_NV_viewport_array2',
                                  'GLEW_NV_viewport_swizzle',
                                  'GLEW_OES_byte_coordinates',
                                  'GLEW_OES_compressed_paletted_texture',
                                  'GLEW_OES_read_format',
                                  'GLEW_OES_single_precision',
                                  'GLEW_OML_interlace',
                                  'GLEW_OML_resample',
                                  'GLEW_OML_subsample',
                                  'GLEW_OVR_multiview',
                                  'GLEW_OVR_multiview2',
                                  'GLEW_PGI_misc_hints',
                                  'GLEW_PGI_vertex_hints',
                                  'GLEW_REGAL_ES1_0_compatibility',
                                  'GLEW_REGAL_ES1_1_compatibility',
                                  'GLEW_REGAL_enable',
                                  'GLEW_REGAL_error_string',
                                  'GLEW_REGAL_extension_query',
                                  'GLEW_REGAL_log',
                                  'GLEW_REGAL_proc_address',
                                  'GLEW_REND_screen_coordinates',
                                  'GLEW_S3_s3tc',
                                  'GLEW_SGIS_color_range',
                                  'GLEW_SGIS_detail_texture',
                                  'GLEW_SGIS_fog_function',
                                  'GLEW_SGIS_generate_mipmap',
                                  'GLEW_SGIS_multisample',
                                  'GLEW_SGIS_pixel_texture',
                                  'GLEW_SGIS_point_line_texgen',
                                  'GLEW_SGIS_sharpen_texture',
                                  'GLEW_SGIS_texture4D',
                                  'GLEW_SGIS_texture_border_clamp',
                                  'GLEW_SGIS_texture_edge_clamp',
                                  'GLEW_SGIS_texture_filter4',
                                  'GLEW_SGIS_texture_lod',
                                  'GLEW_SGIS_texture_select',
                                  'GLEW_SGIX_async',
                                  'GLEW_SGIX_async_histogram',
                                  'GLEW_SGIX_async_pixel',
                                  'GLEW_SGIX_blend_alpha_minmax',
                                  'GLEW_SGIX_clipmap',
                                  'GLEW_SGIX_convolution_accuracy',
                                  'GLEW_SGIX_depth_texture',
                                  'GLEW_SGIX_flush_raster',
                                  'GLEW_SGIX_fog_offset',
                                  'GLEW_SGIX_fog_texture',
                                  'GLEW_SGIX_fragment_specular_lighting',
                                  'GLEW_SGIX_framezoom',
                                  'GLEW_SGIX_interlace',
                                  'GLEW_SGIX_ir_instrument1',
                                  'GLEW_SGIX_list_priority',
                                  'GLEW_SGIX_pixel_texture',
                                  'GLEW_SGIX_pixel_texture_bits',
                                  'GLEW_SGIX_reference_plane',
                                  'GLEW_SGIX_resample',
                                  'GLEW_SGIX_shadow',
                                  'GLEW_SGIX_shadow_ambient',
                                  'GLEW_SGIX_sprite',
                                  'GLEW_SGIX_tag_sample_buffer',
                                  'GLEW_SGIX_texture_add_env',
                                  'GLEW_SGIX_texture_coordinate_clamp',
                                  'GLEW_SGIX_texture_lod_bias',
                                  'GLEW_SGIX_texture_multi_buffer',
                                  'GLEW_SGIX_texture_range',
                                  'GLEW_SGIX_texture_scale_bias',
                                  'GLEW_SGIX_vertex_preclip',
                                  'GLEW_SGIX_vertex_preclip_hint',
                                  'GLEW_SGIX_ycrcb',
                                  'GLEW_SGI_color_matrix',
                                  'GLEW_SGI_color_table',
                                  'GLEW_SGI_texture_color_table',
                                  'GLEW_SUNX_constant_data',
                                  'GLEW_SUN_convolution_border_modes',
                                  'GLEW_SUN_global_alpha',
                                  'GLEW_SUN_mesh_array',
                                  'GLEW_SUN_read_video_pixels',
                                  'GLEW_SUN_slice_accum',
                                  'GLEW_SUN_triangle_list',
                                  'GLEW_SUN_vertex',
                                  'GLEW_WIN_phong_shading',
                                  'GLEW_WIN_specular_fog',
                                  'GLEW_WIN_swap_hint'
                                ]
    );
}

1;
